
* =============================================================================================== *
* =============================================================================================== *
*								WBL 2024        												  *
*			        WBL 2024  RRR : Chapter 2 - Tables and Figures 				                  *
* =============================================================================================== *
* =============================================================================================== *
/*

	Title: 		WBL2024_Report_Chapter2.do   

 	Outline: 	This .do file creates output for WBL 2024 Report Chapter 2

 	Input: 		This .do file uses the following files in "/DataWork/Data/Final" subfolder:
	            "WBL2024_LEGAL_PROCESS_EOIndex.dta" 
				"WBL2024_Job_Restrictions_Data.xlsx"
				"WBL2024_EODataset_EligibleCountriesOnly_EOLevel.dta"

	Output:		Figures and tables for Chapter 2 are created and saved in  Saved in "/Outputs/Chapter2" folder. 
	
	Description: Variables ending with *_LegNew are for WBL Legal Frameworks 2.0 variables,
	             Variables starting with pro_* are for WBL Supportive Frameworks variables,
				 Variables ending with *_LegOld are for WBL Legal Frameworks 1.0 variables,
				 Variables ending with *_EO are for WBL Expert Opinions variables.
				 Variables for Indices:  Legal_Index_LegNew ,  Process_Index , Legal_Index_old , EO_index
	
	            
*/
* =============================================================================================== *

	clear all
	clear matrix
	set more off
	set matsize 700
	set graph on
	
* =============================================================================================== *
*  CHAPTER 2
* =============================================================================================== *

{

*** Figure 2.1

    **	Not Codable

*** Table 2.1

    **	Not Codable


*** Figure 2.2
	
    * Load Dataset on Indicator Breakdown

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    preserve 

    * Keep only the relevant variables
    keep economy safety1_LegNew safety2_LegNew safety3_LegNew safety4_LegNew

    * Rename the variables for consistency  
    * Reorder the sequence of these questions based on the graph
    rename safety1_LegNew safety_LegNew3
    rename safety2_LegNew safety_LegNew4
    rename safety3_LegNew safety_LegNew2
    rename safety4_LegNew safety_LegNew1

    * Reshape the data to long format
    reshape long safety_LegNew, i(economy) j(question)

    * Generate labels for the questions
    label define label_q ///
          1 "Does the law address child marriage?" ///
          2 "Does the law address sexual harassment?" ///
          3 "Does the law address domestic violence?" ///
          4 "Does the law address femicide?"

    * Using label define and label values to turn 0/1 to No/Yes
    label values question label_q

    * Keep only the relevant variables
    keep safety_LegNew question

    * Contract the data to get the counts
    contract safety_LegNew question

    * Reshape from long to wide for numbers on "Yes" or "No"
    reshape wide _freq, i(question) j(safety_LegNew)

    * Generate the horizontal bar chart
    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.2: Safety Legal Frameworks Question Examine Laws on" "Child Marriage, Sexual Harassment, Domestic Violence, and Femicide", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)

graph export "${output_c2}/02_Figure_2_2.png", as(png) replace

restore
	
*** Figure 2.3

    preserve
    keep economy childcare1_LegNew childcare2_LegNew childcare3_LegNew childcare4_LegNew
    rename childcare1_LegNew childcare_LegNew1
    rename childcare2_LegNew childcare_LegNew2
    rename childcare3_LegNew childcare_LegNew3
    rename childcare4_LegNew childcare_LegNew4

    reshape long childcare_LegNew, i(economy) j(question)

    label define label_q ///
          1 "Does the law establish the provision of center-based childcare services?" ///
          2 "Does the law establish any form of support for families for childcare services?" ///
          3 "Does the law establish any form of support for nonstate childcare providers?" ///
          4 "Does the law establish quality standards for the provision of center-based childcare services?"

    label values question label_q

    keep childcare_LegNew question

    contract childcare_LegNew question

    reshape wide _freq, i(question) j(childcare_LegNew)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.3: Childcare Legal Frameworks Questions Examine Laws" "Governing the Provision of Center-Based Childcare Services", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)

graph export "${output_c2}/02_Figure_2_3.png", as(png) replace

     restore 

*** Figure 2.4

    preserve
	keep economy mobility1_LegNew mobility2_LegNew mobility3_LegNew mobility4_LegNew
	rename mobility1_LegNew mobility_LegNew2 
	rename mobility2_LegNew mobility_LegNew1
	rename mobility3_LegNew mobility_LegNew3
	rename mobility4_LegNew mobility_LegNew4

    reshape long mobility_LegNew, i(economy) j(question)

    label define label_q ///
          1 "Can a woman choose where to live in the same way as a man?" ///
          2 "Can a woman travel internationally in the same way as a man?" ///
          3 "Can a woman travel outside her home in the same way as a man?" ///
          4 "Do a woman and a man have equal rights to confer citizenship on their spouses and their children?"

    label values question label_q

    keep mobility_LegNew question

    contract mobility_LegNew question

    reshape wide _freq, i(question) j(mobility_LegNew)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.4: Mobility Legal Frameworks Questions Examine Laws" "Affecting Women's Agency and Freedom of Movement", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)
	
graph export "${output_c2}/02_Figure_2_4.png", as(png) replace

    restore 

	
*** Figure 2.5

    preserve
	keep economy workplace1_LegNew workplace2_LegNew workplace3_LegNew workplace4_LegNew
	rename workplace1_LegNew workplace_LegNew1
	rename workplace2_LegNew workplace_LegNew3
	rename workplace3_LegNew workplace_LegNew2
	rename workplace4_LegNew workplace_LegNew4

    reshape long workplace_LegNew, i(economy) j(question)

    label define label_q ///
          1 "Can a woman get a job in the same way as a man?" ///
          2 "Does the law explicitly prohibit discrimination in recruitment based on marital status, parental status, and age?" ///
          3 "Does the law prohibit discrimination in employment based on gender?" ///
          4 "Does the law allow employees to request flexible work?"

    label values question label_q

    keep workplace_LegNew question

    contract workplace_LegNew question

    reshape wide _freq, i(question) j(workplace_LegNew)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.5: Workplace Legal Frameworks Questions Examine Laws" "Affecting Women's Decision to Work", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)

graph export "${output_c2}/02_Figure_2_5.png", as(png) replace
	
    restore 


*** Figure 2.6

    preserve
	keep economy pay1_LegNew pay2_LegNew pay3_LegNew pay4_LegNew
	rename pay1_LegNew pay_LegNew1
	rename pay2_LegNew pay_LegNew2
	rename pay3_LegNew pay_LegNew4
	rename pay4_LegNew pay_LegNew3
	
	reshape long pay_LegNew, i(economy) j(question)

    label define label_q ///
           1 "Does the law mandate equal remuneration for work of equal value?" ///
           2 "Can a woman work at night in the same way as a man?" ///
           3 "Can a woman work in a job deemed dangerous in the same way as a man?" ///
           4 "Can a woman work in an industrial job in the same way as a man?"

    label values question label_q

    keep pay_LegNew question

    contract pay_LegNew question

    reshape wide _freq, i(question) j(pay_LegNew)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.6: Pay Legal Frameworks Questions Examine Laws" "Affecting the Gender Wage Gap", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)
	
graph export "${output_c2}/02_Figure_2_6.png", as(png) replace

    restore 

*** Table 2.2 

    * Load Dataset on Prohibitions in Industrial Jobs

	import excel using "${raw}/WBL2024_Job_Restrictions_Data.xlsx" , firstrow clear 

    local industries "Agriculture Construction Energy Factories Mining Transportation Water MinisterPower"

    foreach industry in `industries' {
        gen `industry' = .
	    replace `industry' = 0 if Industries`industry' == "Yes"
	    replace `industry' = 1 if Industries`industry' == "No"
    }

    rename Factories Manufacturing
	gen AtLeastOne = 0
	replace AtLeastOne = 1 if Agriculture == 1 | Construction == 1 | Energy == 1 | Manufacturing == 1 | Mining == 1 | Transportation == 1 | Water == 1 | MinisterPower == 1
    collapse (sum) Agriculture Construction Energy Manufacturing Mining Transportation Water MinisterPower AtLeastOne
    gen id = 1
    xpose, clear varname
    replace _varname = "With at least one prohibition" if _varname == "AtLeastOne"
    rename _varname Industry
    rename v1 Number_Economies
    order Industry Number_Economies
    drop in 10
    label variable Number_Economies "Number of Economies"

export excel using "${output_c2}/02_Table_2_2.xlsx", replace firstrow(variables)

    * Re-Load Dataset on Indicator Breakdown
use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear


*** Figure 2.7

    preserve
	keep economy marriage1_LegNew marriage2_LegNew marriage3_LegNew marriage4_LegNew
	rename marriage1_LegNew marriage_LegNew2
	rename marriage2_LegNew marriage_LegNew1
	rename marriage3_LegNew marriage_LegNew3
	rename marriage4_LegNew marriage_LegNew4
	
	reshape long marriage_LegNew, i(economy) j(question)

    label define label_q ///
          1 "Is the law free of legal provisions that require a married woman to obey her husband?" ///
          2 "Can a woman be head of household or head of family in the same way as a man?" ///
          3 "Can a woman obtain a judgment of divorce in the same way as a man?" ///
          4 "Does a woman have the same rights to remarry as a man?"

    label values question label_q

    keep marriage_LegNew question

    contract marriage_LegNew question

    reshape wide _freq, i(question) j(marriage_LegNew)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.7: Marriage Legal Frameworks Questions Examine Constraints" "In Marriage and Divorce", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)

graph export "${output_c2}/02_Figure_2_7.png", as(png) replace
	
    restore

*** Figure 2.8

preserve

    keep economy parenthood1_LegNew parenthood2_LegNew parenthood3_LegNew parenthood4_LegNew
	rename parenthood1_LegNew parenthood_LegNew1
	rename parenthood2_LegNew parenthood_LegNew2
	rename parenthood3_LegNew parenthood_LegNew3
	rename parenthood4_LegNew parenthood_LegNew4
	
	reshape long parenthood_LegNew, i(economy) j(question)
	
	label define label_q ///
          1 "Is paid leave of at least 14 weeks available to mothers?" ///
          2 "Are leave benefits for mothers paid solely by the government?" ///
          3 "Is paid leave available to fathers?" ///
          4 "Is dismissal of pregnant workers prohibited?" 

    label values question label_q

    keep parenthood_LegNew question

    contract parenthood_LegNew question

    reshape wide _freq, i(question) j(parenthood_LegNew)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.8: Parenthood Legal Frameworks Questions Examine Paid Leave" "Policies and Protections for Pregnant Workers", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)
	
	
graph export "${output_c2}/02_Figure_2_8.png", as(png) replace
	
    restore

***  Figure 2.9

    preserve
	keep economy entrepre1_LegNew entrepre2_LegNew entrepre3_LegNew entrepre4_LegNew
	rename entrepre1_LegNew entrepre_LegNew1
	rename entrepre2_LegNew entrepre_LegNew2
	rename entrepre3_LegNew entrepre_LegNew3
	rename entrepre4_LegNew entrepre_LegNew4

    reshape long entrepre_LegNew, i(economy) j(question)

    label define label_q ///
          1 "Can a woman undertake entrepreneurial activities in the same way as a man?" ///
          2 "Does the law prohibit discrimination in access to credit based on gender?" ///
          3 "Does the law prescribe a gender quota for corporate boards?" ///
          4 "Does the law include gender-sensitive procurement provisions for public procurement processes?"

    label values question label_q

    keep entrepre_LegNew question

    contract entrepre_LegNew question

    reshape wide _freq, i(question) j(entrepre_LegNew)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.9: Entrepreneurship Legal Frameworks Questions Examine Legal" "Constraints on Women's Abilities to Start and Run a Business", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)
	
graph export "${output_c2}/02_Figure_2_9.png", as(png) replace

    restore


*** Figure 2.10

    preserve
    keep economy assets1_LegNew assets2_LegNew assets3_LegNew assets4_LegNew
    rename assets1_LegNew assets_LegNew1
    rename assets2_LegNew assets_LegNew2
    rename assets3_LegNew assets_LegNew3
    rename assets4_LegNew assets_LegNew4

    reshape long assets_LegNew, i(economy) j(question)

    label define label_q ///
          1 "Do a woman and a man have equal administrative power and ownership rights to immovable property, including land?" ///
          2 "Do sons and daughters have equal rights to inherit assets from their parents?" ///
          3 "Do male and female surviving spouses have equal rights to inherit assets?" ///
          4 "Does the law provide for the valuation of nonmonetary contributions?"

    label values question label_q

    keep assets_LegNew question

    contract assets_LegNew question

    reshape wide _freq, i(question) j(assets_LegNew)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.10: Assets Legal Frameworks Questions Examine Gender" "Differences in Property and Inheritance Laws", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)

graph export "${output_c2}/02_Figure_2_10.png", as(png) replace

    restore


***  Figure 2.11

    preserve
	keep economy pension1_LegNew pension2_LegNew pension3_LegNew pension4_LegNew
	rename pension1_LegNew pension_LegNew1
	rename pension2_LegNew pension_LegNew2
	rename pension3_LegNew pension_LegNew3
	rename pension4_LegNew pension_LegNew4
	
	reshape long pension_LegNew, i(economy) j(question)

    label define label_q ///
          1 "Is the age at which a woman and a man can retire with full pension benefits the same?" ///
		  2 "Is the age at which a woman and a man can retire with partial pension benefits the same?" ///
          3 "Is the mandatory retirement age for a woman and a man the same?" ///
          4 "Are periods of absence due to childcare accounted for in pension benefits?"

    label values question label_q

    keep pension_LegNew question

    contract pension_LegNew question

    reshape wide _freq, i(question) j(pension_LegNew)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.11: Pension Legal Frameworks Questions Examine Laws" "Affecting the Size of a Woman's Pension", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)

graph export "${output_c2}/02_Figure_2_11.png", as(png) replace

    restore


*** Table 2.3
    **	Not Codable


*** Figure 2.12

    preserve
    keep economy pro_safety1 pro_safety2 pro_safety3 pro_safety4

    reshape long pro_safety, i(economy) j(question)

    label define label_q ///
          1 "Has the government developed comprehensive mechanisms to address violence against women?" ///
          2 "Are special procedures in place for cases of sexual harassment?" ///
          3 "Is a government entity responsible for monitoring and implementing national services, plans, and programs addressing violence against women?" ///
          4 "Is an annual budgetary allocation devoted to violence against women risk mitigation, prevention, and response programs?"

    label values question label_q

    keep pro_safety question

    contract pro_safety question

    reshape wide _freq, i(question) j(pro_safety)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.12: Safety Supportive Frameworks Questions Examine" "Mechanisms Implementing Laws on child Marriage, Sexual" "Harassment, Domestic Violence and Femicide", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)
	
graph export "${output_c2}/02_Figure_2_12.png", as(png) replace

    restore


*** Figure 2.13

    preserve
	keep economy pro_mobility1 pro_mobility2 pro_mobility3

    reshape long pro_mobility, i(economy) j(question)

    label define label_q ///
          1 "Are passport application processes the same for a woman and a man?" ///
          2 "Are the application processes for official identity documents the same for a woman and a man?" ///
          3 "Does a current policy or plan explicitly consider the specific mobility needs of women in public transportation?"

    label values question label_q

    keep pro_mobility question

    contract pro_mobility question

    reshape wide _freq, i(question) j(pro_mobility)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.13: Mobility Supportive Frameworks Questions Examine" "Bureaucratic Barriers to Women's Agency and Freedom of Movement", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)

graph export "${output_c2}/02_Figure_2_13.png", as(png) replace

    restore


*** Figure 2.14

    preserve
	keep economy pro_workplace1 pro_workplace2 pro_workplace3
	rename pro_workplace1 temp_var
	rename pro_workplace3 pro_workplace1
	rename pro_workplace2 pro_workplace3
	rename temp_var pro_workplace2
	reshape long pro_workplace, i(economy) j(question)

    label define label_q ///
          1 "Does a specialized body receive complaints about gender discrimination in employment?" ///
          2 "Has the government published guidelines on nondiscrimination based on gender in recruitment?" ///
          3 "Has the government published guidelines on flexible work arrangements?"

    label values question label_q

    keep pro_workplace question

    contract pro_workplace question

    reshape wide _freq, i(question) j(pro_workplace)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.14: Workplace Supportive Frameworks Questions Examine" "Measures Implementing Laws Affecting Women's Decisions to Work", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)

graph export "${output_c2}/02_Figure_2_14.png", as(png) replace

    restore

	
*** Figure 2.15

    preserve
    keep economy pro_pay1 pro_pay2

    reshape long pro_pay, i(economy) j(question)

    label define label_q ///
          1 "Are pay transparency measures or enforcement mechanisms in place to address the gender pay gap?" ///
          2 "Have sex-disaggregated data on employment in various industries or sectors been published?"

    label values question label_q

    keep pro_pay question

    contract pro_pay question

    reshape wide _freq, i(question) j(pro_pay)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.15: Pay Supportive Frameworks Questions Examine" "Implementing Laws Affecting Women's Pay", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)
	
graph export "${output_c2}/02_Figure_2_15.png", as(png) replace

    restore
	

*** Figure 2.16

    preserve
    keep economy pro_marriage1 pro_marriage2 pro_marriage3

    reshape long pro_marriage, i(economy) j(question)

    label define label_q ///
          1 "Is there a fast-track process or procedure for family law disputes?" ///
          2 "Are there specialized family courts?" ///
          3 "Is legal aid available for family law disputes"

    label values question label_q

    keep pro_marriage question

    contract pro_marriage question

    reshape wide _freq, i(question) j(pro_marriage)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.16: Marriage Supportive Frameworks Questions Examine" "Courts and Procedures in Family Law", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)

graph export "${output_c2}/02_Figure_2_16.png", as(png) replace

    restore

	
*** Figure 2.17

    preserve
    keep economy pro_parenthood1 pro_parenthood2 pro_parenthood3

    reshape long pro_parenthood, i(economy) j(question)

    label define label_q ///
          1 "Is it possible to apply for maternity benefits using a single government application process?" ///
          2 "Are incentives in place to encourage fathers to take paternity leave upon the birth of a child?" ///
          3 "Have sex-disaggregated data on unpaid care work been published?"

    label values question label_q

    keep pro_parenthood question

    contract pro_parenthood question

    reshape wide _freq, i(question) j(pro_parenthood)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.17: Parenthood Supportive Frameworks Questions Examine" "Measures Implementing Laws Affecting Women's Work Upon" "the Birth of a Child", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)

	
graph export "${output_c2}/02_Figure_2_17.png", as(png) replace

    restore


*** Figure 2.18

    preserve
	keep economy pro_childcare1 pro_childcare2 pro_childcare3 pro_childcare4

    reshape long pro_childcare, i(economy) j(question)

    label define label_q ///
          1 "Is there a publicly available registry or database of childcare providers?" ///
          2 "Is there a clearly outlined application procedure for parents to request financial support from the government for childcare services?" ///
          3 "Is there a clearly outlined application procedure for nonstate childcare providers (private childcare centers or employers) to request financial support from the government for childcare services?" ///
          4 "Has the government published any reports on the quality of childcare services?"

    label values question label_q

    keep pro_childcare question

    contract pro_childcare question

    reshape wide _freq, i(question) j(pro_childcare)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.18: Childcare Supportive Frameworks Questions Examine" "Mechanisms Implementing Childcare Laws", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)

graph export "${output_c2}/02_Figure_2_18.png", as(png) replace

    restore


*** Figure 2.19

    preserve
    keep economy pro_entrepre1 pro_entrepre2 pro_entrepre3

    reshape long pro_entrepre, i(economy) j(question)

    label define label_q ///
          1 "Have sex-disaggregated data on business activities, entrepreneurship, and women-owned businesses been published?" ///
          2 "Are there government-led programs supporting female entrepreneurs providing access to finance and training, coaching, or business development?" ///
          3 "Does a current national government plan or strategy focus on women's access to financial services?"

    label values question label_q

    keep pro_entrepre question

    contract pro_entrepre question

    reshape wide _freq, i(question) j(pro_entrepre)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.19: Entrepreneurship Supportive Frameworks Questions Examine" "Programs and Data Supporting Female Entrepreneurs", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)
	
graph export "${output_c2}/02_Figure_2_19.png", as(png) replace

    restore

	
*** Figure 2.20

    preserve
	keep economy pro_assets1 pro_assets2 pro_assets3

    reshape long pro_assets, i(economy) j(question)

    label define label_q ///
          1 "Are mechanisms or incentives in place to encourage women to register immovable property (including joint titling)?" ///
          2 "Are awareness measures in place to improve women's access to information about marital and inheritance rights?" ///
          3 "Have anonymized sex-disaggregated data on property ownership been published?"

    label values question label_q

    keep pro_assets question

    contract pro_assets question

    reshape wide _freq, i(question) j(pro_assets)

    splitvallabels question, length(40)

    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.20: Assets Supportive Frameworks Questions Examine" "Mechanisms and Data to Implement women's Property and" "Inheritance Rights", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)
	
graph export "${output_c2}/02_Figure_2_20.png", as(png) replace

    restore

	
*** Figure 2.21

    preserve
    keep economy pro_pension1 pro_pension2

    reshape long pro_pension, i(economy) j(question)

    label define label_q ///
          1 "Are incentives in place to increase women's retirement benefits?" ///
          2 "Is a procedure in place for pension beneficiaries to challenge decisions about their benefits?"

    label values question label_q

    keep pro_pension question

    contract pro_pension question

    reshape wide _freq, i(question) j(pro_pension)

    splitvallabels question, length(40)
	
    graph hbar (asis) _freq1 _freq0, ///
        over(question, sort(question) gap(*1) relabel(`r(relabel)')   ///
        label(labsize(small)) axis(outergap(65))) stack ///
        title("Figure 2.21: Pension Supportive Frameworks Questions Examine Policies" "Aimed at Reducing the Gender Pension Gap", ///
        size(medium) jus(left)) ///
        legend(order(1 "Number of economies responding Yes" 2 "Number of economies responding No") position(6) cols(2)) ///
        blabel(bar, position(center) color(white) size(small)) ///
        ysize(3) xsize(8)
	
graph export "${output_c2}/02_Figure_2_21.png", as(png) replace

    restore

	
*** Table 2.4
{

	use "${raw}/WBL2024_ExpertOpinion_EOLevel_ToPublish.dta",  clear 
	
	sort Economy SubmissionID
    by Economy: egen EO_num_econ = count(SubmissionID) // create a variable for total number of EO received at econ level.
  	  
	* Country level data:	  
    
	bys   Economy: gen rank = _n
	keep  if rank == 1   
	keep  Economy EconomyCode  EO_num_econ
   
    egen  EO_ave_glob = mean(EO_num_econ)  
    gen   weight_glob = EO_ave_glob/EO_num_econ
        
    la var EO_num_econ "Number of EO in economy"
    la var EO_ave_glob "Global average # EO per econ"
    la var weight_glob "Weight based on global average # EO per econ"
		  
	keep Economy EO_num_econ EO_ave_glob  weight_glob 
  
  	tempfile weights
	save `weights', replace 	
	  
	* Merge back with EO level data again:	  
	  
    use "${raw}/WBL2024_ExpertOpinion_EOLevel_ToPublish.dta",  clear  // n=1224    
    merge m:1 Economy using 	`weights'
     
    * Rename the variables   
	
	rename  (safety1 mobility1 workplace1 workplace2 pay1 pay2 marriage1 marriage2 parenthood1 parenthood2 childcare1 entrepreneurship1 entrepreneurship2 assets1 pension1) (EO_1_1 EO_2_1 EO_3_1 EO_3_2 EO_3_4 EO_3_5 EO_2_3 EO_2_4 EO_3_7 EO_3_8 EO_3_10 EO_2_6 EO_2_7 EO_2_9 EO_3_12) 
  
  
    * Generate table, store in Excel:

  	estpost tab EO_1_1 [aweight=weight_glob] , m     // Weighted summary statistics
	ereturn list
	mat T = e(pct)
	mat TA = T'
	mat list TA
 	local varlist  EO_2_1 EO_3_1 EO_3_2 EO_3_4 EO_3_5 EO_2_3 EO_2_4 EO_3_7 EO_3_8 EO_3_10 EO_2_6 EO_2_7 EO_2_9 EO_3_12
	foreach var in 	`varlist' {
	    estpost tab `var' [aweight=weight_glob] , m
	    mat T_`var'  = e(pct)
	    mat TA_`var' =  T_`var''
	    mat TA = TA , TA_`var'
	    }
	matrix TB = TA'
	putexcel set "${output_c2}/02_Table_2_4.xlsx" , modify sheet("Weighted_GlobalAve")
    putexcel A1 = matrix(TB), names
	local varlist2 EO_1_1 EO_2_1 EO_3_1 EO_3_2 EO_3_4 EO_3_5 EO_2_3 EO_2_4 EO_3_7 EO_3_8 EO_3_10 EO_2_6 EO_2_7 EO_2_9 EO_3_12
	local row = 2
    foreach x of varlist `varlist2' {
        describe `x'
        local varlabel : var label `x'
        putexcel A`row' = ("`varlabel'")
        local row = `row' + 1
        }
	putexcel A18 = ("Weight=Global average number of EO submissions per economy / Number of EO submissions in the economy")
	putexcel B1  = ("Almost no women…") 
	putexcel C1  = ("Some women…") 
	putexcel D1  = ("About half of all women…") 
	putexcel E1  = ("Most women…") 
	putexcel F1  = ("Almost all women…") 
	putexcel G1  = ("No response") 
	

  }



*** Figure 2.22

    **	Not Codable
	
	
*** Annex 2A.1

    **	Not Codable

	
	
}


* End of do-file!	
