
* =============================================================================================== *
* =============================================================================================== *
*								WBL 2024        												  *
*			        WBL 2024  RRR : Chapter 3 - Tables and Figures 				                  *
* =============================================================================================== *
* =============================================================================================== *
/*

	Title: 		WBL2024_Report_Chapter3.do   

 	Outline: 	This .do file creates output for WBL 2024 Report Chapter 3

 	Input: 		This .do file uses the following files 
	            -- In "/DataWork/Data/Final" subfolder:
	            "WBL2024_LEGAL_PROCESS_EOIndex.dta", 
				"WBL2024_LEGAL_PROCESS_EOIndex_ForComparisons.dta" 

				-- In "/DataWork/Data/Map" subfolder:
				"WB_countries_Admin0_10m"
				"world.dta"
				"world_shp.dta"
			
			
	Output:		Figures and tables for Chapter 3 are created and saved in  Saved in "/Outputs/Chapter3" folder. 
				
				This .do file also creates a .dta file for creating maps using WBL indicators and stores it 
				-- In "/DataWork/Data/Final" subfolder:
				"map_wb.dta"
	
	Description: Variables ending with *_LegNew are for WBL Legal Frameworks 2.0 variables,
	             Variables starting with pro_* are for WBL Supportive Frameworks variables,
				 Variables ending with *_LegOld are for WBL Legal Frameworks 1.0 variables,
				 Variables ending with *_EO are for WBL Expert Opinions variables.
				 Variables for Indices:  Legal_Index_LegNew ,  Process_Index , Legal_Index_old , EO_index	
	
	            
*/
* =============================================================================================== *

	clear all
	clear matrix
	set more off
	set matsize 700
	set graph on
	
* =============================================================================================== *
*  CHAPTER 3
* =============================================================================================== *

{
*** Figure 3.1
    **	Not Codable

*** Map 3.1
    cd "$map"
    spshape2dta "$map\WB_countries_Admin0_10m", replace saving(world)

    cd "$DIREC_MAIN\Code"

    use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear
    keep economy economycode Legal_Index_LegNew Legal_Index_old Process_Index EO_index
    rename economy WB_NAME
    replace WB_NAME = "Congo, Democratic Republic of" if WB_NAME == "Congo, Dem. Rep."
    replace WB_NAME = "Congo, Rep. of" if WB_NAME == "Congo, Rep."
    replace WB_NAME = "Czech Republic" if WB_NAME == "Czechia"
    replace WB_NAME = "Egypt, Arab Republic of" if WB_NAME == "Egypt, Arab Rep."
    replace WB_NAME = "eSwatini" if WB_NAME == "Eswatini"
    replace WB_NAME = "Hong Kong (SAR, China)" if WB_NAME == "Hong Kong SAR, China"
    replace WB_NAME = "Iran, Islamic Republic of" if WB_NAME == "Iran, Islamic Rep."
    replace WB_NAME = "Korea, Republic of" if WB_NAME == "Korea, Rep."
    replace WB_NAME = "Lao People's Democratic Republic" if WB_NAME == "Lao PDR"
    replace WB_NAME = "Micronesia, Federated States of" if WB_NAME == "Micronesia, Fed. Sts."
    replace WB_NAME = "Puerto Rico (US)" if WB_NAME == "Puerto Rico"
    replace WB_NAME = "Saint Kitts and Nevis" if WB_NAME == "St. Kitts and Nevis"
    replace WB_NAME = "Saint Lucia" if WB_NAME == "St. Lucia"
    replace WB_NAME = "Saint Vincent and the Grenadines"  if WB_NAME == "St. Vincent and the Grenadines"
    replace WB_NAME = "Turkey" if WB_NAME == "Türkiye"
    replace WB_NAME = "United States of America" if WB_NAME == "United States"
    replace WB_NAME = "Venezuela, Republica Bolivariana de" if WB_NAME == "Venezuela, RB"
    replace WB_NAME = "Vietnam" if WB_NAME == "Viet Nam"
    replace WB_NAME = "Yemen, Republic of" if WB_NAME == "Yemen, Rep."


save "$data\map_wb.dta", replace

use "$map\world.dta", clear

    merge 1:1 WB_NAME using "$data\map_wb.dta"
    drop if _merge == 2
    drop _merge      // Missing Taiwan, China
	
	summarize Legal_Index_LegNew if FORMAL_EN == "Kingdom of Denmark"
	local denmark_legal = r(mean)
	replace Legal_Index_LegNew = `denmark_legal' if FORMAL_EN == "Greenland"

spmap Legal_Index_LegNew using "$map\world_shp.dta", id(_ID) fcolor(Blues) clmethod(custom) clbreaks(0 15 29 43 58 72 86 100)


graph export "${output_c3}\03_Map_3_1.png", width(2000) replace

*** Figure 3.2

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    label define regionlabel 1 "Middle East & North Africa" 2 "South Asia" 3 "Sub-Saharan Africa" 4 "East Asia & Pacific"  5 "Latin America & Caribbean"  6 "Europe & Central Asia" 7 "High income: OECD"

    encode region, gen(nregion) label(regionlabel)
    gen ccc = 100
    bysort nregion: egen meanbyregion = mean(Legal_Index_LegNew)
    bysort nregion: egen minbyregion  = min(Legal_Index_LegNew)
    bysort nregion: egen maxbyregion  = max(Legal_Index_LegNew)

    tw scatter nregion Legal_Index_LegNew, msymbol(pipe) mcolor(navy) msize(.3in) xsize(8) ylabel(1 "Middle East & North Africa" 2 "South Asia" 3 "Sub-Saharan Africa" 4 "East Asia & Pacific"  5 "Latin America & Caribbean"  6 "Europe & Central Asia" 7 "High income: OECD" ) ylab(, angle(0)) ysc(r(0.5 4.5)) xtitle("WBL score (0-100)") ytitle("") xscale(range(10 .)) || bar ccc nregion, hor barw(.6) color(blue) fintensity(5) bstyle(outline) legend(off) || scatter nregion meanbyregion, msymbol(O) mcolor(orange) msize(.4in) ml(meanbyregion) mlabp(0) mlabf(%9.1f) mlabc(navy)|| scatter nregion minbyregion, ml(minbyregion) mlabf(%9.1f) mlabc(navy) mlabp(9) msymbol(pipe) mcolor(orange) msize(.3in) || scatter nregion maxbyregion, ml(maxbyregion) mlabf(%9.1f) mlabc(navy) mlabp(0) msymbol(pipe) mcolor(orange) msize(.3in)

graph export "${output_c3}\03_Figure_3_2.png", width(2000) replace


*** Figure 3.3

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    label define incomelabel 1 "Low income" 2 "Lower middle income" 3 "Upper middle income" 4 "High income"

    encode incomegroup, gen(nincome) label(incomelabel)
    gen ccc = 100
    bysort nincome: egen meanbyincome = mean(Legal_Index_LegNew)
    bysort nincome: egen minbyincome  = min(Legal_Index_LegNew)
    bysort nincome: egen maxbyincome  = max(Legal_Index_LegNew)

    tw scatter nincome Legal_Index_LegNew, msymbol(pipe) mcolor(navy) msize(.3in) xsize(8) ylabel(1 "Low income" 2 "Lower middle income" 3 "Upper middle income" 4 "High income") ylab(, angle(0)) ysc(r(0.5 4.5)) xtitle("WBL score (0-100)") ytitle("") xscale(range(0 .)) || bar ccc nincome, hor barw(.6) color(blue) fintensity(5) bstyle(outline) legend(off) || scatter nincome meanbyincome, msymbol(O) mcolor(orange) msize(.4in) ml(meanbyincome) mlabp(0) mlabf(%9.1f) mlabc(navy)|| scatter nincome minbyincome, ml(minbyincome) mlabf(%9.1f) mlabc(navy) mlabp(9) msymbol(pipe) mcolor(orange) msize(.3in) || scatter nincome maxbyincome, ml(maxbyincome) mlabf(%9.1f) mlabc(navy) mlabp(0) msymbol(pipe) mcolor(orange) msize(.3in)

graph export "${output_c3}\03_Figure_3_3.png", width(2000) replace


*** Figure 3.4

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    summarize Legal_Index_LegNew, meanonly
    local legal_index_2 = r(mean)
	local rounded_legal_index_2 = round(`legal_index_2', 0.1)

    keep mobility_LegNew workplace_LegNew pay_LegNew marriage_LegNew parenthood_LegNew entrprnshp_LegNew assets_LegNew pension_LegNew childcare_LegNew safety_LegNew

    collapse (mean) mobility_LegNew workplace_LegNew pay_LegNew marriage_LegNew parenthood_LegNew entrprnshp_LegNew assets_LegNew pension_LegNew childcare_LegNew safety_LegNew

    label variable mobility_LegNew Mobility
    label variable workplace_LegNew Workplace
    label variable pay_LegNew Pay
    label variable marriage_LegNew Marriage
    label variable parenthood_LegNew Parenthood
    label variable entrprnshp_LegNew Entrepreneurship
    label variable assets_LegNew Assets
    label variable pension_LegNew Pension
    label variable childcare_LegNew Childcare
    label variable safety_LegNew Safety

graph bar (asis) mobility_LegNew marriage_LegNew assets_LegNew pension_LegNew pay_LegNew parenthood_LegNew workplace_LegNew childcare_LegNew entrprnshp_LegNew safety_LegNew, ///
    ascategory ///
    yline(`legal_index_2') ///
	text(68 75 "WBL 2.0 legal frameworks scores," "global average (`rounded_legal_index_2')", place(e)) ///
    bargap(30) /// 
    bar(1, color(blue)) /// 
    blabel(bar, format(%4.1f)) /// 
    legend(off) ///
	xsize(12)

graph export "${output_c3}\03_Figure_3_4.png", width(2000) replace


*** Figure 3.5

	* R script

*** Figure 3.6

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

	*drop if economy=="Venezuela, RB"
	gen Legal_Index_old_rounded = round(Legal_Index_old, 0.1)
	gen Legal_Index_LegNew_rounded = round(Legal_Index_LegNew, 0.1)
		
	preserve 
	collapse (mean) mean_old = Legal_Index_old_rounded mean_new = Legal_Index_LegNew_rounded, by(region)
	gen pct_change = round(100 * (mean_new - mean_old) / mean_old, 0.1)	
	gen label_pct_region = string(pct_change) + "%"
	
	tempfile pct_region
	save `pct_region'
	
	restore
		
	merge m:1 region using `pct_region'
	drop _merge

    * Panel A: By region

	* Generate sorting by gap
	replace region = "Middle East&North Africa" if region == "Middle East & North Africa"

    gen sort = 1		if region == "Middle East&North Africa"
    replace sort = 2	if region == "South Asia"
    replace sort = 3 	if region == "Sub-Saharan Africa"
    replace sort = 4 	if region == "East Asia & Pacific"
    replace sort = 5 	if region == "Latin America & Caribbean"
    replace sort = 6 	if region == "High income: OECD"
	replace sort = 7 	if region == "Europe & Central Asia"
	
	egen float regionpct = group(region label_pct_region), label lname(mylabel)

    graph dot Legal_Index_old_rounded Legal_Index_LegNew_rounded, ///
		  over(regionpct, label(angle(vertical)) sort(sort)) vertical ///
		  marker(1, mcolor(blue)) marker(2, mcolor(orange)) ///
		  plotregion(fcolor(white)) graphregion(fcolor(white)) ///
		  legend(pos(6) label(1 "WBL 1.0 Legal Frameworks score (0-100)") label(2 "WBL 2.0 Legal Frameworks score (0-100)")) xsize(8) ///
		  yscale(range(30 100)) ///
		  blabel(bar, format(%4.1f)) ///
		  ysize(13) ///
		  name(dot1, replace)

	graph export "${output_c3}\03_Figure_3_6_a.png", replace
		   
    * Panel B: By income	
	drop if economy=="Venezuela, RB"
	gen Legal_Index_old_rounded_inc = round(Legal_Index_old, 0.1)
	gen Legal_Index_LegNew_rounded_inc = round(Legal_Index_LegNew, 0.1)
	
	
	preserve
	collapse (mean) mean_old = Legal_Index_old_rounded_inc mean_new = Legal_Index_LegNew_rounded_inc, by(incomegroup)
	gen pct_change = round(100 * (mean_new - mean_old) / mean_old, 0.1)
	gen label_pct_income = string(pct_change, "%4.1f") + "%"
	
	tempfile pct_income
	save `pct_income'
	
	restore
	
	merge m:1 incomegroup using `pct_income'
	drop _merge
	
    * Generate sorting by gap
    gen sort2 = 1		if incomegroup == "Low income"
    replace sort2 = 2	if incomegroup == "Lower middle income"
    replace sort2 = 3	if incomegroup == "Upper middle income"
    replace sort2 = 4	if incomegroup == "High income"

	egen float incomepct = group(incomegroup label_pct_income), label lname(mylabel)
	
    graph dot Legal_Index_old_rounded_inc Legal_Index_LegNew_rounded_inc, ///
		  over(incomepct, label(angle(vertical)) sort(sort)) vertical ///
		  marker(1, mcolor(blue)) marker(2, mcolor(orange)) ///
		  plotregion(fcolor(white)) graphregion(fcolor(white)) ///
		  legend(pos(6) label(1 "WBL 1.0 Legal Frameworks score (0-100)") label(2 "WBL 2.0 Legal Frameworks score (0-100)")) xsize(8) ///
		  yscale(range(30 100)) ///
		  blabel(bar, format(%4.1f)) ///
		  ysize(12) ///
		  name(dot2, replace)
		  
	graph export "${output_c3}\03_Figure_3_6_b.png", replace

	graph combine dot1 dot2, col(2) xsize(4)

	graph export "${output_c3}\03_Figure_3_6.png", replace 
	
	
*** Map 3.2

use "$map\world.dta", clear
    merge 1:1 WB_NAME using "$data\map_wb.dta"
    drop if _merge == 2
    drop _merge       // Missing Taiwan, China

	summarize Process_Index if FORMAL_EN == "Kingdom of Denmark"
	local denmark_process = r(mean)
	replace Process_Index = `denmark_process' if FORMAL_EN == "Greenland"
	
spmap Process_Index using "$map\world_shp.dta", id(_ID) fcolor(Blues) clmethod(custom) clbreaks(0 15 29 43 58 72 86 100)


graph export "${output_c3}\03_Map_3_2.png", width(2000) replace

*** Figure 3.7

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    label define regionlabel 1 "Sub-Saharan Africa" 2 "Middle East & North Africa" 3 "South Asia" 4 "East Asia & Pacific"  5 "Latin America & Caribbean"  6 "Europe & Central Asia" 7 "High income: OECD"

    encode region, gen(nregion) label(regionlabel)
    gen ccc = 100
    bysort nregion: egen meanbyregion = mean(Process_Index)
    bysort nregion: egen minbyregion  = min(Process_Index)
    bysort nregion: egen maxbyregion  = max(Process_Index)

    tw scatter nregion Process_Index, msymbol(pipe) mcolor(navy) msize(.3in) xsize(8) ylabel(1 "Sub-Saharan Africa" 2 "Middle East and North Africa" 3 "South Asia" 4 "East Asia and Pacific"  5 "Latin America & Caribbean"  6 "Europe & Central Asia" 7 "High income: OECD" ) ylab(, angle(0)) ysc(r(0.5 4.5)) xtitle("WBL score (0-100)") ytitle("") xscale(range(10 .)) || bar ccc nregion, hor barw(.6) color(blue) fintensity(5) bstyle(outline) legend(off) || scatter nregion meanbyregion, msymbol(O) mcolor(orange) msize(.4in) ml(meanbyregion) mlabp(0) mlabf(%9.1f) mlabc(navy)|| scatter nregion minbyregion, ml(minbyregion) mlabf(%9.1f) mlabc(navy) mlabp(9) msymbol(pipe) mcolor(orange) msize(.3in) || scatter nregion maxbyregion, ml(maxbyregion) mlabf(%9.1f) mlabc(navy) mlabp(0) msymbol(pipe) mcolor(orange) msize(.3in)

graph export "${output_c3}\03_Figure_3_7.png", width(2000) replace

*** Figure 3.8

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    label define incomelabel 1 "Low income" 2 "Lower middle income" 3 "Upper middle income" 4 "High income"

    encode incomegroup, gen(nincome) label(incomelabel)
    gen ccc = 100
    bysort nincome: egen meanbyincome = mean(Process_Index)
    bysort nincome: egen minbyincome  = min(Process_Index)
    bysort nincome: egen maxbyincome  = max(Process_Index)

    tw scatter nincome Process_Index, msymbol(pipe) mcolor(navy) msize(.3in) xsize(8) ylabel(1 "Low income" 2 "Lower middle income" 3 "Upper middle income" 4 "High income") ylab(, angle(0)) ysc(r(0.5 4.5)) xtitle("WBL score (0-100)") ytitle("") xscale(range(0 .)) || bar ccc nincome, hor barw(.6) color(blue) fintensity(5) bstyle(outline) legend(off) || scatter nincome meanbyincome, msymbol(O) mcolor(orange) msize(.4in) ml(meanbyincome) mlabp(0) mlabf(%9.1f) mlabc(navy)|| scatter nincome minbyincome, ml(minbyincome) mlabf(%9.1f) mlabc(navy) mlabp(9) msymbol(pipe) mcolor(orange) msize(.3in) || scatter nincome maxbyincome, ml(maxbyincome) mlabf(%9.1f) mlabc(navy) mlabp(0) msymbol(pipe) mcolor(orange) msize(.3in)

graph export "${output_c3}\03_Figure_3_8.png", width(2000) replace


*** Figure 3.9

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    summarize Process_Index, meanonly
    local sf = r(mean)
	local rounded_sf = round(`sf', 0.1)

    keep pro_mobility pro_workplace pro_pay pro_marriage pro_parenthood pro_entrprnshp pro_assets pro_pension pro_childcare pro_safety

    collapse (mean) pro_mobility pro_workplace pro_pay pro_marriage pro_parenthood pro_entrprnshp pro_assets pro_pension pro_childcare pro_safety

    label variable pro_mobility Mobility
    label variable pro_workplace Workplace
    label variable pro_pay Pay
    label variable pro_marriage Marriage
    label variable pro_parenthood Parenthood
    label variable pro_entrprnshp Entrepreneurship
    label variable pro_assets Assets
    label variable pro_pension Pension
    label variable pro_childcare Childcare
    label variable pro_safety Safety

graph bar (asis) pro_mobility pro_marriage pro_pension pro_entrprnshp pro_safety pro_parenthood pro_pay pro_childcare pro_assets pro_workplace, ///
    ascategory ///
    yline(`sf') ///
	text(45 75 "WBL 2.0 supportive frameworks scores," "global average (`rounded_sf')", place(e)) ///
    bargap(30) /// 
    bar(1, color(blue)) /// 
    blabel(bar, format(%4.1f)) /// 
    legend(off) ///
	xsize(12)

graph export "${output_c3}\03_Figure_3_9.png", width(2000) replace


*** Figure 3.10

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    * Panel A: By region
	
	* Generate sorting by gap
    gen sort = 7		if region == "Middle East & North Africa"
    replace sort = 6	if region == "South Asia"
	replace sort = 5 	if region == "High income: OECD"
    replace sort = 4 	if region == "East Asia & Pacific"
    replace sort = 3 	if region == "Europe & Central Asia"
    replace sort = 2 	if region == "Latin America & Caribbean"
    replace sort = 1 	if region == "Sub-Saharan Africa"

    graph dot Legal_Index_LegNew Process_Index, ///
		  over(region, sort(sort)) ///
		  marker(1, mcolor(blue)) marker(2, mcolor(orange)) marker(3, mcolor(green)) ///
		  plotregion(fcolor(white)) graphregion(fcolor(white)) ///
		  legend (pos(6) label(1 "WBL 2.0 Legal Frameworks score (0-100)") label(2 "WBL 2.0 Supportive Frameworks score (0-100)")) xsize(8) ///
		  name(dot1, replace)

graph export "${output_c3}\03_Figure_3_10_a.png", replace
		   
    * Panel B: By income	
	
    * Generate sorting by gap
    gen sort2 = 1		if incomegroup == "Low income"
    replace sort2 = 2	if incomegroup == "Lower middle income"
    replace sort2 = 3	if incomegroup == "Upper middle income"
    replace sort2 = 4	if incomegroup == "High income"

    drop if economy=="Venezuela, RB"
	
    graph dot Legal_Index_LegNew Process_Index, ///
		  over(income, sort(sort2)) ///		  
		  marker(1, mcolor(blue)) marker(2, mcolor(orange)) marker(3, mcolor(green)) ///
		  plotregion(fcolor(white)) graphregion(fcolor(white)) ///
		  legend(pos(6) label(1 "WBL 2.0 Legal Frameworks score (0-100)") label(2 "WBL 2.0 Supportive Frameworks score (0-100)")) xsize(8) ///
 		  name(dot2, replace)
		  
graph export "${output_c3}\03_Figure_3_10_b.png", replace

graph combine dot1 dot2, col(1) xsize(4)

graph export "${output_c3}\03_Figure_3_10.png", replace


*** Figure 3.11

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

	keep mobility_LegNew workplace_LegNew pay_LegNew marriage_LegNew parenthood_LegNew entrprnshp_LegNew assets_LegNew pension_LegNew childcare_LegNew safety_LegNew pro_mobility pro_workplace pro_pay pro_marriage pro_parenthood pro_entrprnshp pro_assets pro_pension pro_childcare pro_safety
	
	local varlist mobility_LegNew workplace_LegNew pay_LegNew marriage_LegNew parenthood_LegNew entrprnshp_LegNew assets_LegNew pension_LegNew childcare_LegNew safety_LegNew
	
	foreach var of local varlist {
		local newname = subinstr("`var'", "_", " ", .)
		local newname = word("`newname'", 2) + "_" + word("`newname'", 1)
		rename `var' `newname'
	} 

	gen id = _n
	reshape long LegNew_ pro_, i(id) j(indicator, string)
		
	replace indicator = proper(indicator)
	replace indicator = "Entrepreneurship" if indicator == "Entrprnshp"

	* Generate sorting by gap
    gen sort = 1		if indicator == "Assets"
    replace sort = 2	if indicator == "Pay"
    replace sort = 3 	if indicator == "Workplace"
    replace sort = 4 	if indicator == "Parenthood"
    replace sort = 5 	if indicator == "Pension"
    replace sort = 6 	if indicator == "Marriage"
    replace sort = 7 	if indicator == "Mobility"
	replace sort = 8	if indicator == "Childcare"
	replace sort = 9	if indicator == "Entrepreneurship"
	replace sort = 10 	if indicator == "Safety"

	graph dot LegNew_ pro_, ///
		over(indicator, label(angle(vertical)) sort(sort)) vertical ////
		marker(1, mcolor(blue)) marker(2, mcolor(orange)) ///
		plotregion(fcolor(white)) graphregion(fcolor(white)) ///
		legend(pos(6) label(1 "WBL 2.0 Legal Frameworks score (0-100)") label(2 "WBL 2.0 Supportive Frameworks score (0-100)")) xsize(8) ///
		blabel(bar, format(%4.1f)) ///
		ysize(11)
		
graph export "${output_c3}\03_Figure_3_11.png", replace



*** Map 3.3

use "$map\world.dta", clear
    merge 1:1 WB_NAME using "$data\map_wb.dta"
	drop if _merge == 2
	drop _merge     // Missing Taiwan, China
	
	summarize EO_index if FORMAL_EN == "Kingdom of Denmark"
	local denmark_eo = r(mean)
	replace EO_index = `denmark_eo' if FORMAL_EN == "Greenland"

spmap EO_index using "$map\world_shp.dta", id(_ID) fcolor(Blues) clmethod(custom) clbreaks(0 15 29 43 58 72 86 100)

graph export "${output_c3}\03_Map_3_3.png", width(2000) replace



*** Figure 3.12

use "$data\WBL2024_LEGAL_PROCESS_EOIndex_ForComparisons.dta", clear

    label define regionlabel 1 "South Asia" 2 "Sub-Saharan Africa" 3 "Latin America & Caribbean" 4 "East Asia & Pacific" 5 "Middle East & North Africa" 6 "Europe & Central Asia"  7 "High income: OECD"

    encode region, gen(nregion) label(regionlabel)
    gen ccc = 100
    bysort nregion: egen meanbyregion = mean(EO_index)
    bysort nregion: egen minbyregion  = min(EO_index)
    bysort nregion: egen maxbyregion  = max(EO_index)

    tw scatter nregion EO_index, msymbol(pipe) mcolor(navy) msize(.3in) xsize(8) ylabel(1 "Sub-Saharan Africa" 2 "Middle East and North Africa" 3 "South Asia" 4 "East Asia and Pacific"  5 "Latin America & Caribbean"  6 "Europe & Central Asia" 7 "High income: OECD" ) ylab(, angle(0)) ysc(r(0.5 4.5)) xtitle("WBL score (0-100)") ytitle("") xscale(range(10 .)) || bar ccc nregion, hor barw(.6) color(blue) fintensity(5) bstyle(outline) legend(off) || scatter nregion meanbyregion, msymbol(O) mcolor(orange) msize(.4in) ml(meanbyregion) mlabp(0) mlabf(%9.1f) mlabc(navy)|| scatter nregion minbyregion, ml(minbyregion) mlabf(%9.1f) mlabc(navy) mlabp(9) msymbol(pipe) mcolor(orange) msize(.3in) || scatter nregion maxbyregion, ml(maxbyregion) mlabf(%9.1f) mlabc(navy) mlabp(0) msymbol(pipe) mcolor(orange) msize(.3in)

graph export "${output_c3}\03_Figure_3_12.png", width(2000) replace


*** Figure 3.13

use "$data\WBL2024_LEGAL_PROCESS_EOIndex_ForComparisons.dta", clear

    label define incomelabel 1 "Low income" 2 "Lower middle income" 3 "Upper middle income" 4 "High income"

    encode incomegroup, gen(nincome) label(incomelabel)
    gen ccc = 100
    bysort nincome: egen meanbyincome = mean(EO_index)
    bysort nincome: egen minbyincome  = min(EO_index)
    bysort nincome: egen maxbyincome  = max(EO_index)

    tw scatter nincome EO_index, msymbol(pipe) mcolor(navy) msize(.3in) xsize(8) ylabel(1 "Low income" 2 "Lower middle income" 3 "Upper middle income" 4 "High income") ylab(, angle(0)) ysc(r(0.5 4.5)) xtitle("WBL score (0-100)") ytitle("") xscale(range(0 .)) || bar ccc nincome, hor barw(.6) color(blue) fintensity(5) bstyle(outline) legend(off) || scatter nincome meanbyincome, msymbol(O) mcolor(orange) msize(.4in) ml(meanbyincome) mlabp(0) mlabf(%9.1f) mlabc(navy)|| scatter nincome minbyincome, ml(minbyincome) mlabf(%9.1f) mlabc(navy) mlabp(9) msymbol(pipe) mcolor(orange) msize(.3in) || scatter nincome maxbyincome, ml(maxbyincome) mlabf(%9.1f) mlabc(navy) mlabp(0) msymbol(pipe) mcolor(orange) msize(.3in)

graph export "${output_c3}\03_Figure_3_13.png", width(2000) replace


*** Figure 3.14

use "$data\WBL2024_LEGAL_PROCESS_EOIndex_ForComparisons.dta", clear

    summarize EO_index, meanonly
    local eo = r(mean)
	local rounded_eo = round(`eo', 0.1)

    keep safety_EO mobility_EO workplace_EO pay_EO marriage_EO parenthood_EO childcare_EO entrepre_EO assets_EO pension_EO

    collapse (mean) mobility_EO workplace_EO pay_EO marriage_EO parenthood_EO childcare_EO entrepre_EO assets_EO pension_EO safety_EO
	
	replace mobility_EO = round(mobility_EO, 0.1)
	replace workplace_EO = round(workplace_EO, 0.1)
	replace pay_EO = round(pay_EO, 0.1)
	replace marriage_EO = round(marriage_EO, 0.1)
	replace parenthood_EO = round(parenthood_EO, 0.1)
	replace childcare_EO = round(childcare_EO, 0.1)
	replace entrepre_EO = round(entrepre_EO, 0.1)
	replace assets_EO = round(assets_EO, 0.1)
	replace pension_EO = round(pension_EO, 0.1)
	replace safety_EO = round(safety_EO, 0.1)

    label variable mobility_EO Mobility
    label variable workplace_EO Workplace
    label variable pay_EO Pay
    label variable marriage_EO Marriage
    label variable parenthood_EO Parenthood
    label variable entrepre_EO Entrepreneurship
    label variable assets_EO Assets
    label variable pension_EO Pension
    label variable childcare_EO Childcare
    label variable safety_EO Safety

graph bar (asis) pension_EO mobility_EO assets_EO parenthood_EO entrepre_EO marriage_EO workplace_EO pay_EO childcare_EO safety_EO, ///
    ascategory ///
    yline(`eo') ///
	text(70 75 "WBL 2.0 expert opinions scores," "global average (`rounded_eo')", place(e)) ///
    bargap(30) /// 
    bar(1, color(blue)) /// 
    blabel(bar, format(%4.1f)) /// 
    legend(off) ///
	xsize(12)

graph export "${output_c3}\03_Figure_3_14.png", width(2000) replace


*** Figure 3.15

use "$data\WBL2024_LEGAL_PROCESS_EOIndex_ForComparisons.dta", clear

    * Panel A: By region
	
	* Generate sorting by gap
    gen sort = 7		if region == "Middle East & North Africa"
    replace sort = 6 	if region == "East Asia & Pacific"
	replace sort = 5 	if region == "High income: OECD"
    replace sort = 4 	if region == "Europe & Central Asia"
    replace sort = 3 	if region == "Sub-Saharan Africa"	
    replace sort = 2	if region == "South Asia"
    replace sort = 1 	if region == "Latin America & Caribbean"

    graph dot Legal_Index_LegNew EO_index, ///
		  over(region, sort(sort)) ///
		  marker(1, mcolor(blue)) marker(2, mcolor(green)) ///
		  plotregion(fcolor(white)) graphregion(fcolor(white)) ///
		  legend (pos(6) label(1 "WBL 2.0 Legal Frameworks score (0-100)") label(2 "WBL 2.0 Supportive Frameworks score (0-100)")) xsize(8) ///
		  name(dot1, replace)

graph export "${output_c3}\03_Figure_3_15_a.png", replace
		   
    * Panel B: By income	
	
    * Generate sorting by gap
    gen sort2 = 1		if incomegroup == "Upper middle income"
    replace sort2 = 2	if incomegroup == "Low income"
    replace sort2 = 3	if incomegroup == "Lower middle income"
    replace sort2 = 4	if incomegroup == "High income"

    drop if economy=="Venezuela, RB"
	
    graph dot Legal_Index_LegNew EO_index, ///
		  over(income, sort(sort2)) ///		  
		  marker(1, mcolor(blue)) marker(2, mcolor(green)) ///
		  plotregion(fcolor(white)) graphregion(fcolor(white)) ///
		  legend(pos(6) label(1 "WBL 2.0 Legal Frameworks score (0-100)") label(2 "WBL 2.0 Supportive Frameworks score (0-100)")) xsize(8) ///
 		  name(dot2, replace)
		  
graph export "${output_c3}\03_Figure_3_15_b.png", replace

graph combine dot1 dot2, col(1) xsize(4)

graph export "${output_c3}\03_Figure_3_15.png", replace


*** Figure 3.16

use "$data\WBL2024_LEGAL_PROCESS_EOIndex_ForComparisons.dta", clear
	
	local varlist mobility_LegNew workplace_LegNew pay_LegNew marriage_LegNew parenthood_LegNew entrprnshp_LegNew assets_LegNew pension_LegNew childcare_LegNew safety_LegNew safety_EO mobility_EO workplace_EO pay_EO marriage_EO parenthood_EO childcare_EO entrepre_EO assets_EO pension_EO
	
	keep `varlist'
	
	foreach var of local varlist {
		local newname = subinstr("`var'", "_", " ", .)
		local newname = word("`newname'", 2) + "_" + word("`newname'", 1)
		rename `var' `newname'
	}
	
	rename EO_entrepre EO_Entrepreneurship
	rename LegNew_entrprnshp LegNew_Entrepreneurship
	
	gen id = _n
	reshape long LegNew_ EO_, i(id) j(indicator, string)
		
	replace indicator = proper(indicator)

	* Generate sorting by gap
    gen sort = 1		if indicator == "Pay"
    replace sort = 2	if indicator == "Marriage"
    replace sort = 3 	if indicator == "Childcare"
    replace sort = 4 	if indicator == "Mobility"
    replace sort = 5 	if indicator == "Safety"
    replace sort = 6 	if indicator == "Assets"
    replace sort = 7 	if indicator == "Workplace"
	replace sort = 8	if indicator == "Parenthood"
	replace sort = 9	if indicator == "Pension"
	replace sort = 10 	if indicator == "Entrepreneurship"


	graph dot LegNew_ EO_, ///
		over(indicator, label(angle(vertical)) sort(sort)) vertical ////
		marker(1, mcolor(blue)) marker(2, mcolor(green)) ///
		plotregion(fcolor(white)) graphregion(fcolor(white)) ///
		legend(pos(6) label(1 "WBL 2.0 Legal Frameworks score (0-100)") label(2 "WBL 2.0 Expert Opinions score (0-100)")) xsize(8) ///
		blabel(bar, position(outside) format(%4.1f)) ///
		ysize(11)
		
graph export "${output_c3}\03_Figure_3_16.png", replace


*** Figure 3.17
	* R Script

*** Figure 3.18
	* R Script


*** Figure 3.19

use "$data\WBL2024_LEGAL_PROCESS_EOIndex_ForComparisons.dta", clear

    * Panel A: By region
	
	* Generate sorting by gap
    gen sort = 1		if region == "Middle East & North Africa"
    replace sort = 2	if region == "South Asia"
    replace sort = 3 	if region == "Sub-Saharan Africa"
    replace sort = 4 	if region == "East Asia & Pacific"
    replace sort = 5 	if region == "Latin America & Caribbean"
    replace sort = 6 	if region == "Europe & Central Asia"
    replace sort = 7 	if region == "High income: OECD"
	
    graph dot Legal_Index_LegNew Process_Index EO_index, ///
		  over(region, sort(sort)) ///
		  marker(1, mcolor(blue)) marker(2, mcolor(orange)) marker(3, mcolor(green)) ///
		  plotregion(fcolor(white)) graphregion(fcolor(white)) ///
		  legend (pos(6) label(1 "WBL 2.0 Legal Frameworks score (0-100)") label(2 "WBL 2.0 Supportive Frameworks score (0-100)") label(3 "WBL 2.0 Expert Opinions Score (0-100)")) xsize(8) ///
		  name(dot1, replace)

graph export "${output_c3}\03_Figure_3_19_a.png", replace
		   
    * Panel B: By income	
	
    * Generate sorting by gap
    gen sort2 = 1		if incomegroup == "Low income"
    replace sort2 = 2	if incomegroup == "Lower middle income"
    replace sort2 = 3	if incomegroup == "Upper middle income"
    replace sort2 = 4	if incomegroup == "High income"

    drop if economy=="Venezuela, RB"
	
    graph dot Legal_Index_LegNew Process_Index EO_index, ///
		  over(income, sort(sort2)) ///		  
		  marker(1, mcolor(blue)) marker(2, mcolor(orange)) marker(3, mcolor(green)) ///
		  plotregion(fcolor(white)) graphregion(fcolor(white)) ///
		  legend(pos(6) label(1 "WBL 2.0 Legal Frameworks score (0-100)") label(2 "WBL 2.0 Supportive Frameworks score (0-100)") label(3 "WBL 2.0 Expert Opinions Score (0-100)")) xsize(8) ///
 		  name(dot2, replace)
		  
graph export "${output_c3}\03_Figure_3_19_b.png", replace

graph combine dot1 dot2, col(1) xsize(4)

graph export "${output_c3}\03_Figure_3_19.png", replace



*** Annex 3A

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    gsort -Legal_Index_old economy
    keep  economy Legal_Index_LegNew Legal_Index_old Process_Index EO_index
	order economy Legal_Index_old Legal_Index_LegNew Process_Index EO_index

export excel using "${output_c3}\03_Table_3A_1.xlsx", firstrow(variables) replace 


}


* End of do-file!	

