
* =============================================================================================== *
* =============================================================================================== *
*								WBL 2024  RRR      												  *
*			  Data Creation: LEGAL 2.0, SUPPORTIVE, LEGAL 1.0, EXPERT OPINIONS 				      *
* =============================================================================================== *
* =============================================================================================== *
/*

	Title: 		WBL2024_Report_DataCreation.do  

 	Outline: 	This .do file creates WBL Legal Frameworks 2.0, Supportive Frameworks, Legal Frameworks 1.0, Expert Opinions indicator scores and indexes  

 	Input: 		This .do file uses the following files in "/DataWork/Data/Raw" subfolder:
	            "WBL2024_RAW_Data.xlsx"
	            "WBL2024_RAW_Data_LegalFrameworks_1_0.xlsx" 
				"WBL2024_ExpertOpinion_EOLevel_ToPublish.dta"

	Output:		"WBL2024_LEGAL_PROCESS_EOIndex.xlsx"
	            "WBL2024_LEGAL_PROCESS_EOIndex.dta"
	            "WBL2024_LEGAL_PROCESS_EOIndex_ForComparisons.xlsx"
	            "WBL2024_LEGAL_PROCESS_EOIndex_ForComparisons.dta"

	Description: Variables ending with *_LegNew are for WBL Legal Frameworks 2.0 variables,
	             Variables starting with pro_* are for WBL Supportive Frameworks variables,
				 Variables ending with *_LegOld are for WBL Legal Frameworks 1.0 variables,
				 Variables ending with *_EO are for WBL Expert Opinions variables.
				 Variables for Indices:  Legal_Index_LegNew ,  Process_Index , Legal_Index_old , EO_index
	
	            
*/
* =============================================================================================== *

	clear all
	clear matrix
	set more off
	set matsize 700
	set graph on

* =============================================================================================== *
*  LEGAL FRAMEWORKS 2.0 INDEX
* =============================================================================================== *

    {  				
	import excel using "${raw}/WBL2024_RAW_Data.xlsx" , firstrow clear  

	rename   APN           WBL_dvLawSexHarWorkPCriPeCivRe    
	
	tab1     WBL_dv_LawAgeMarriageBoys WBL_dv_LawAgeMarriageGirls , m
	destring WBL_dv_LawAgeMarriageBoys WBL_dv_LawAgeMarriageGirls, replace force
	
	tab1     WBL_dv_LawMinAgeMarriageBoys WBL_dv_LawMinAgeMarriageGirls , m	
	replace  WBL_dv_LawMinAgeMarriageBoys=""  if WBL_dv_LawMinAgeMarriageBoys=="N/A"
	replace  WBL_dv_LawMinAgeMarriageGirls="" if WBL_dv_LawMinAgeMarriageGirls=="N/A"
	destring WBL_dv_LawMinAgeMarriageBoys WBL_dv_LawMinAgeMarriageGirls, replace force

	

	** Mobility
	    gen mobility1 = (Fam_CM_Passport_legal == "Yes" & Fam_CM_TravelAbroad == "Yes")
	    gen mobility2 = (Fam_CM_ChooseMaritalHome == "Yes")
	    gen mobility3 = (Fam_CM_LeaveMaritalHome == "Yes")
	    gen mobility4 = (Fam_CM_Nationality_Child == "Yes" & Fam_CM_Nationality_Husb == "Yes")
		    tab1 mobility*, m
			
	** Workplace	
	    gen workplace1 = (Fam_CM_GetJob == "Yes")
	    gen workplace2 = (NonDiscriminEmployment == "Yes")
	    gen workplace3 = (NonDiscrim_Recruit == "Yes")
	    gen workplace4 = (Option_Flex == "Yes")		
		    tab1 workplace*, m
	** Pay
	    gen pay1 = (EqualRemunEqualValue == "Yes")
	    gen pay2 = (NightHours == "Yes")
	    gen pay3 = (Industriesscored == "Yes")
	    gen pay4 = (Hazardousetcscored == "Yes")		
		    tab1 pay*, m
			
	** Marriage
	    gen marriage1 = (Fam_CM_HOH == "Yes")
	    gen marriage2 = (Fam_MR_Obedience == "Yes")
	    gen marriage3 = (Fam_R2D_ObtainDivorce == "Yes")
	    gen marriage4 = (Fam_R2D_Remarry == "Yes")		
	        tab1 marriage*, m 
			
	** Parenthood
	    gen parenthood1 = (Leavewomendaysscored == "Yes")
	    gen parenthood2 = (Maternitybenefitsscored == "Yes")
	    gen parenthood3 = (Paternityscored == "Yes")
	    gen parenthood4 = (DismissalPregnantWomen == "Yes")		
	        tab1 parenthood* , m
			
	** Entrepreneurship
	    gen entrepre1 = (Fam_CM_SignContract == "Yes" & Fam_CM_RegisterBiz == "Yes" & Fam_CM_OpenBankAccount == "Yes")
	    gen entrepre2 = (Fam_A2F_Gender == "Yes")
	    gen entrepre3 = (Fam_A2F_quota == "Yes")		
	    gen entrepre4 = (Fam_A2F_genderprocur == "Yes")
		    tab1 entrepre* , m 
			
	** Assets
	    gen assets1 = (Fam_AM_PropertyAdministration_fo == "Yes" & Fam_AM_RightsImmovables == "Yes" & Fam_AM_adminland == "Yes")
	    gen assets2 = (Fam_AM_InheritanceChildren == "Yes")
	    gen assets3 = (Fam_AM_InheritanceSpouses == "Yes")
	    gen assets4 = (Fam_AM_NonmonetaryContributions == "Yes")
		    tab1 assets* , m 
			
	** Pension
	    gen pension1 = (Agesfullbenefitsscored == "Yes")
	    gen pension2 = (Agespartialbenefitsscored == "Yes")
	    gen pension3 = (Agesmandatoryretirementscored == "Yes")
	    gen pension4 = (Pensioncarecredit == "Yes")		
            tab1 pension* , m

	** Childcare
	tab1 PublicChildcare PrivateChildcare , m
	tab  EmployerProvidedChildcare EmployerProvidedFemale, m 
	
		gen childcare1 = (PublicChildcare    == "Yes" | PrivateChildcare      == "Yes" | (EmployerProvidedChildcare == "Yes"  & EmployerProvidedFemale == "No"))
	    gen childcare2 = (SupportParentsTax  == "Yes" | SupportParentsNonTax  == "Yes")
	    gen childcare3 = (SupportEmployerTax == "Yes" | SupportEmployerNonTax == "Yes" | SupportCentersTax== "Yes" | SupportCentersNonTax == "Yes")
	    gen childcare4 = (Workforce == "Yes" & (MaxGroupSize == "Yes" | CaregivertoChildRatio == "Yes" ) & (PeriodicInspection == "Yes" | PeriodicReport == "Yes" ))			
		    tab1 childcare* , m  
			
	** Safety: 	    		  
	tab1 WBL_dv_LawDomVioPhysAbuse WBL_dv_LawDomVioSexAbuse WBL_dv_LawDomVioPsycEmoAbuse WBL_dv_LawDomVioFinEconAbuse WBL_dv_LawDomVioCrimPenalties   WBL_dv_ProtOrderDomVio WBL_dv_LawMaritalRapeGenLaw WBL_dv_LawMaritalRapeCrime, m
		
		gen safety1 = (WBL_dv_LawDomVioPhysAbuse     == "Yes") &  ///
		              (WBL_dv_LawDomVioSexAbuse      == "Yes") &  ///
		              (WBL_dv_LawDomVioPsycEmoAbuse  == "Yes") &  ///
					  (WBL_dv_LawDomVioFinEconAbuse  == "Yes") &  ///
					  (WBL_dv_LawDomVioCrimPenalties == "Yes" | WBL_dv_ProtOrderDomVio      == "Yes") & ///
					  (WBL_dv_LawMaritalRapeCrime    == "Yes" | WBL_dv_LawMaritalRapeGenLaw == "Yes")
		
		gen safety2 = (WBL_Law_Femicide == "Yes")
	
		    gen WorkPlace_num = ((WBL_dv_LawSexHarWorkPlace == "Yes" &  WBL_dvLawSexHarWorkPCriPeCivRe == "Yes"))
	        gen EduFac_num    = ((WBL_dv_LawSexHarEduFac    == "Yes" & (WBL_dv_LawSexHarEduFacCrimPen  == "Yes" | WBL_dv_LawSexHarEduFacCivRem   == "Yes")))
	        gen PubSpace_num  = ((WBL_dv_LawSexHarPubSpace  == "Yes" & (WBL_dv_LawSexHarPubSpaceCrimPe == "Yes" | WBL_dv_LawSexHarPubSpaceCivRem == "Yes")))
			gen CyberHar_num  = ((WBL_dv_LawCyberHarStalking== "Yes" & (WBL_dv_LawCyberHarStalking_crim== "Yes" | WBL_dv_LawCyberHarStalking_civ == "Yes")))
	        egen safety3_temp = rowtotal(WorkPlace_num EduFac_num PubSpace_num CyberHar_num)
        gen safety3 = (safety3_temp>=2)


	    gen safety4 = ((WBL_dv_LawAgeMarriageBoys  >= 18)  & (WBL_dv_LawAgeMarriageBoys  != .)) & ///
		              ((WBL_dv_LawAgeMarriageGirls >= 18)  & (WBL_dv_LawAgeMarriageGirls != .)) & /// 
					  (WBL_dv_LawChildMarriageVoid== "Yes" &  WBL_dv_LawChildMarriagePenaltie== "Yes") & ///
					  (WBL_dv_LawMinAgeMarriageBoys==.     | WBL_dv_LawMinAgeMarriageBoys>=18)  & ///
					  (WBL_dv_LawMinAgeMarriageGirls==.    | WBL_dv_LawMinAgeMarriageGirls>=18) 
		   tab1 safety* , m 
		   
	** Create Indicator Scores and Index:
	
        gen mobility    = 100*(mobility1   + mobility2   + mobility3   + mobility4)/4 
        gen workplace   = 100*(workplace1  + workplace2  + workplace3  + workplace4)/4 
        gen pay         = 100*(pay1        + pay2        + pay3        + pay4)/4 	
        gen marriage    = 100*(marriage1   + marriage2   + marriage3   + marriage4)/4
        gen parenthood  = 100*(parenthood1 + parenthood2 + parenthood3 + parenthood4)/4 		
        gen entrprnshp  = 100*(entrepre1   + entrepre2   + entrepre3   + entrepre4)/4 		
        gen assets      = 100*(assets1     + assets2     + assets3     + assets4)/4 		
        gen pension     = 100*(pension1    + pension2    + pension3    + pension4)/4 				
        gen childcare   = 100*(childcare1  + childcare2  + childcare3  + childcare4)/4 		
        gen safety      = 100*(safety1     + safety2     + safety3     + safety4)/4 		
		
		egen Legal_Index = rowmean(mobility workplace pay marriage parenthood entrprnshp assets pension childcare safety)  
		  
	** Label Indicator Variables: 
	
        la var mobility     "MOBILITY (LegalNew)"
	    la var mobility1    "Can a woman travel internationally in the same way as a man?"
	    la var mobility2    "Can a woman choose where to live in the same way as a man?"
	    la var mobility3    "Can a woman travel outside her home in the same way as a man?"
	    la var mobility4    "Do women and men have equal rights to confer citizenship to their spouses and their children?"
	    la var workplace    "WORKPLACE (LegalNew)"		
	    la var workplace1   "Can a woman get a job in the same way as a man?"
	    la var workplace2   "Does the law prohibit discrimination in employment based on gender?"
	    la var workplace3   "Does the law prohibit discrimination in recruitment based on marital status, parental status, or age?"
	    la var workplace4   "Does the law allow employees to request flexible work?"
	    la var pay          "PAY (LegalNew)"
	    la var pay1         "Does the law mandate equal remuneration for work of equal value?"
	    la var pay2         "Can a woman work at night in the same way as a man?"
	    la var pay3         "Can a woman work in an industrial job in the same way as a man?"
     	la var pay4         "Can a woman work in a job deemed dangerous in the same way as a man?"
	    la var marriage     "MARRIAGE (LegalNew)"	
	    la var marriage1    "Can a woman be head of household or head of family in the same way as a man? "
	    la var marriage2    "Is the law free of legal provisions that require a married woman to obey her husband?"
	    la var marriage3    "Can a woman obtain a judgment of divorce in the same way as a man?"
	    la var marriage4    "Does a woman have the same rights to remarry as a man?"
	    la var parenthood   "PARENTHOOD (LegalNew)"
	    la var parenthood1  "Is paid leave of at least 14 weeks available to mothers?"
	    la var parenthood2  "Are leave benefits for mothers paid solely by the government?"
	    la var parenthood3  "Is there paid leave available to fathers?"
	    la var parenthood4  "Is dismissal of pregnant workers prohibited?"
	    la var entrprnshp   "ENTREPRENEURSHIP (LegalNew)"
	    la var entrepre1    "Can a woman undertake entrepreneurial activities in the same way as a man?"
	    la var entrepre2    "Does the law prohibit discrimination in access to credit based on gender?"
		la var entrepre3    "Does the law prescribe a gender quota on corporate boards?"
	    la var entrepre4    "Does the law include gender-sensitive procurement provisions for public procurement processes?"
	    la var assets       "ASSETS (LegalNew)"
	    la var assets1      "Do men and women have equal administrative power and ownership rights to immovable property, including land?"
	    la var assets2      "Do sons and daughters have equal rights to inherit assets from their parents?"
	    la var assets3      "Do male and female surviving spouses have equal rights to inherit assets?"
	    la var assets4      "Does the law provide for the valuation of nonmonetary contributions?"
	    la var pension      "PENSION (LegalNew)"
	    la var pension1     "Are the ages at which men and women can retire with full pension benefits equal?"
	    la var pension2     "Are the ages at which men and women can retire with partial pension benefits equal?"
	    la var pension3     "Is the mandatory retirement age for men and women equal?"
	    la var pension4     "Are periods of absence due to childcare accounted for in pension benefits?"
	    la var childcare    "CHILDCARE (LegalNew)"
	    la var childcare1   "Does the law establish childcare services in center-based settings?"
	    la var childcare2   "Does the law establish any form of support to parents for childcare services?"
	    la var childcare3   "Does the law establish any form of support to non-state childcare providers?"
	    la var childcare4   "Does the law establish quality standards for the provision of childcare services in center-based settings?"
	    la var safety       "SAFETY (LegalNew)"
	    la var safety1      "Is there legislation on domestic violence?"
	    la var safety2      "Is there legislation on femicide?"
	    la var safety3      "Is there comprehensive legislation on sexual harassment?"
	    la var safety4      "Is there legislation on child marriage?"
	    la var Legal_Index  "WBL 2024 Legal Index (new)"

	** Label questions:
	
		  la var Fam_CM_Passport_legal     "Can a woman apply for a passport in the same way as a man?"
		  la var Fam_CM_TravelAbroad       "Can a woman travel outside the country in the same way as a man?"
		  la var Fam_CM_LeaveMaritalHome   "Can a woman travel outside her home in the same way as a man?"
		  la var Fam_CM_ChooseMaritalHome  "Can a woman choose where to live in the same way as a man?"
		  la var Fam_CM_Nationality_Child  "Do women have the same legal rights as men to confer their nationality to their children?"
		  la var Fam_CM_Nationality_Husb   "Do women have the same legal rights as men to confer their nationality to their husband?"
		  
		  la var Fam_CM_GetJob             "Can a woman get a job in the same way as a man?"
		  la var NonDiscriminEmployment    "Does the law prohibit discrimination in employment based on gender?"
		  la var NonDiscrim_Recruit        "Does the law specifically prohibit discrimination based on gender in recruitment?"
		  la var Option_Flex               "Does the law give employees the right to request flexible work?"
		  
		  la var EqualRemunEqualValue      "Does the law mandate equal remuneration for men and women who perform work of equal value?"
		  la var NightHours                "Can a woman work at night in the same way as a man?"
		  la var Industriesscored          "Can a woman work in an industrial job in the same way as a man?"
		  la var Hazardousetcscored        "Can a woman work in a job deemed dangerous in the same way as a man?"
		  
		  la var Fam_CM_HOH                "Can a woman be head of household in the same way as a man?"		  
		  la var Fam_MR_Obedience          "Is a married woman required to obey her husband?"           // Check	 
		  la var Fam_R2D_ObtainDivorce     "Can a woman obtain a judgment of divorce in the same way as a man?"
		  la var Fam_R2D_Remarry           "Does a woman have the same rights to remarry as a man?"
		  
		  la var Leavewomendaysscored      "Is paid leave of at least 14 weeks available to mothers?"
		  la var Maternitybenefitsscored   "Does the government administer 100% of maternity leave benefits?"
		  la var Paternityscored           "Is paid leave available to fathers?"
		  la var DismissalPregnantWomen    "Does the law explicitly prohibit the dismissal of pregnant workers?"
		  
		  la var Fam_CM_SignContract       "Can a woman sign a contract in the same way as a man?"
		  la var Fam_CM_RegisterBiz        "Can a woman register a business in the same way as a man?"
		  la var Fam_CM_OpenBankAccount    "Can a woman open a bank account in the same way as a man?"
		  la var Fam_A2F_Gender            "Does the law prohibit discrimination in access to credit based on gender?"
		  la var Fam_A2F_quota             "Does the law prescribe a gender quota on corporate boards?"
		  la var Fam_A2F_genderprocur      "Does the law include a gender-responsive approach to public procurement?"
		  
		  la var Fam_AM_PropertyAdministration_fo "Does the law grant spouses equal administrative authority over"   
		  la var Fam_AM_RightsImmovables          "Do men and women have equal ownership rights to immovable property?"      
		  la var Fam_AM_adminland                 "Can a woman own and administer land in the same way as men?" 
		  la var Fam_AM_InheritanceChildren       "Do sons and daughters have equal rights to inherit assets from their parents?"   
		  la var Fam_AM_InheritanceSpouses        "Do male and female surviving spouses have equal rights to inherit assets?"
		  la var Fam_AM_NonmonetaryContributions  "Does the law provide for the valuation of nonmonetary contributions?"

		  la var Agesfullbenefitsscored         "Is the age at which men and women can retire with full pension benefits the same?"
		  la var Agespartialbenefitsscored      "Is the age at which men and women can retire with partial pension benefits the same?"
		  la var Agesmandatoryretirementscored  "Is the mandatory retirement age for men and women the same?"
		  la var Pensioncarecredit              "Are periods of absence due to childcare accounted for in pension benefits?"
		  
		  la var PublicChildcare                "Is the age at which men and women can retire with full pension benefits the same?"
		  la var PrivateChildcare               "Is the age at which men and women can retire with partial pension benefits the same?"
		  la var EmployerProvidedChildcare      "Is the mandatory retirement age for men and women the same?"
		  la var EmployerProvidedFemale         "Are periods of absence due to childcare accounted for in pension benefits?"
		  la var SupportParentsTax              "Does the law establish tax support to families for using childcare services?"
		  la var SupportParentsNonTax           "Does the law establish financial support to families for using childcare services?"
		  la var SupportEmployerTax             "Does the law establish tax support to employers for providing childcare services?"
		  la var SupportEmployerNonTax          "Does the law establish financial support to employers for providing childcare services?"
		  la var SupportCentersTax              "Does the law establish tax support to private centers for providing childcare services?"
		  la var SupportCentersNonTax           "Does the law establish financial support to private centers for providing childcare services?"
		  la var Workforce                      "Does the law set requirements on workforce quality at childcare centers (public or private)?"
		  la var MaxGroupSize                   "Does the law set maximum group size in childcare centers (public or private)?"
		  la var CaregivertoChildRatio          "Does the law set caregiver-to-child ratio in childcare centers (public or private)?"
		  la var PeriodicInspection             "Is there a mandatory periodic inspection of childcare centers (public or private) by authorized bodies?"
		  la var PeriodicReport                 "Is there a mandatory periodic reporting by childcare centers (public or private) to authorized bodies?"
	
	      la var WBL_dv_LawDomViolence          "Is there legislation on domestic violence?"
	      la var WBL_dv_LawDomVioPhysAbuse      "Does legislation on domestic violence include: Physical violence?"
	      la var WBL_dv_LawDomVioSexAbuse       "Does legislation on domestic violence include: Sexual violence?"
	      la var WBL_dv_LawDomVioPsycEmoAbuse   "Does legislation on domestic violence include: Psychological/emotional violence?"
	      la var WBL_dv_LawDomVioFinEconAbuse   "Does legislation on domestic violence include: Financial/economic violence?"
	      la var WBL_dv_LawDomVioCrimPenalties  "Does the legislation establish clear criminal penalties for domestic violence?"
	      la var WBL_dv_ProtOrderDomVio         "Can a victim of domestic violence obtain a protection order?"
	      la var WBL_dv_LawMaritalRapeCrime     "Is there a specific law or provision that explicitly criminalizes marital rape without qualifications?"
	      la var WBL_dv_LawMaritalRapeGenLaw    "Is a woman legally entitled to file a complaint against her husband or partner under criminal law for rape or sexual assault?"
	      la var WBL_Law_Femicide               "Is there legislation that specifically addresses femicide?"
	      la var WBL_dv_LawSexHarWorkPlace      "Is there legislation that specifically addresses sexual harassment in employment/workplaces?"
	      la var WBL_dvLawSexHarWorkPCriPeCivRe "Are there criminal penalties or civil remedies for sexual harassment in employment?"
	      la var WBL_dv_LawSexHarEduFac         "Is there legislation on: Sexual harassment in education/schools?"
	      la var WBL_dv_LawSexHarEduFacCrimPen  "Does it establish: Criminal penalties for sexual harassment in education?"
	      la var WBL_dv_LawSexHarEduFacCivRem   "Does it establish: Civil remedies for sexual harassment in education?"
	      la var WBL_dv_LawSexHarPubSpace       "Is there legislation on: Sexual harassment in public spaces (including on transportation)?"
	      la var WBL_dv_LawSexHarPubSpaceCrimPe "Does it establish: Criminal penalties for sexual harassment in public spaces (including on transportation)?"
	      la var WBL_dv_LawSexHarPubSpaceCivRem "Does it establish: Civil remedies for sexual harassment in public spaces (including on transportation)?"
	      la var WBL_dv_LawCyberHarStalking      "Is there legislation on: Cyber harassment or cyber stalking?"
	      la var WBL_dv_LawCyberHarStalking_crim "Does it establish: Criminal penalties for Cyber harassment or cyber stalking?"
	      la var WBL_dv_LawCyberHarStalking_civ  "Does it establish: Civil remedies for Cyber harassment or cyber stalking?"				
	      la var WBL_dv_LawAgeMarriageBoys       "What is the legal age of marriage for: Boys?"
	      la var WBL_dv_LawAgeMarriageGirls      "What is the legal age of marriage for: Girls?"
	      la var WBL_dv_LawChildMarriageVoid     "Is marriage under the legal age void or voidable?"
	      la var WBL_dv_LawChildMarriagePenaltie "Are there penalties for authorizing or entering into child or early marriage?"

			  
	local legal_ScoreList  Legal_Index mobility workplace pay marriage parenthood entrprnshp assets pension childcare safety ///
		  mobility1 mobility2 mobility3 mobility4 workplace1 workplace2 workplace3 workplace4 ///
          pay1 pay2 pay3 pay4 marriage1 marriage2 marriage3 marriage4  ///
		  parenthood1 parenthood2 parenthood3 parenthood4  entrepre1 entrepre2 entrepre3 entrepre4 ///
		  assets1 assets2 assets3 assets4  pension1 pension2 pension3 pension4 ///		  
		  childcare1 childcare2 childcare3 childcare4  safety1 safety2 safety3 safety4 
		  
	local legal_DPlist  Fam_CM_Passport_legal Fam_CM_TravelAbroad Fam_CM_ChooseMaritalHome Fam_CM_LeaveMaritalHome Fam_CM_Nationality_Child  Fam_CM_Nationality_Husb ///
	      Fam_CM_GetJob NonDiscriminEmployment NonDiscrim_Recruit Option_Flex 		///
		  EqualRemunEqualValue  NightHours Industriesscored  Hazardousetcscored	///
		  Fam_CM_HOH  Fam_MR_Obedience Fam_R2D_ObtainDivorce Fam_R2D_Remarry ///
		  Leavewomendaysscored Maternitybenefitsscored Paternityscored  DismissalPregnantWomen ///
		  Fam_CM_SignContract Fam_CM_RegisterBiz Fam_CM_OpenBankAccount Fam_A2F_Gender Fam_A2F_quota Fam_A2F_genderprocur ///
		  Fam_AM_PropertyAdministration_fo Fam_AM_RightsImmovables Fam_AM_adminland Fam_AM_InheritanceChildren Fam_AM_InheritanceSpouses Fam_AM_NonmonetaryContributions ///
		  Agesfullbenefitsscored  Agespartialbenefitsscored  Agesmandatoryretirementscored  Pensioncarecredit 		///
		  PublicChildcare  PrivateChildcare EmployerProvidedChildcare EmployerProvidedFemale SupportParentsTax SupportParentsNonTax ///
		  SupportEmployerTax SupportEmployerNonTax SupportCentersTax SupportCentersNonTax Workforce MaxGroupSize CaregivertoChildRatio PeriodicInspection PeriodicReport 	///
		  WBL_dv_LawDomViolence WBL_dv_LawDomVioPhysAbuse WBL_dv_LawDomVioSexAbuse WBL_dv_LawDomVioPsycEmoAbuse WBL_dv_LawDomVioFinEconAbuse WBL_dv_LawDomVioCrimPenalties WBL_dv_ProtOrderDomVio ///
		  WBL_dv_LawMaritalRapeCrime WBL_dv_LawMaritalRapeGenLaw WBL_Law_Femicide WBL_dv_LawSexHarWorkPlace WBL_dvLawSexHarWorkPCriPeCivRe  ///
		  WBL_dv_LawSexHarEduFac    WBL_dv_LawSexHarEduFacCrimPen  WBL_dv_LawSexHarEduFacCivRem  ///
		  WBL_dv_LawSexHarPubSpace  WBL_dv_LawSexHarPubSpaceCrimPe WBL_dv_LawSexHarPubSpaceCivRem ///
		  WBL_dv_LawCyberHarStalking WBL_dv_LawCyberHarStalking_crim WBL_dv_LawCyberHarStalking_civ  ///
		  WBL_dv_LawAgeMarriageBoys WBL_dv_LawAgeMarriageBoys WBL_dv_LawAgeMarriageGirls WBL_dv_LawAgeMarriageGirls WBL_dv_LawChildMarriageVoid  WBL_dv_LawChildMarriagePenaltie
		  
    tab1  `legal_ScoreList' `legal_DPlist' , m
	
    order economy economycode region incomegroup `legal_ScoreList' `legal_DPlist'

	foreach var in `legal_ScoreList'  {
	    rename `var' `var'_LegNew	
		}
			  	
    keep economy-safety4_LegNew
	
	tempfile LegalNew
	save `LegalNew', replace 
	
	}
	 

* =============================================================================================== *
* SUPPORTIVE FRAMEWORKS INDEX 
* =============================================================================================== *	
	
	{
	import excel using "${raw}/WBL2024_RAW_Data.xlsx" , firstrow clear  

	rename   ASD           VAW_Process_SHEmployment_Proto    
	destring WBL_dv_LawAgeMarriageBoys WBL_dv_LawAgeMarriageGirls, replace force
	    
		
    ** Mobility:  
	    gen pro_mobility1 = (Fam_Impl_CM_Passport_Procedure == "Yes")
	    gen pro_mobility2 = (Fam_Impl_CM_ID_Procedure == "Yes")
	    gen pro_mobility3 = (Fam_Impl_CM_Urban_Transp_Policy == "Yes")
			
	** Workplace:	
	    gen pro_workplace1 = (Lab_Impl_Work_Recruit == "Yes")
	    gen pro_workplace2 = (Lab_Impl_Work_Flexguide == "Yes")
	    gen pro_workplace3 = (Lab_Impl_Work_Complaints == "Yes")
				
	** Pay:  	
	    gen pro_pay1 = (Lab_Impl_Pay_Measure == "Yes" | Lab_Impl_Pay_Enforce == "Yes")
	    gen pro_pay2 = (Lab_Impl_Pay_Industries == "Yes")
			
	** Marriage:  
	    gen pro_marriage1 = (Fam_Impl_R2D_Fast_Track == "Yes")
	    gen pro_marriage2 = (Fam_Impl_R2D_Fam_Courts == "Yes")
	    gen pro_marriage3 = (Fam_Impl_R2D_Legal_Aid == "Yes")
			
	** Parenthood:

	tab Lab_Impl_Fam_Care_Scored , m   
    tab economy if Lab_Impl_Fam_Care_Scored == "No " | Lab_Impl_Fam_Care_Scored == "Yes " | Lab_Impl_Fam_Care_Scored == "" | Lab_Impl_Fam_Care_Scored == "0"

	    gen pro_parenthood1 = (Lab_Impl_Fam_Application == "Yes")
	    gen pro_parenthood2 = (Lab_Impl_Fam_Incentives == "Yes")
	    gen pro_parenthood3 = (Lab_Impl_Fam_Care_Scored == "Yes" | Lab_Impl_Fam_Care_Scored == "Yes ")		
				 
	** Entrepreneurship: 
	
	tab1 Fam_Impl_A2F_Data_Entrep_WSME , m  
	tab1 Fam_Impl_A2F_Programs_BizDep  , m  
	
	    gen pro_entrepre1 = (Fam_Impl_A2F_Data_Entrep_WSME == "Yes" & Fam_Impl_A2F_Data_Entrep == "Yes")
	    gen pro_entrepre2 = (Fam_Impl_A2F_Programs == "Yes"  & Fam_Impl_A2F_Programs_Fin == "Yes" & (Fam_Impl_A2F_Programs_Training == "Yes" | Fam_Impl_A2F_Programs_BizDep == "Yes" ))
	    gen pro_entrepre3 = (Fam_A2F_FIStrategy == "Yes")		
					 
	** Assets:  
	    gen pro_assets1 = (Fam_Impl_AM_Policies_Register == "Yes"| Fam_AM_jointtitle== "Yes")
	    gen pro_assets2 = (Fam_Impl_AM_Aware_Rights == "Yes")
	    gen pro_assets3 = (Fam_Impl_AM_Data_Propown == "Yes")
				
	** Pension: 			
	    gen pro_pension1 = (Lab_Impl_Pension_Incentives == "Yes")
	    gen pro_pension2 = (Lab_Impl_Pension_Procedure == "Yes")
	
	** Childcare:
	    gen pro_childcare1 = (ChildcareRegistry == "Yes")
	    gen pro_childcare2 = (ProcedureParentsNonTax == "Yes")
	    gen pro_childcare3 = (ProcedureCentersNonTax == "Yes"  | ProcedureEmployerNonTax == "Yes")
	    gen pro_childcare4 = (GovernmentQualityReports == "Yes")
			
	** Safety: 	                
	        gen  CM_Policy_num          = (VAW_Process_CM_Policy=="Yes")
			gen  EmpProto_PubPolicy_num = (VAW_Process_SHEmployment_Proto=="Yes" | VAW_Process_SHPublicS_Policy=="Yes")
		    gen  Services_num           = (VAW_Process_VAW_Services=="Yes")
	        gen  Femicide_Training_num  = (VAW_Process_Femicide_Training=="Yes")
	        egen pro_safety1_temp       = rowtotal(CM_Policy_num EmpProto_PubPolicy_num Services_num Femicide_Training_num)
        gen pro_safety1      = (pro_safety1_temp>=2)
	
	        gen SHEmployment_Procedu_num = (VAW_Process_SHEmployment_Procedu=="Yes")
	        gen SHEducation_Procedur_num = (VAW_Process_SHEducation_Procedur=="Yes")
	        gen CyberHar_Procedure_num   = (VAW_Process_CyberHar_Procedure=="Yes") 
	        egen pro_safety2_temp    = rowtotal(SHEmployment_Procedu_num SHEducation_Procedur_num CyberHar_Procedure_num)
        gen pro_safety2 = (pro_safety2_temp>=2)		
	    gen pro_safety3 = (VAW_Process_Entity_MonitoringEva == "Yes")
	    gen pro_safety4 = (VAW_Process_Budget == "Yes")

			drop  pro_safety1_temp pro_safety2_temp
			

	** Create Indicator Scores and Index:

        gen pro_mobility   = 100*(pro_mobility1   + pro_mobility2   + pro_mobility3)/3
        gen pro_workplace  = 100*(pro_workplace1  + pro_workplace2  + pro_workplace3)/3
        gen pro_pay        = 100*(pro_pay1        + pro_pay2)/2
		gen pro_marriage   = 100*(pro_marriage1   + pro_marriage2   + pro_marriage3)/3 	
        gen pro_parenthood = 100*(pro_parenthood1 + pro_parenthood2 + pro_parenthood3)/3
        gen pro_entrprnshp = 100*(pro_entrepre1   + pro_entrepre2   + pro_entrepre3)/3	
        gen pro_assets     = 100*(pro_assets1     + pro_assets2     + pro_assets3)/3	
        gen pro_pension    = 100*(pro_pension1    + pro_pension2 )/2
        gen pro_childcare  = 100*(pro_childcare1  + pro_childcare2  + pro_childcare3 + pro_childcare4)/4 	
        gen pro_safety     = 100*(pro_safety1     + pro_safety2     + pro_safety3    + pro_safety4)/4 	

		egen Process_Index = rowmean(pro_mobility pro_workplace pro_pay pro_marriage pro_parenthood pro_entrprnshp pro_assets pro_pension pro_childcare pro_safety)   

		
	** Label Indicator Variables: 
	
	la var pro_mobility1    "Are passport application processes the same for women and men?"
	la var pro_mobility2    "Are the application processes for official identity documents the same for women and men?"
	la var pro_mobility3    "Is there a current policy or plan that explicitly considers the specific mobility needs of women in public transportation?"
	la var pro_mobility     "MOBILITY (process)"
	la var pro_workplace1   "Has the government published guidelines on non-discrimination in recruitment?"
	la var pro_workplace2   "Has the government published guidelines on flexible work arrangements?"
	la var pro_workplace3   "Is there a specialized body that receives complaints about gender discrimination? "
	la var pro_workplace    "WORKPLACE (process)"		
	la var pro_pay1         "Are there pay transparency measures in place to address the pay gap?"
	la var pro_pay2         "Is sex-disaggregated data on employment in different industries/sectors published on a regular basis? "
	la var pro_pay          "PAY (process)"
	la var pro_marriage1    "Is there a fast-track process or procedure for family law disputes?"
	la var pro_marriage2    "Are there specialized family courts?"
	la var pro_marriage3    "Is legal aid available for family law disputes?"
	la var pro_marriage     "MARRIAGE (process)"	
	la var pro_parenthood1  "Is it possible to apply for maternity benefits through a single government application process?"
	la var pro_parenthood2  "Are incentives in place to encourage fathers to take paternity leave on the birth of a child ? "
	la var pro_parenthood3  "Has sex-disaggregated data on unpaid care work been published within the past five years?"
	la var pro_parenthood   "PARENTHOOD (process)"
	la var pro_entrepre1    "Is sex-disaggregated data on business activities and entrepreneurship published on a regular basis?"
	la var pro_entrepre2    "Are there government-led programs that provide support to female entrepreneurs?"
	la var pro_entrepre3    "Is there a current national government plan or strategy with a focus on women's access to financial services? "
	la var pro_entrprnshp   "ENTREPRENEURSHIP (process)"
	la var pro_assets1      "Are there policies to encourage women to register immovable property?"
	la var pro_assets2      "Are there awareness measures in place to improve women's access to information about marital and inheritance rights?"
	la var pro_assets3      "Is anonymized sex-disaggregated data on property ownership published on a regular basis?"
	la var pro_assets       "ASSETS (process)"
	la var pro_pension1     "Are there incentives in place to increase women's retirement benefits?"
	la var pro_pension2     "Is there a procedure in place for pension beneficiaries to challenge the decisions of the competent authority regarding their benefits? "
	la var pro_pension      "PENSION (process)"
	la var pro_childcare1   "Is there a publicly available registry or database of childcare providers?"
	la var pro_childcare2   "Is there a clearly outlined application procedure to request financial support from the government for childcare services by parents?"
	la var pro_childcare3   "Is there a clearly outlines application procedure to request financial support by non-state childcare providers?"
	la var pro_childcare4   "Does the government publish regular reports on quaity of childcare services?"
	la var pro_childcare    "CHILDCARE (process)"
	la var pro_safety1      "Has the government developed comprehensive mechanisms to address violence against women?"
	la var pro_safety2      "Is there a special procedure in cases of var. forms of harassment?"
	la var pro_safety3      "Is there a government entity responsible for the monitoring and implementation of national services, plans and programs addressing violence against women?"
	la var pro_safety4      "Is there an annual budgetary allocation towards violence against women risk mitigation, prevention and response programs?"
	la var pro_safety       "SAFETY (process)"
	la var Process_Index    "WBL 2024 Process Index"

	** Label questions:	

	la var  Fam_Impl_CM_Passport_Procedure  "Are passport application processes the same for women and men?"
	la var 	Fam_Impl_CM_ID_Procedure        "Are the application processes for official identity documents the same for women and men?"
	la var 	Fam_Impl_CM_Urban_Transp_Policy "Is there a current policy or plan that explicitly considers the specific mobility needs of women in public transportation?"
	la var 	Lab_Impl_Work_Recruit           "Has the government published guidelines on non-discrimination in recruitment?"
	la var 	Lab_Impl_Work_Flexguide         "Has the government published guidelines on flexible work arrangements?"
	la var 	Lab_Impl_Work_Complaints        "Is there a specialized body that receives complaints about gender discrimination? "
	la var 	Lab_Impl_Pay_Measure            "Are there pay transparency measures in place to address the pay gap?"
	la var 	Lab_Impl_Pay_Industries         "Is sex-disaggregated data on employment in different industries/sectors published on a regular basis? "
	la var 	Fam_Impl_R2D_Fast_Track         "Is there a fast-track process or procedure for family law disputes?"
	la var 	Fam_Impl_R2D_Fam_Courts         "Are there specialized family courts?"
	la var 	Fam_Impl_R2D_Legal_Aid          "Is legal aid available for family law disputes?"
	la var 	Lab_Impl_Fam_Mompctgpay         "Are at least 2/3 of wages paid during the minimum maternity leave period of 14 weeks?"
	la var 	Lab_Impl_Fam_Application        "Is it possible to apply for maternity benefits through a single government application process?"
	la var 	Lab_Impl_Fam_Incentives         "Are incentives in place to encourage fathers to take paternity leave on the birth of a child ? "
	la var 	Lab_Impl_Fam_Care_Scored     	"Has sex-disaggregated data on unpaid care work been published within the past five years?"
	la var 	Fam_Impl_A2F_Data_Entrep        "Is sex-disaggregated data on business activities and entrepreneurship published on a regular basis?"
	la var 	Fam_Impl_A2F_Data_Entrep_WSME   "Is sex-disaggregated data on women-owned businesses (WSME) published on a regular basis?"
	la var 	Fam_Impl_A2F_Programs           "Are there government-led programs that provide support to female entrepreneurs?"
	la var 	Fam_Impl_A2F_Programs_Fin       "Are there government-led programs that provide support to female entrepreneurs in accessing finance?"
	la var 	Fam_Impl_A2F_Programs_Training  "Are there government-led programs that provide support to female entrepreneurs regarding agency and empowerment?"
	la var 	Fam_Impl_A2F_Programs_BizDep    "Are there government-led programs that provide support to female entrepreneurs in business development?"
	la var 	Fam_A2F_FIStrategy              "Is there a current national government plan or strategy with a focus on women's access to financial services? "
	la var 	Fam_Impl_AM_Policies_Register   "Are there policies to encourage women to register immovable property?"
	la var 	Fam_Impl_AM_Aware_Rights        "Are there awareness measures in place to improve women's access to information about marital and inheritance rights?"
	la var 	Fam_Impl_AM_Data_Propown        "Is anonymized sex-disaggregated data on property ownership published on a regular basis?"
	la var  Lab_Impl_Pension_Incentives     "Are there incentives in place to increase women's retirement benefits?"
	la var  Lab_Impl_Pension_Procedure      "Is there a procedure in place for pension beneficiaries to challenge the decisions of the competent authority regarding their benefits? "
	la var  ChildcareRegistry               "Is there a publicly available registry or database of childcare providers?"
	la var 	ProcedureParentsNonTax          "Is there a clearly outlined application procedure to request financial support from the government for childcare services by parents?"
	la var 	ProcedureCentersNonTax          "Is there a clearly outlined application procedure to request financial support from the government for childcare services by private centers?"
	la var 	ProcedureEmployerNonTax         "Is there a clearly outlined application procedure to request financial support from the government for childcare services by employers?"
	la var 	GovernmentQualityReports	    "Does the government publish regular reports on quaity of childcare services?"
	

	
	local process_ScoreList  Process_Index pro_mobility pro_workplace pro_pay pro_marriage pro_parenthood pro_entrprnshp pro_assets pro_pension pro_childcare pro_safety ///
		  pro_mobility1 pro_mobility2 pro_mobility3  pro_workplace1 pro_workplace2 pro_workplace3  ///
          pro_pay1 pro_pay2   pro_marriage1 pro_marriage2 pro_marriage3   ///
		  pro_parenthood1 pro_parenthood2 pro_parenthood3   pro_entrepre1 pro_entrepre2 pro_entrepre3  ///
		  pro_assets1 pro_assets2 pro_assets3   pro_pension1 pro_pension2   ///		  
		  pro_childcare1 pro_childcare2 pro_childcare3 pro_childcare4  pro_safety1 pro_safety2 pro_safety3 pro_safety4 
		  
    local process_DPlist Fam_Impl_CM_Passport_Procedure Fam_Impl_CM_ID_Procedure Fam_Impl_CM_Urban_Transp_Policy ///
	      Lab_Impl_Work_Recruit Lab_Impl_Work_Flexguide Lab_Impl_Work_Complaints ///
	      Lab_Impl_Pay_Measure Lab_Impl_Pay_Industries ///
	      Fam_Impl_R2D_Fast_Track Fam_Impl_R2D_Fam_Courts Fam_Impl_R2D_Legal_Aid ///
	      Lab_Impl_Fam_Mompctgpay  Lab_Impl_Fam_Application  Lab_Impl_Fam_Incentives  Lab_Impl_Fam_Care_Scored  ///	
	      Fam_Impl_A2F_Data_Entrep Fam_Impl_A2F_Data_Entrep_WSME Fam_Impl_A2F_Programs Fam_Impl_A2F_Programs_Fin Fam_Impl_A2F_Programs_Training  Fam_Impl_A2F_Programs_BizDep Fam_A2F_FIStrategy ///
	      Fam_Impl_AM_Policies_Register Fam_Impl_AM_Aware_Rights Fam_Impl_AM_Data_Propown ///
	      Lab_Impl_Pension_Incentives Lab_Impl_Pension_Procedure   ///
	      ChildcareRegistry  ProcedureParentsNonTax ProcedureCentersNonTax ProcedureEmployerNonTax GovernmentQualityReports			
		
    tab1  `process_ScoreList' `process_DPlist' , m
	
    order economy economycode  region incomegroup `process_ScoreList' `process_DPlist'
			
	
	keep economy-pro_safety4
	
	tempfile Process
	save `Process', replace 			
	}
	
	
* =============================================================================================== *
*  LEGAL FRAMEWORKS 1.0 INDEX
* =============================================================================================== *
     	
    {
	import excel using "${raw}/WBL2024_RAW_Data_LegalFrameworks_1_0.xlsx" , firstrow clear  

	gen    economycode =      EconomyCode
	rename EconomyCode        ISOcode
	rename Economy            economy
	rename SurveyYear         reportyr
	rename EconomyRegion      region
	rename EconomyIncomeGroup incomegroup
	tab1   _all, m

	** Mobility
    gen mobility1 = Fam_CM_Passport          
    gen mobility2 = Fam_CM_TravelAbroad      
    gen mobility3 = Fam_CM_LeaveMaritalHome  
    gen mobility4 = Fam_CM_ChooseMaritalHome 

	** Workplace
    gen workplace1 = Fam_CM_GetJob            
    gen workplace2 = NonDiscriminEmployment   
    gen workplace3 = WBL_dv_LawSexHarWorkPlace 
    gen workplace4 = WBL_dv_LawSexHarWorkPlaceCrimP 
	
	** Pay
    gen pay1 = EqualRemunEqualValue 
    gen pay2 = NightHours 
    gen pay3 = Hazardousetcscored 
    gen pay4 = Industriesscored 

	** Marriage
    gen marriage1 = Fam_MR_Obedience 
    gen marriage2 = Fam_CM_HOH 
    gen marriage3 = WBL_dv_LawDomViolence 
    gen marriage4 = Fam_R2D_ObtainDivorce 
    gen marriage5 = Fam_R2D_Remarry 
	
	** Parenthood
	gen parenthood1 = Leavewomendaysscored 
	gen parenthood2 = Maternitybenefitsscored 
	gen parenthood3 = Paternityscored 
	gen parenthood4 = Parentalscored 
	gen parenthood5 = DismissalPregnantWomen 

	** Entrepreneurship
	gen entrepre1 = Fam_CM_SignContract 
	gen entrepre2 = Fam_CM_RegisterBiz 
	gen entrepre3 = Fam_CM_OpenBankAccount 
	gen entrepre4 = Fam_A2F_Gender 
    
	** Assets
	gen assets1 = Fam_AM_RightsImmovables 
	gen assets2 = Fam_AM_InheritanceChildren 
	gen assets3 = Fam_AM_InheritanceSpouses 
	gen assets4 = Fam_AM_PropertyAdministration_fo 
    gen assets5 = Fam_AM_NonmonetaryContributions 

	** Pension
	gen pension1 = Agesfullbenefitsscored 
	gen pension2 = Agespartialbenefitsscored 
	gen pension3 = Agesmandatoryretirementscored 
	gen pension4 = Pensioncarecredit 

	** Childcare
	gen childcare1 = Paidmaternitydays 
	gen childcare2 = Paidpaternitydays 
	gen childcare3 = Paidparentaldays 
	gen childcare4 = Paidparentalmotherquota 
	gen childcare5 = Paidparentalfatherquota 

	local indicatorlist mobility1 mobility2 mobility3 mobility4 workplace1 workplace2 workplace3 workplace4 ///
                        pay1 pay2 pay3 pay4 marriage1 marriage2 marriage3 marriage4 marriage5 ///
						parenthood1 parenthood2 parenthood3 parenthood4 parenthood5 entrepre1 entrepre2 entrepre3 entrepre4 ///
						assets1 assets2 assets3 assets4 assets5 pension1 pension2 pension3 pension4 ///
						childcare1 childcare2 childcare3 childcare4 childcare5
						
	ds3 `indicatorlist', any(X=="N/A")
	for var `r(varlist)': replace X="" if X=="N/A"
	ds3 `indicatorlist', any(X=="NA")
	for var `r(varlist)': replace X="" if X=="NA"
	ds3 `indicatorlist', any(X=="N/a")
	for var `r(varlist)': replace X="" if X=="N/a"
	ds3 `indicatorlist', any(X==".")
	for var `r(varlist)': replace X="" if X=="."
	ds3 `indicatorlist', any(X=="..")
	for var `r(varlist)': replace X="" if X==".."
	ds3 `indicatorlist', any (X=="Yes")
	for var `r(varlist)': replace X="1" if X=="Yes"
	ds3 `indicatorlist', any (X=="Yes ")
	for var `r(varlist)': replace X="1" if X=="Yes "
	ds3 `indicatorlist', any (X=="YES")
	for var `r(varlist)': replace X="1" if X=="YES"
	ds3 `indicatorlist', any (X=="yes")
	for var `r(varlist)': replace X="1" if X=="yes"
	ds3 `indicatorlist', any (X=="No")
	for var `r(varlist)': replace X="0" if X=="No"
	ds3 `indicatorlist', any (X=="No ")
	for var `r(varlist)': replace X="0" if X=="No "
	ds3 `indicatorlist', any (X=="NO")
	for var `r(varlist)': replace X="0" if X=="NO"
	ds3 `indicatorlist', any (X=="no")
	for var `r(varlist)': replace X="0" if X=="no"
	ds3 `indicatorlist', any (X=="NS")
	for var `r(varlist)': replace X="0" if X=="NS"
			
	label define YesNo 1 "Yes" 0 "No"
	
	foreach var in `indicatorlist'{
	    destring `var', replace	
	    label values `var' YesNo 
		}
		
	** Create Indicator Scores and Index:

	gen GR1_mobility   = 100*(mobility1   + mobility2   + mobility3   + mobility4)/4 	
	gen GR2_workplace  = 100*(workplace1  + workplace2  + workplace3  + workplace4)/4 	
	gen GR3_pay        = 100*(pay1        + pay2        + pay3        + pay4)/4 
	gen GR4_marriage   = 100*(marriage1   + marriage2   + marriage3   + marriage4   + marriage5)/5 
	gen GR5_parenthood = 100*(parenthood1 + parenthood2 + parenthood3 + parenthood4 + parenthood5)/5 
	gen GR6_entrprnshp = 100*(entrepre1   + entrepre2   + entrepre3   + entrepre4)/4 
	gen GR7_assets     = 100*(assets1     + assets2     + assets3     + assets4     + assets5)/5 
	gen GR8_pension    = 100*(pension1    + pension2    + pension3    + pension4)/4 
	
	gen Legal_Index_old = (GR1_mobility + GR2_workplace + GR3_pay + GR4_marriage + GR5_parenthood + GR6_entrprnshp + GR7_assets + GR8_pension)/8
	 	
	order economy economycode ISOcode region incomegroup Legal_Index_old ///
	      GR1_mobility GR2_workplace GR3_pay GR4_marriage GR5_parenthood GR6_entrprnshp GR7_assets GR8_pension  ///
		  mobility1 mobility2 mobility3 mobility4 workplace1 workplace2 workplace3 workplace4 ///
          pay1 pay2 pay3 pay4 marriage1 marriage2 marriage3 marriage4 marriage5 ///
		  parenthood1 parenthood2 parenthood3 parenthood4 parenthood5 entrepre1 entrepre2 entrepre3 entrepre4 ///
		  assets1 assets2 assets3 assets4 assets5 pension1 pension2 pension3 pension4 ///
		  childcare1 childcare2 childcare3 childcare4 childcare5
		  
	** Label Legal Old Variables: 
	
		  la var Legal_Index_old "LEGAL INDEX (OLD)"
		  la var GR1_mobility    "MOBILITY(OLD)"
		  la var mobility1       "Can a woman apply for a passport in the same way as a man?"
		  la var mobility2       "Can a woman travel outside the country in the same way as a man?"
		  la var mobility3       "Can a woman travel outside her home in the same way as a man?"
		  la var mobility4       "Can a woman  choose where to live in the same way as a man?"
		  la var GR2_workplace   "WORKPLACE(OLD)"
		  la var workplace1      "Can a woman get a job in the same way as a man?"
		  la var workplace2      "Does the law prohibit discrimination in employment based on gender?"
		  la var workplace3      "Is there legislation on sexual harassment in employment?"
		  la var workplace4      "Are there criminal penalties or civil remedies for sexual harassment in employment?"
		  la var GR3_pay         "PAY(OLD)"
		  la var pay1            "Does the law mandate equal remuneration for work of equal value?"
		  la var pay2            "Can a woman work at night in the same way as a man?"
		  la var pay3            "Can a woman work in a job deemed dangerous in the same way as a man?"
		  la var pay4            "Can a woman work in an industrial job in the same way as a man?"
		  la var GR4_marriage    "MARRIAGE(OLD)"
		  la var marriage1       "Is the law free of legal provisions that require a married woman to obey her husband?"
		  la var marriage2       "Can a woman be head of household in the same way as a man?"
		  la var marriage3       "Is there legislation specifically addressing domestic violence?"
		  la var marriage4       "Can a woman obtain a judgment of divorce in the same way as a man?"
		  la var marriage5       "Does a woman have the same rights to remarry as a man?"
		  la var GR5_parenthood  "PARENTHOOD(OLD)"
		  la var parenthood1     "Is paid leave of at least 14 weeks available to mothers?"
		  la var parenthood2     "Does the government administer 100% of maternity leave benefits?"
		  la var parenthood3     "Is paid leave available to fathers?"
		  la var parenthood4     "Is there paid parental leave?"
		  la var parenthood5     "Is dismissal of pregnant workers prohibited?"
		  la var GR6_entrprnshp  "ENTREPRENEURSHIP(OLD)"
		  la var entrepre1       "Can a woman sign a contract in the same way as a man?"
		  la var entrepre2       "Can a woman register a business in the same way as a man?"
		  la var entrepre3       "Can a woman open a bank account in the same way as a man?"
		  la var entrepre4       "Does the law prohibit discrimination in access to credit based on gender?"
		  la var GR7_assets      "ASSETS(OLD)"
		  la var assets1         "Do men and women have equal ownership rights to immovable property?"
		  la var assets2         "Do sons and daughters have equal rights to inherit assets from their parents?"
		  la var assets3         "Do male and female surviving spouses have equal rights to inherit assets?"
		  la var assets4         "Does the law grant spouses equal administrative authority over assets during marriage?"
		  la var assets5         "Does the law provide for the valuation of nonmonetary contributions?"
		  la var GR8_pension     "PENSION(OLD)"
		  la var pension1        "Is the age at which men and women can retire with full pension benefits the same?"
		  la var pension2        "Is the age at which men and women can retire with partial pension benefits the same?"
		  la var pension3        "Is the mandatory retirement age for men and women the same?"
		  la var pension4        "Are periods of absence due to childcare accounted for in pension benefits?"
		  
		  la var economycode     "Economy code"
		  la var ISOcode         "ISO code"
		  la var region          "Region"
		  la var incomegroup     "Income group"

          la var childcare1      "Paid maternity leave days"
          la var childcare2      "Paid paternity leave days"
          la var childcare3      "Paid parental leave days (shared)"
          la var childcare4      "Paid parental leave days mother quota"
          la var childcare5      "Paid parental leave days father quota"

    replace incomegroup = "Not classified" if economy == "Venezuela, RB"   
    replace ISOcode = "XKX" if economy == "Kosovo"
    replace ISOcode = "ROU" if economy == "Romania"
    replace ISOcode = "COD" if economy == "Congo, Dem. Rep."
    replace ISOcode = "TLS" if economy == "Timor-Leste"
    replace ISOcode = "PSE" if economy == "West Bank and Gaza"

	foreach var in `indicatorlist'  {
	    rename `var' `var'_LegOld	
		}
						  

	keep economy-childcare5_LegOld	
	
	tempfile LegalOld
	save `LegalOld', replace 
	
    }
	
	
* =============================================================================================== *
* EXPERT OPINIONS INDEX 
* =============================================================================================== *

    {
	  use "${raw}/WBL2024_ExpertOpinion_EOLevel_ToPublish.dta" ,  clear  
	  sort Economy EconomyID
	  
	  ** Create Question Scores per question by taking their median within economy:
	  
	  foreach var in safety1 mobility1 workplace1 workplace2 pay1 pay2 marriage1 marriage2 ///
	                 parenthood1 parenthood2 childcare1 entrepreneurship1 entrepreneurship2 assets1 pension1 {
          by Economy: egen `var'_med = median(`var')
	      la var `var'_med "Question score `var'"
		 * count if `var'_med == .
	  }	
	  
	  ** Scale Question Scores to 0-100: 
	  
	  local vars  safety1_med mobility1_med workplace1_med workplace2_med pay1_med pay2_med ///
	              marriage1_med marriage2_med parenthood1_med parenthood2_med childcare1_med ///
				  entrepreneurship1_med entrepreneurship2_med assets1_med pension1_med
	  foreach var in `vars' {
	      summ `var'
	 	  replace `var'= `var' * 25
		  sum `var'  
	  }
	  	  
	   	  			
	  ** Create Indicator Scores: 
	  
	  gen  safety_EO      = safety1_med    // used to be: rowmean(EO_1_1_med EO_1_2_med)	, dropped EO_1_2 from EOI calcualtions	
	  gen  mobility_EO    = mobility1_med	
	  egen workplace_EO   = rowmean(workplace1_med workplace2_med)	  
	  egen pay_EO         = rowmean(pay1_med pay2_med)	
	  egen marriage_EO    = rowmean(marriage1_med marriage2_med )	
	  egen parenthood_EO  = rowmean(parenthood1_med parenthood2_med)		  	  
	  gen  childcare_EO   = childcare1_med		  
	  egen entrepre_EO    = rowmean(entrepreneurship1_med entrepreneurship2_med)		  	  
	  gen  assets_EO      = assets1_med 		  	  
	  gen  pension_EO     = pension1_med		
	   
	  la var  safety_EO     "SAFETY (EO)"
	  la var  mobility_EO   "MOBILITY (EO)"
	  la var  workplace_EO  "WORKPLACE (EO)"
	  la var  pay_EO        "PAY (EO)"
	  la var  marriage_EO   "MARRIAGE (EO)"
	  la var  parenthood_EO "PARENTHOOD (EO)"
	  la var  childcare_EO  "CHILDCARE (EO)"
	  la var  entrepre_EO   "ENTREPRENEURSHIP (EO)" 
	  la var  assets_EO     "ASSETS (EO)"	  
	  la var  pension_EO    "PENSION (EO)"
		
	  bys Economy: egen TotalSubmissions = count(EconomyID)
	  la var TotalSubmissions "Total number of submissions"

	  ** Economy level data:	  
	  bys   Economy: gen rank = _n
	  keep  if rank == 1
	  drop  SubmissionID EconomyID safety1-pension1 rank
	  
	  ** Create country level EO index :	  	  
	  egen EO_index = rowmean(safety_EO mobility_EO workplace_EO pay_EO marriage_EO parenthood_EO childcare_EO entrepre_EO assets_EO pension_EO)
	      la var EO_index "WBL 2024 EO index"
		 	  
	  rename  Economy       economy  
	  rename  EconomyCode   economycode
 
        tempfile EOdata
	    save `EOdata', replace 	  
	  
	}
	
			
* =============================================================================================== *
*  CREATE MERGED DATASET 
* =============================================================================================== *		
	
	{
		use `LegalNew', clear
		
		merge 1:1 economy using `LegalOld' , gen(merge_old)
		merge 1:1 economy using `Process'  , gen(merge_process)
		merge 1:1 economy using `EOdata'   , gen(merge_EOdata)
		 
		
		gen    diff_legal = Legal_Index_LegNew - Legal_Index_old
		la var diff_legal   "Legal(new) Index - Legal(old) Index"	
		gen    diff_SuppF = Legal_Index_LegNew - Process_Index
		la var diff_SuppF   "Legal(new) Index - Supportive Frameworks Index"			
		gen    diff_EO    = Legal_Index_LegNew - EO_index
		la var diff_EO      "Legal(new) Index - EO Index"	
		
		sort  economy
		tab1  *_LegNew *_LegOld pro_* *EO, m
		summ  *_LegNew *_LegOld pro_* *EO EO_index
		order economy economycode region incomegroup Legal_Index_LegNew Legal_Index_old Process_Index EO_index
		drop  merge_old merge_process 

		** Generate Venezuela as Not classified 		
        tab     incomegroup , m
		tab     incomegroup      if economy=="Venezuela, RB"   // upper middle income
		replace incomegroup = "" if economy=="Venezuela, RB"   // Not classified in WBL2024 report

		local  today: display %td_CCYYNNDD date(c(current_date),"DMY")

		export excel using "${data}/WBL2024_LEGAL_PROCESS_EO_Index.xlsx" , firstrow(varlabels) sheet(WBL2024_all, replace)  
		
		save "${data}/WBL2024_LEGAL_PROCESS_EOIndex.dta", replace 
		
        * =============================================================================================== *
		****** CREATE SUBSAMPLE FOR ECONOMIES with EO INDEX:
		* =============================================================================================== *

		use "${data}/WBL2024_LEGAL_PROCESS_EOIndex.dta", clear
		
		keep if merge_EOdata==3   // n=164 EO Index Eligible Economies
		
		save "${data}/WBL2024_LEGAL_PROCESS_EOIndex_ForComparisons.dta", replace   
		
		export excel using "${data}/WBL2024_LEGAL_PROCESS_EOIndex_ForComparisons.xlsx" , firstrow(varlabels) sheet(WBL2024_n=164, replace)  
		
	}
	
	
	
		
	
* End of do-file!	



		

	

			


		
	
	
	