
* =============================================================================================== *
* =============================================================================================== *
*								WBL 2024        												  *
*			        WBL 2024  RRR : Executive Summary and Chapter 1 - Tables and Figures 		  *
* =============================================================================================== *
* =============================================================================================== *
/*

	Title: 		WBL2024_Report_ES_Chapter1.do   

 	Outline: 	This .do file creates output for WBL 2024 Report Executive Summary and Chapter 1

 	Input: 		This .do file uses the following files in "/DataWork/Data/Final" subfolder:
	            "WBL2024_LEGAL_PROCESS_EOIndex.dta"
				"WBL2024_LEGAL_PROCESS_EOIndex_ForComparisons.dta"
				"WBL-1971-2024-Reforms_Database.xlsx"
				"WBL1-0-1971-2024.dta"
				"WBL2024-Data-revisions-web.xlsx"

	Output:		Figures and tables in Executive Summary and Chapter 1, except for Figures ES.6, ES.7,
				and ES.8. Saved in "/Outputs/ExecutiveSummary" and "/Outputs/Chapter1" folders. 
	
	Description: Variables ending with *_LegNew are for WBL Legal Frameworks 2.0 variables,
	             Variables starting with pro_* are for WBL Supportive Frameworks variables,
				 Variables ending with *_LegOld are for WBL Legal Frameworks 1.0 variables,
				 Variables ending with *_EO are for WBL Expert Opinions variables.
				 Variables for Indices:  Legal_Index_LegNew ,  Process_Index , Legal_Index_old , EO_index
	
	            
*/
* =============================================================================================== *

	clear all
	clear matrix
	set more off
	set matsize 700
	set graph on

* =============================================================================================== *
*  EXECUTIVE SUMMARY (ES) 
* =============================================================================================== *

{
*** Figure ES.1
    * Not Codable


*** Table ES.1
    * Not Codable


*** Figure ES.2

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    label define regionlabel 1 "Middle East & North Africa" 2 "South Asia" 3 "Sub-Saharan Africa" 4 "East Asia & Pacific"  5 "Latin America & Caribbean"  6 "Europe & Central Asia" 7 "High income: OECD"

    encode region, gen(nregion) label(regionlabel)
    gen ccc = 100
    bysort nregion: egen meanbyregion = mean(Legal_Index_LegNew)
    bysort nregion: egen minbyregion  = min(Legal_Index_LegNew)
    bysort nregion: egen maxbyregion  = max(Legal_Index_LegNew)

    tw scatter nregion Legal_Index_LegNew, msymbol(pipe) mcolor(navy) msize(.3in) xsize(8) ylabel(1 "Middle East & North Africa" 2 "South Asia" 3 "Sub-Saharan Africa" 4 "East Asia & Pacific"  5 "Latin America & Caribbean"  6 "Europe & Central Asia" 7 "High income: OECD" ) ylab(, angle(0)) ysc(r(0.5 4.5)) xtitle("WBL score (0-100)") ytitle("") xscale(range(10 .)) || bar ccc nregion, hor barw(.6) color(blue) fintensity(5) bstyle(outline) legend(off) || scatter nregion meanbyregion, msymbol(O) mcolor(orange) msize(.4in) ml(meanbyregion) mlabp(0) mlabf(%9.1f) mlabc(navy)|| scatter nregion minbyregion, ml(minbyregion) mlabf(%9.1f) mlabc(navy) mlabp(9) msymbol(pipe) mcolor(orange) msize(.3in) || scatter nregion maxbyregion, ml(maxbyregion) mlabf(%9.1f) mlabc(navy) mlabp(0) msymbol(pipe) mcolor(orange) msize(.3in)

graph export "${output_es}\00_Figure_ES_2.png", width(2000) replace


*** Figure ES.3

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    summarize Legal_Index_LegNew, meanonly
    local legal_index_2 = r(mean)
	local rounded_legal_index_2 = round(`legal_index_2', 0.1)

    keep mobility_LegNew workplace_LegNew pay_LegNew marriage_LegNew parenthood_LegNew entrprnshp_LegNew assets_LegNew pension_LegNew childcare_LegNew safety_LegNew

    collapse (mean) mobility_LegNew workplace_LegNew pay_LegNew marriage_LegNew parenthood_LegNew entrprnshp_LegNew assets_LegNew pension_LegNew childcare_LegNew safety_LegNew

    label variable mobility_LegNew Mobility
    label variable workplace_LegNew Workplace
    label variable pay_LegNew Pay
    label variable marriage_LegNew Marriage
    label variable parenthood_LegNew Parenthood
    label variable entrprnshp_LegNew Entrepreneurship
    label variable assets_LegNew Assets
    label variable pension_LegNew Pension
    label variable childcare_LegNew Childcare
    label variable safety_LegNew Safety

graph bar (asis) mobility_LegNew marriage_LegNew assets_LegNew pension_LegNew pay_LegNew parenthood_LegNew workplace_LegNew childcare_LegNew entrprnshp_LegNew safety_LegNew, ///
    ascategory ///
    yline(`legal_index_2') ///
	text(68 75 "WBL 2.0 legal frameworks scores," "global average (`rounded_legal_index_2')", place(e)) ///
    bargap(30) /// 
    bar(1, color(blue)) /// 
    blabel(bar, format(%4.1f)) /// 
    legend(off) ///
	xsize(12)

graph export "${output_es}\00_Figure_ES_3.png", width(2000) replace

	
*** Figure ES.4

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    label define regionlabel  1 "Sub-Saharan Africa" 2 "Middle East & North Africa" 3 "South Asia" 4 "East Asia & Pacific" 5 "Latin America & Caribbean" 6 "Europe & Central Asia"  7 "High income: OECD" , replace 
 
    encode region, gen(nregion) label(regionlabel)
    gen ccc = 100
    bysort nregion: egen meanbyregion = mean(Process_Index)
    bysort nregion: egen minbyregion  = min(Process_Index)
    bysort nregion: egen maxbyregion  = max(Process_Index)

    tw scatter nregion Process_Index, msymbol(pipe) mcolor(navy) msize(.3in) xsize(8) ylabel(1 "Sub-Saharan Africa" 2 "Middle East & North Africa" 3 "South Asia" 4 "East Asia & Pacific"5 "Latin America & Caribbean" 6 "Europe & Central Asia"  7 "High income: OECD" ) ylab(, angle(0)) ysc(r(0.5 4.5)) xtitle("WBL score (0-100)") ytitle("") xscale(range(0 .)) || bar ccc nregion, hor barw(.6) color(blue) fintensity(5) bstyle(outline) legend(off) || scatter nregion meanbyregion, msymbol(O) mcolor(orange) msize(.4in) ml(meanbyregion) mlabp(0) mlabf(%9.1f) mlabc(navy)|| scatter nregion minbyregion, ml(minbyregion) mlabf(%9.1f) mlabc(navy) mlabp(9) msymbol(pipe) mcolor(orange) msize(.3in) || scatter nregion maxbyregion, ml(maxbyregion) mlabf(%9.1f) mlabc(navy) mlabp(0) msymbol(pipe) mcolor(orange) msize(.3in)

graph export "${output_es}\00_Figure_ES_4.png", width(2000) replace


*** Figure ES.5

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    label define regionlabel 1 "South Asia"  2"Sub-Saharan Africa" 3 "Latin America & Caribbean" 4 "East Asia & Pacific" 5  "Middle East & North Africa" 6 "Europe & Central Asia"  7 "High income: OECD" , replace 
 
    encode region, gen(nregion) label(regionlabel)
    gen ccc = 100
    bysort nregion: egen meanbyregion = mean(EO_index)
    bysort nregion: egen minbyregion  = min(EO_index)
    bysort nregion: egen maxbyregion  = max(EO_index)

    tw scatter nregion EO_index, msymbol(pipe) mcolor(navy) msize(.3in) xsize(8) ylabel(1 "South Asia"  2"Sub-Saharan Africa" 3 "Latin America & Caribbean" 4 "East Asia & Pacific" 5  "Middle East & North Africa" 6 "Europe & Central Asia"  7 "High income: OECD") ylab(, angle(0)) ysc(r(0.5 4.5)) xtitle("WBL score (0-100)") ytitle("") xscale(range(0 .)) || bar ccc nregion, hor barw(.6) color(blue) fintensity(5) bstyle(outline) legend(off) || scatter nregion meanbyregion, msymbol(O) mcolor(orange) msize(.4in) ml(meanbyregion) mlabp(0) mlabf(%9.1f) mlabc(navy)|| scatter nregion minbyregion, ml(minbyregion) mlabf(%9.1f) mlabc(navy) mlabp(9) msymbol(pipe) mcolor(orange) msize(.3in) || scatter nregion maxbyregion, ml(maxbyregion) mlabf(%9.1f) mlabc(navy) mlabp(0) msymbol(pipe) mcolor(orange) msize(.3in)

graph export "${output_es}\00_Figure_ES_5.png", width(2000) replace


*** Figure ES.6
    * Please run the associated R Code


*** Figure ES.7
    * Please run the associated R Code


*** Figure ES.8
    * Please run the associated R Code


*** Figure ES.9

use "$data\WBL2024_LEGAL_PROCESS_EOIndex_ForComparisons.dta", clear

    * Panel A: By region
	
	* Generate sorting by gap
    gen sort = 1		if region == "Middle East & North Africa"
    replace sort = 2	if region == "South Asia"
    replace sort = 3 	if region == "Sub-Saharan Africa"
    replace sort = 4 	if region == "East Asia & Pacific"
    replace sort = 5 	if region == "Latin America & Caribbean"
    replace sort = 6 	if region == "Europe & Central Asia"
    replace sort = 7 	if region == "High income: OECD"
	
    graph dot Legal_Index_LegNew Process_Index EO_index, ///
		  over(region, sort(sort)) ///
		  marker(1, mcolor(blue)) marker(2, mcolor(orange)) marker(3, mcolor(green)) ///
		  plotregion(fcolor(white)) graphregion(fcolor(white)) ///
		  legend (pos(6) label(1 "WBL 2.0 Legal Frameworks score (0-100)") label(2 "WBL 2.0 Supportive Frameworks score (0-100)") label(3 "WBL 2.0 Expert Opinions Score (0-100)")) xsize(8) ///
		  name(dot1, replace)

graph export "${output_es}\00_Figure_ES_9_a.png", replace
		   
    * Panel B: By income	
	
    * Generate sorting by gap
    gen sort2 = 1		if incomegroup == "Low income"
    replace sort2 = 2	if incomegroup == "Lower middle income"
    replace sort2 = 3	if incomegroup == "Upper middle income"
    replace sort2 = 4	if incomegroup == "High income"

    drop if economy=="Venezuela, RB"
	
    graph dot Legal_Index_LegNew Process_Index EO_index, ///
		  over(income, sort(sort2)) ///		  
		  marker(1, mcolor(blue)) marker(2, mcolor(orange)) marker(3, mcolor(green)) ///
		  plotregion(fcolor(white)) graphregion(fcolor(white)) ///
		  legend(pos(6) label(1 "WBL 2.0 Legal Frameworks score (0-100)") label(2 "WBL 2.0 Supportive Frameworks score (0-100)") label(3 "WBL 2.0 Expert Opinions Score (0-100)")) xsize(8) ///
 		  name(dot2, replace)
		  
graph export "${output_es}\00_Figure_ES_9_b.png", replace

graph combine dot1 dot2, col(2) xsize(15)

graph export "${output_es}\00_Figure_ES_9.png", replace


*** Figure ES.10
    * Not codable


*** Table ES.A.1
    * Not codable


*** Table ES.B.1

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    gsort -Legal_Index_old economy
    keep economy Legal_Index_LegNew Legal_Index_old Process_Index EO_index
    order economy Legal_Index_old Legal_Index_LegNew Process_Index EO_index

export excel using "${output_es}\00_Table_ES_B_1.xlsx", firstrow(variables) replace

}
	
* =============================================================================================== *
*  CHAPTER 1 
* =============================================================================================== *

{
*** Table 1.1

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    gsort -Legal_Index_old economy
    keep  economy Legal_Index_old

export excel using "${output_c1}\01_Table_1_1.xlsx", firstrow(variables) replace 

*** Figure 1.1

    * By region
use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    label define regionlabel 1 "Middle East & North Africa" 2 "South Asia" 3 "East Asia & Pacific" 4 "Sub-Saharan Africa" 5 "Latin America & Caribbean" 6 "Europe & Central Asia"  7 "High income: OECD"
    encode region, gen(nregion) label(regionlabel)
    gen ccc = 100
	
	gen Legal_Index_old_rounded = round(Legal_Index_old, 0.1)
	
    bysort nregion: egen meanbyregion = mean(Legal_Index_old_rounded)
    bysort nregion: egen minbyregion  = min(Legal_Index_old_rounded)
    bysort nregion: egen maxbyregion  = max(Legal_Index_old_rounded)

    tw scatter nregion Legal_Index_old_rounded, msymbol(pipe) mcolor(navy) msize(.3in) xsize(8) ///
	           ylabel(1 "Middle East & North Africa" 2 "South Asia" 3 "East Asia & Pacific" 4 "Sub-Saharan Africa" 5 "Latin America & Caribbean" 6 "Europe & Central Asia"  7 "OECD High Income" ) ///
			   ylab(, angle(0)) ysc(r(0.5 4.5)) xtitle("WBL score (0-100)") ytitle("") || bar ccc nregion, hor barw(.6) color(blue) fintensity(5) bstyle(outline) legend(off) || ///
			   scatter nregion meanbyregion, msymbol(O) mcolor(orange) msize(.4in) ml(meanbyregion) mlabp(0) mlabf(%9.1f) mlabc(navy)  || ///
			   scatter nregion minbyregion, ml(minbyregion) mlabf(%9.1f) mlabc(navy) mlabp(9) msymbol(pipe) mcolor(orange) msize(.3in) ||  ///
			   scatter nregion maxbyregion, ml(maxbyregion) mlabf(%9.1f) mlabc(navy) mlabp(0) msymbol(pipe) mcolor(orange) msize(.3in)

graph export "${output_c1}\01_Figure_1_1.png", width(2000) replace


*** Figure 1.2

    * By incomegroup

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear

    drop if incomegroup == ""   // Drop Venezuela
    label define incomelabel 1 "Low income" 2 "Lower middle income" 3 "Upper middle income" 4 "High income"
    encode incomegroup, gen(nincomegroup) label(incomelabel)
	
	gen Legal_Index_old_rounded = round(Legal_Index_old, 0.1)
	
	bysort nincomegroup: egen meanbyincome = mean(Legal_Index_old_rounded)
	bysort nincomegroup: egen minbyincome  = min(Legal_Index_old_rounded)
	bysort nincomegroup: egen maxbyincome  = max(Legal_Index_old_rounded)
	gen ccc = 100
	set scheme stcolor

    tw scatter nincomegroup Legal_Index_old_rounded, msymbol(pipe) mcolor(navy) msize(ehuge) xsize(8) ///
	           ylabel(1 "Low income" 2 "Lower middle income" 3 "Upper middle income" 4 "High income") ///
			   ylab(, angle(0)) ysc(r(0.5 4.5)) xtitle("WBL score (0-100)") ytitle("") || ///
			   bar ccc nincomegroup, hor barw(.6) color(blue) fintensity(5) bstyle(outline) legend(off) || ///
			   scatter nincomegroup meanbyincome, msymbol(O) mcolor(orange) msize(.4in) ml(meanbyincome) mlabp(0) mlabf(%9.1f) mlabc(navy)   || ///
			   scatter nincomegroup minbyincome, ml(minbyincome) mlabf(%9.1f) mlabc(navy) mlabp(9) msymbol(pipe) mcolor(orange) msize(ehuge) || ///
			   scatter nincomegroup maxbyincome, ml(maxbyincome) mlabf(%9.1f) mlabc(navy) mlabp(0) msymbol(pipe) mcolor(orange) msize(ehuge)

graph export "${output_c1}\01_Figure_1_2.png", width(2000) replace


*** Figure 1.3

use "$data\WBL2024_LEGAL_PROCESS_EOIndex.dta", clear
    keep economy incomegroup
    rename economy Economy
	tempfile econ_incomegroup
	save `econ_incomegroup', replace 
	

import excel "$raw\WBL-1971-2024-Reforms_Database.xlsx", sheet("Reform database (1971-2024)_web") firstrow clear

    keep if ReportYear == 2024
	merge n:1 Economy using `econ_incomegroup'  
	drop if _merge == 2
	drop _merge
	
	preserve
	contract Region
    egen percent = pc(_freq)
    gen rounded_percent = round(percent)
    gen label_text = "=" + string(_freq)
    egen float reg = group(Region label_text), label lname(mylabel) 

    graph pie _freq, over(reg) plabel(_all percent, format("%2.0f") size(small)) /// 
	                 title("By income group") /// 
	                 legend(ring(0) position(6) col(2) size(small)) ///
	                 ysize(12) ///
	                 name(pie1, replace)
	
	graph export "${output_c1}\01_Figure_1_3_a.png", replace

    restore
	
	preserve
	contract incomegroup
    egen percent = pc(_freq)
    gen rounded_percent = round(percent)
	gen label_text = "=" + string(_freq)
	egen float income = group(incomegroup label_text), label lname(mylabel) 

    graph pie _freq, over(income) plabel(_all percent, format("%2.0f") size(small)) /// 
	                 title("By income group") /// 
	                 legend(ring(0) position(6) col(2) size(small)) ///
	                 ysize(12) ////
	                 name(pie2, replace)

	graph export "${output_c1}\01_Figure_1_3_b.png", replace
	
	restore

	graph combine pie1 pie2, col(2)

	graph export "${output_c1}\01_Figure1_3.png", replace



*** Table 1.2

import excel "$raw\WBL-1971-2024-Reforms_Database.xlsx", sheet("Reform database (1971-2024)_web") firstrow clear
	keep if ReportYear == 2024
	keep Economy Indicator
	
	contract Economy Indicator
	
	reshape wide _freq, i(Economy) j(Indicator, string) 
	
	local indicators "Assets Entrepreneurship Marriage Mobility Parenthood Pay Pension Workplace"
	foreach ind in `indicators' {
		rename _freq`ind' `ind'_reform
		replace `ind' = 0 if `ind' == .
	}
	
	rename Economy economy

	tempfile reform
	save `reform'
	
import excel "$raw\WBL2024-Data-revisions-web.xlsx", sheet("WBL 1.0 Panel 2023") firstrow clear
	keep if ReportYear == 2023
	keep Economy WBLINDEX 
	rename Economy economy
	rename WBLINDEX WBL_index2023
	
	replace economy = "Viet Nam" if economy == "Vietnam"
	
	merge 1:1 economy using `reform'
	drop _merge

	tempfile wbl23
	save `wbl23'
	
use "$raw\WBL1-0-1971-2024.dta", clear
	keep if reportyr == 2024
	keep economy economycode ISOcode region incomegroup year WBL_index
	rename WBL_index WBL_index2024
	
	merge 1:1 economy using `wbl23'
	reshape long WBL_index, i(economy) j(reportyr)
	
	bysort economy (reportyr): gen score_diff = WBL_index - WBL_index[_n-1]
	bysort economy (reportyr): gen pct_change = (WBL_index - WBL_index[_n-1]) / WBL_index[_n-1] * 100
	drop if score_diff == .
	
	gsort -score_diff
	keep in 1/5
	
	label variable score_diff "Change in score"
	label variable pct_change "% increase in score"

	drop _merge
	gsort -score_diff
	
	order economy economycode ISOcode region incomegroup year reportyr WBL_index score_diff pct_change Mobility_reform Workplace_reform Pay_reform Marriage_reform Parenthood_reform Entrepreneurship_reform Assets_reform Pension_reform
	
	replace score_diff = round(score_diff, 0.2)
	replace pct_change = round(pct_change, 0.2)
	
export excel using "${output_c1}\01_Table_1_2.xlsx", firstrow(variables) replace


*** Figure 1.4
    * Not Codable	
	
	
*** Table 1.3

import excel "$raw\WBL-1971-2024-Reforms_Database.xlsx", sheet("Reform database (1971-2024)_web") firstrow clear
	keep if ReportYear == 2024
	egen indicatorCount = count(Indicator), by(Indicator)
	
	order indicatorCount, after(Indicator)
	
	gen indicator_order = .
	replace indicator_order = 1 if Indicator == "Mobility"
	replace indicator_order = 2 if Indicator == "Workplace"
	replace indicator_order = 3 if Indicator == "Pay"
	replace indicator_order = 4 if Indicator == "Marriage"
	replace indicator_order = 5 if Indicator == "Parenthood"
	replace indicator_order = 6 if Indicator == "Entrepreneurship"
	replace indicator_order = 7 if Indicator == "Assets"
	replace indicator_order = 8 if Indicator == "Pension"
	
	sort indicator_order Economy
	
export excel using "${output_c1}\01_Table_1_3.xlsx", firstrow(variables) replace

}



* End of do-file!	






