*! -spmap_color-: Auxiliary program for -spmap-                                
*! Version 1.3.0 - 13 March 2017                                               
*! Version 1.2.0 - 14 March 2008                                               
*! Version 1.1.0 - 7 May 2007                                                  
*! Version 1.0.0 - 7 December 2006                                             
*! Author: Maurizio Pisati                                                     
*! Department of Sociology and Social Research                                 
*! University of Milano Bicocca (Italy)                                        
*! maurizio.pisati@unimib.it                                                   




*  ----------------------------------------------------------------------------
*  1. Define program                                                           
*  ----------------------------------------------------------------------------

program spmap_color, sclass
version 9.2
args PALETTE NC




*  ----------------------------------------------------------------------------
*  2. Get specified palette colors and return color list                       
*  ----------------------------------------------------------------------------

preserve

quietly {

   /* Predefined palettes */
   if (!inlist("`PALETTE'","Blues2","Greens2","Reds2","Greys2","Rainbow")) {
      cap findfile "spmap_color.ado"
      insheet palette levels maxlev class r g b using `"`r(fn)'"', tab clear
      drop in 1/147
      keep if palette == "`PALETTE'"
      su maxlev, mean
      if (r(mean) < `NC') {
         di as err "{p}Maximum number of colors for palette "   ///
                   "{bf:`PALETTE'} is `r(mean)'{p_end}"
         exit 198
      }
      keep if levels == `NC'
      tempname RGB
      mkmat r g b, matrix(`RGB')
      forval i = 1/`NC' {
         local R = `RGB'[`i',1]
         local G = `RGB'[`i',2]
         local B = `RGB'[`i',3]
         local COLORS `"`COLORS'"`R' `G' `B'" "'
      }
   }

   /* Other palettes */
   else {

      /* Palette Blues2 */
      if ("`PALETTE'" == "Blues2") {
         tempname HSB
         matrix `HSB' = J(`NC', 3, .)
         forval i = 1/`NC' {
            matrix `HSB'[`i', 1] = 208
            matrix `HSB'[`i', 2] = 20 + 80 * (`i' - 1) / (`NC' - 1)
            matrix `HSB'[`i', 3] = 100 - 60 * (`i' - 1) / (`NC' - 1)
         }
      }

      /* Palette Greens2 */
      if ("`PALETTE'" == "Greens2") {
         tempname HSB
         matrix `HSB' = J(`NC', 3, .)
         forval i = 1/`NC' {
            matrix `HSB'[`i', 1] = 122 + 20 * (`i' - 1) / (`NC' - 1)
            matrix `HSB'[`i', 2] = 20 + 80 * (`i' - 1) / (`NC' - 1)
            matrix `HSB'[`i', 3] = 100 - 70 * (`i' - 1) / (`NC' - 1)
         }
      }

      /* Palette Reds2 */
      if ("`PALETTE'" == "Reds2") {
         tempname HSB
         matrix `HSB' = J(`NC', 3, .)
         forval i = 1/`NC' {
            local PROP = (`i' - 1) / (`NC' - 1)
            matrix `HSB'[`i', 1] = 20 - 20 * (`i' - 1) / (`NC' - 1)
            matrix `HSB'[`i', 2] = 20 + 80 * (`i' - 1) / (`NC' - 1)
            if (`PROP' < 0.5) matrix `HSB'[`i', 3] = 100
            else matrix `HSB'[`i', 3] = 100 -                            ///
                         60 * (((`i' - 1) / (`NC' - 1)) - (0.5)) / 0.5
         }
      }

      /* Palette Greys2 */
      if ("`PALETTE'" == "Greys2") {
         tempname HSB
         matrix `HSB' = J(`NC', 3, 0)
         forval i = 1/`NC' {
            matrix `HSB'[`i', 3] = 88 - ((`i' - 1) * 88) / (`NC' - 1)
         }
      }

      /* Palette Rainbow */
      if ("`PALETTE'" == "Rainbow") {
         tempname HSB
         matrix `HSB' = J(`NC', 3, 100)
         forval i = 1/`NC' {
            matrix `HSB'[`i', 1] = 240 - ((`i' - 1) * 240) / (`NC' - 1)
         }
      }

      /* Convert HSB -> RGB */
      forval i = 1/`NC' {
         local H = `HSB'[`i', 1] / 360
         local S = `HSB'[`i', 2] / 100
         local V = `HSB'[`i', 3] / 100
         local H = `H' * 6
         local V = trunc(min(`V' * 256, 255))
         local iH = trunc(`H')
         local fH = `H' - `iH'
         if (mod(`iH',2) == 0) local fH = 1 - `fH'
         local M = round(`V' * (1 - `S'))
         local N = round(`V' * (1 - (`S' * `fH')))
         if (`iH' == 1) {
            local R = `N'
            local G = `V'
            local B = `M'
         }
         if (`iH' == 2) {
            local R = `M'
            local G = `V'
            local B = `N'
         }
         if (`iH' == 3) {
            local R = `M'
            local G = `N'
            local B = `V'
         }
         if (`iH' == 4) {
            local R = `N'
            local G = `M'
            local B = `V'
         }
         if (`iH' == 5) {
            local R = `V'
            local G = `M'
            local B = `N'
         }
         if (`iH' == 0) {
            local R = `V'
            local G = `N'
            local B = `M'
         }
         local COLORS `"`COLORS'"`R' `G' `B'" "'
      }
   }
}

sreturn local colors `"`COLORS'"'
restore




*  ----------------------------------------------------------------------------
*  3. End program                                                              
*  ----------------------------------------------------------------------------

end
exit




*  ----------------------------------------------------------------------------
*  Predefined color palettes                                                   
*  ----------------------------------------------------------------------------

/* palette levels maxlev class r g b */
Blues	2	9	1	158	202	225
Blues	2	9	2	49	130	189
Blues	3	9	1	222	235	247
Blues	3	9	2	158	202	225
Blues	3	9	3	49	130	189
Blues	4	9	1	239	243	255
Blues	4	9	2	189	215	231
Blues	4	9	3	107	174	214
Blues	4	9	4	33	113	181
Blues	5	9	1	239	243	255
Blues	5	9	2	189	215	231
Blues	5	9	3	107	174	214
Blues	5	9	4	49	130	189
Blues	5	9	5	8	81	156
Blues	6	9	1	239	243	255
Blues	6	9	2	198	219	239
Blues	6	9	3	158	202	225
Blues	6	9	4	107	174	214
Blues	6	9	5	49	130	189
Blues	6	9	6	8	81	156
Blues	7	9	1	239	243	255
Blues	7	9	2	198	219	239
Blues	7	9	3	158	202	225
Blues	7	9	4	107	174	214
Blues	7	9	5	66	146	198
Blues	7	9	6	33	113	181
Blues	7	9	7	8	69	148
Blues	8	9	1	247	251	255
Blues	8	9	2	222	235	247
Blues	8	9	3	198	219	239
Blues	8	9	4	158	202	225
Blues	8	9	5	107	174	214
Blues	8	9	6	66	146	198
Blues	8	9	7	33	113	181
Blues	8	9	8	8	69	148
Blues	9	9	1	247	251	255
Blues	9	9	2	222	235	247
Blues	9	9	3	198	219	239
Blues	9	9	4	158	202	225
Blues	9	9	5	107	174	214
Blues	9	9	6	66	146	198
Blues	9	9	7	33	113	181
Blues	9	9	8	8	81	156
Blues	9	9	9	8	48	107
BuGn	2	9	1	153	216	201
BuGn	2	9	2	44	162	95
BuGn	3	9	1	229	245	249
BuGn	3	9	2	153	216	201
BuGn	3	9	3	44	162	95
BuGn	4	9	1	237	248	251
BuGn	4	9	2	178	226	226
BuGn	4	9	3	102	194	164
BuGn	4	9	4	35	139	69
BuGn	5	9	1	237	248	251
BuGn	5	9	2	178	226	226
BuGn	5	9	3	102	194	164
BuGn	5	9	4	44	162	95
BuGn	5	9	5	0	109	44
BuGn	6	9	1	237	248	251
BuGn	6	9	2	204	236	230
BuGn	6	9	3	153	216	201
BuGn	6	9	4	102	194	164
BuGn	6	9	5	44	162	95
BuGn	6	9	6	0	109	44
BuGn	7	9	1	237	248	251
BuGn	7	9	2	204	236	230
BuGn	7	9	3	153	216	201
BuGn	7	9	4	102	194	164
BuGn	7	9	5	65	174	118
BuGn	7	9	6	35	139	69
BuGn	7	9	7	0	88	36
BuGn	8	9	1	247	252	253
BuGn	8	9	2	229	245	249
BuGn	8	9	3	204	236	230
BuGn	8	9	4	153	216	201
BuGn	8	9	5	102	194	164
BuGn	8	9	6	65	174	118
BuGn	8	9	7	35	139	69
BuGn	8	9	8	0	88	36
BuGn	9	9	1	247	252	253
BuGn	9	9	2	229	245	249
BuGn	9	9	3	204	236	230
BuGn	9	9	4	153	216	201
BuGn	9	9	5	102	194	164
BuGn	9	9	6	65	174	118
BuGn	9	9	7	35	139	69
BuGn	9	9	8	0	109	44
BuGn	9	9	9	0	68	27
BuPu	2	9	1	158	188	218
BuPu	2	9	2	136	86	167
BuPu	3	9	1	224	236	244
BuPu	3	9	2	158	188	218
BuPu	3	9	3	136	86	167
BuPu	4	9	1	237	248	251
BuPu	4	9	2	179	205	227
BuPu	4	9	3	140	150	198
BuPu	4	9	4	136	65	157
BuPu	5	9	1	237	248	251
BuPu	5	9	2	179	205	227
BuPu	5	9	3	140	150	198
BuPu	5	9	4	136	86	167
BuPu	5	9	5	129	15	124
BuPu	6	9	1	237	248	251
BuPu	6	9	2	191	211	230
BuPu	6	9	3	158	188	218
BuPu	6	9	4	140	150	198
BuPu	6	9	5	136	86	167
BuPu	6	9	6	129	15	124
BuPu	7	9	1	237	248	251
BuPu	7	9	2	191	211	230
BuPu	7	9	3	158	188	218
BuPu	7	9	4	140	150	198
BuPu	7	9	5	140	107	177
BuPu	7	9	6	136	65	157
BuPu	7	9	7	110	1	107
BuPu	8	9	1	247	252	253
BuPu	8	9	2	224	236	244
BuPu	8	9	3	191	211	230
BuPu	8	9	4	158	188	218
BuPu	8	9	5	140	150	198
BuPu	8	9	6	140	107	177
BuPu	8	9	7	136	65	157
BuPu	8	9	8	110	1	107
BuPu	9	9	1	247	252	253
BuPu	9	9	2	224	236	244
BuPu	9	9	3	191	211	230
BuPu	9	9	4	158	188	218
BuPu	9	9	5	140	150	198
BuPu	9	9	6	140	107	177
BuPu	9	9	7	136	65	157
BuPu	9	9	8	129	15	124
BuPu	9	9	9	77	0	75
GnBu	2	9	1	168	221	181
GnBu	2	9	2	67	162	202
GnBu	3	9	1	224	243	219
GnBu	3	9	2	168	221	181
GnBu	3	9	3	67	162	202
GnBu	4	9	1	240	249	232
GnBu	4	9	2	186	228	188
GnBu	4	9	3	123	204	196
GnBu	4	9	4	43	140	190
GnBu	5	9	1	240	249	232
GnBu	5	9	2	186	228	188
GnBu	5	9	3	123	204	196
GnBu	5	9	4	67	162	202
GnBu	5	9	5	8	104	172
GnBu	6	9	1	240	249	232
GnBu	6	9	2	204	235	197
GnBu	6	9	3	168	221	181
GnBu	6	9	4	123	204	196
GnBu	6	9	5	67	162	202
GnBu	6	9	6	8	104	172
GnBu	7	9	1	240	249	232
GnBu	7	9	2	204	235	197
GnBu	7	9	3	168	221	181
GnBu	7	9	4	123	204	196
GnBu	7	9	5	78	179	211
GnBu	7	9	6	43	140	190
GnBu	7	9	7	8	88	158
GnBu	8	9	1	247	252	240
GnBu	8	9	2	224	243	219
GnBu	8	9	3	204	235	197
GnBu	8	9	4	168	221	181
GnBu	8	9	5	123	204	196
GnBu	8	9	6	78	179	211
GnBu	8	9	7	43	140	190
GnBu	8	9	8	8	88	158
GnBu	9	9	1	247	252	240
GnBu	9	9	2	224	243	219
GnBu	9	9	3	204	235	197
GnBu	9	9	4	168	221	181
GnBu	9	9	5	123	204	196
GnBu	9	9	6	78	179	211
GnBu	9	9	7	43	140	190
GnBu	9	9	8	8	104	172
GnBu	9	9	9	8	64	129
Greens	2	9	1	161	217	155
Greens	2	9	2	49	163	84
Greens	3	9	1	229	245	224
Greens	3	9	2	161	217	155
Greens	3	9	3	49	163	84
Greens	4	9	1	237	248	233
Greens	4	9	2	186	228	179
Greens	4	9	3	116	196	118
Greens	4	9	4	35	139	69
Greens	5	9	1	237	248	233
Greens	5	9	2	186	228	179
Greens	5	9	3	116	196	118
Greens	5	9	4	49	163	84
Greens	5	9	5	0	109	44
Greens	6	9	1	237	248	233
Greens	6	9	2	199	233	192
Greens	6	9	3	161	217	155
Greens	6	9	4	116	196	118
Greens	6	9	5	49	163	84
Greens	6	9	6	0	109	44
Greens	7	9	1	237	248	233
Greens	7	9	2	199	233	192
Greens	7	9	3	161	217	155
Greens	7	9	4	116	196	118
Greens	7	9	5	65	171	93
Greens	7	9	6	35	139	69
Greens	7	9	7	0	90	50
Greens	8	9	1	247	252	245
Greens	8	9	2	229	245	224
Greens	8	9	3	199	233	192
Greens	8	9	4	161	217	155
Greens	8	9	5	116	196	118
Greens	8	9	6	65	171	93
Greens	8	9	7	35	139	69
Greens	8	9	8	0	90	50
Greens	9	9	1	247	252	245
Greens	9	9	2	229	245	224
Greens	9	9	3	199	233	192
Greens	9	9	4	161	217	155
Greens	9	9	5	116	196	118
Greens	9	9	6	65	171	93
Greens	9	9	7	35	139	69
Greens	9	9	8	0	109	44
Greens	9	9	9	0	68	27
Greys	2	9	1	189	189	189
Greys	2	9	2	99	99	99
Greys	3	9	1	240	240	240
Greys	3	9	2	189	189	189
Greys	3	9	3	99	99	99
Greys	4	9	1	247	247	247
Greys	4	9	2	204	204	204
Greys	4	9	3	150	150	150
Greys	4	9	4	82	82	82
Greys	5	9	1	247	247	247
Greys	5	9	2	204	204	204
Greys	5	9	3	150	150	150
Greys	5	9	4	99	99	99
Greys	5	9	5	37	37	37
Greys	6	9	1	247	247	247
Greys	6	9	2	217	217	217
Greys	6	9	3	189	189	189
Greys	6	9	4	150	150	150
Greys	6	9	5	99	99	99
Greys	6	9	6	37	37	37
Greys	7	9	1	247	247	247
Greys	7	9	2	217	217	217
Greys	7	9	3	189	189	189
Greys	7	9	4	150	150	150
Greys	7	9	5	115	115	115
Greys	7	9	6	82	82	82
Greys	7	9	7	37	37	37
Greys	8	9	1	255	255	255
Greys	8	9	2	240	240	240
Greys	8	9	3	217	217	217
Greys	8	9	4	189	189	189
Greys	8	9	5	150	150	150
Greys	8	9	6	115	115	115
Greys	8	9	7	82	82	82
Greys	8	9	8	37	37	37
Greys	9	9	1	255	255	255
Greys	9	9	2	240	240	240
Greys	9	9	3	217	217	217
Greys	9	9	4	189	189	189
Greys	9	9	5	150	150	150
Greys	9	9	6	115	115	115
Greys	9	9	7	82	82	82
Greys	9	9	8	37	37	37
Greys	9	9	9	0	0	0
Heat	2	16	1	255	255	0
Heat	2	16	2	255	0	0
Heat	3	16	1	255	255	0
Heat	3	16	2	255	128	0
Heat	3	16	3	255	0	0
Heat	4	16	1	255	255	128
Heat	4	16	2	255	255	0
Heat	4	16	3	255	128	0
Heat	4	16	4	255	0	0
Heat	5	16	1	255	255	128
Heat	5	16	2	255	255	0
Heat	5	16	3	255	170	0
Heat	5	16	4	255	85	0
Heat	5	16	5	255	0	0
Heat	6	16	1	255	255	128
Heat	6	16	2	255	255	0
Heat	6	16	3	255	191	0
Heat	6	16	4	255	128	0
Heat	6	16	5	255	64	0
Heat	6	16	6	255	0	0
Heat	7	16	1	255	255	128
Heat	7	16	2	255	255	0
Heat	7	16	3	255	204	0
Heat	7	16	4	255	153	0
Heat	7	16	5	255	102	0
Heat	7	16	6	255	51	0
Heat	7	16	7	255	0	0
Heat	8	16	1	255	255	191
Heat	8	16	2	255	255	64
Heat	8	16	3	255	255	0
Heat	8	16	4	255	204	0
Heat	8	16	5	255	153	0
Heat	8	16	6	255	102	0
Heat	8	16	7	255	51	0
Heat	8	16	8	255	0	0
Heat	9	16	1	255	255	191
Heat	9	16	2	255	255	64
Heat	9	16	3	255	255	0
Heat	9	16	4	255	213	0
Heat	9	16	5	255	170	0
Heat	9	16	6	255	128	0
Heat	9	16	7	255	85	0
Heat	9	16	8	255	42	0
Heat	9	16	9	255	0	0
Heat	10	16	1	255	255	191
Heat	10	16	2	255	255	64
Heat	10	16	3	255	255	0
Heat	10	16	4	255	219	0
Heat	10	16	5	255	182	0
Heat	10	16	6	255	146	0
Heat	10	16	7	255	109	0
Heat	10	16	8	255	73	0
Heat	10	16	9	255	36	0
Heat	10	16	10	255	0	0
Heat	11	16	1	255	255	191
Heat	11	16	2	255	255	64
Heat	11	16	3	255	255	0
Heat	11	16	4	255	223	0
Heat	11	16	5	255	191	0
Heat	11	16	6	255	159	0
Heat	11	16	7	255	128	0
Heat	11	16	8	255	96	0
Heat	11	16	9	255	64	0
Heat	11	16	10	255	32	0
Heat	11	16	11	255	0	0
Heat	12	16	1	255	255	213
Heat	12	16	2	255	255	128
Heat	12	16	3	255	255	42
Heat	12	16	4	255	255	0
Heat	12	16	5	255	223	0
Heat	12	16	6	255	191	0
Heat	12	16	7	255	159	0
Heat	12	16	8	255	128	0
Heat	12	16	9	255	96	0
Heat	12	16	10	255	64	0
Heat	12	16	11	255	32	0
Heat	12	16	12	255	0	0
Heat	13	16	1	255	255	213
Heat	13	16	2	255	255	128
Heat	13	16	3	255	255	42
Heat	13	16	4	255	255	0
Heat	13	16	5	255	227	0
Heat	13	16	6	255	198	0
Heat	13	16	7	255	170	0
Heat	13	16	8	255	142	0
Heat	13	16	9	255	113	0
Heat	13	16	10	255	85	0
Heat	13	16	11	255	57	0
Heat	13	16	12	255	28	0
Heat	13	16	13	255	0	0
Heat	14	16	1	255	255	213
Heat	14	16	2	255	255	128
Heat	14	16	3	255	255	42
Heat	14	16	4	255	255	0
Heat	14	16	5	255	229	0
Heat	14	16	6	255	204	0
Heat	14	16	7	255	178	0
Heat	14	16	8	255	153	0
Heat	14	16	9	255	128	0
Heat	14	16	10	255	102	0
Heat	14	16	11	255	77	0
Heat	14	16	12	255	51	0
Heat	14	16	13	255	26	0
Heat	14	16	14	255	0	0
Heat	15	16	1	255	255	213
Heat	15	16	2	255	255	128
Heat	15	16	3	255	255	42
Heat	15	16	4	255	255	0
Heat	15	16	5	255	232	0
Heat	15	16	6	255	209	0
Heat	15	16	7	255	185	0
Heat	15	16	8	255	162	0
Heat	15	16	9	255	139	0
Heat	15	16	10	255	116	0
Heat	15	16	11	255	93	0
Heat	15	16	12	255	70	0
Heat	15	16	13	255	46	0
Heat	15	16	14	255	23	0
Heat	15	16	15	255	0	0
Heat	16	16	1	255	255	223
Heat	16	16	2	255	255	159
Heat	16	16	3	255	255	96
Heat	16	16	4	255	255	32
Heat	16	16	5	255	255	0
Heat	16	16	6	255	232	0
Heat	16	16	7	255	209	0
Heat	16	16	8	255	185	0
Heat	16	16	9	255	162	0
Heat	16	16	10	255	139	0
Heat	16	16	11	255	116	0
Heat	16	16	12	255	93	0
Heat	16	16	13	255	70	0
Heat	16	16	14	255	46	0
Heat	16	16	15	255	23	0
Heat	16	16	16	255	0	0
OrRd	2	9	1	253	187	132
OrRd	2	9	2	227	74	51
OrRd	3	9	1	254	232	200
OrRd	3	9	2	253	187	132
OrRd	3	9	3	227	74	51
OrRd	4	9	1	254	240	217
OrRd	4	9	2	253	204	138
OrRd	4	9	3	252	141	89
OrRd	4	9	4	215	48	31
OrRd	5	9	1	254	240	217
OrRd	5	9	2	253	204	138
OrRd	5	9	3	252	141	89
OrRd	5	9	4	227	74	51
OrRd	5	9	5	179	0	0
OrRd	6	9	1	254	240	217
OrRd	6	9	2	253	212	158
OrRd	6	9	3	253	187	132
OrRd	6	9	4	252	141	89
OrRd	6	9	5	227	74	51
OrRd	6	9	6	179	0	0
OrRd	7	9	1	254	240	217
OrRd	7	9	2	253	212	158
OrRd	7	9	3	253	187	132
OrRd	7	9	4	252	141	89
OrRd	7	9	5	239	101	72
OrRd	7	9	6	215	48	31
OrRd	7	9	7	153	0	0
OrRd	8	9	1	255	247	236
OrRd	8	9	2	254	232	200
OrRd	8	9	3	253	212	158
OrRd	8	9	4	253	187	132
OrRd	8	9	5	252	141	89
OrRd	8	9	6	239	101	72
OrRd	8	9	7	215	48	31
OrRd	8	9	8	153	0	0
OrRd	9	9	1	255	247	236
OrRd	9	9	2	254	232	200
OrRd	9	9	3	253	212	158
OrRd	9	9	4	253	187	132
OrRd	9	9	5	252	141	89
OrRd	9	9	6	239	101	72
OrRd	9	9	7	215	48	31
OrRd	9	9	8	179	0	0
OrRd	9	9	9	127	0	0
Oranges	2	9	1	253	174	107
Oranges	2	9	2	230	85	13
Oranges	3	9	1	254	230	206
Oranges	3	9	2	253	174	107
Oranges	3	9	3	230	85	13
Oranges	4	9	1	254	237	222
Oranges	4	9	2	253	190	133
Oranges	4	9	3	253	141	60
Oranges	4	9	4	217	71	1
Oranges	5	9	1	254	237	222
Oranges	5	9	2	253	190	133
Oranges	5	9	3	253	141	60
Oranges	5	9	4	230	85	13
Oranges	5	9	5	166	54	3
Oranges	6	9	1	254	237	222
Oranges	6	9	2	253	208	162
Oranges	6	9	3	253	174	107
Oranges	6	9	4	253	141	60
Oranges	6	9	5	230	85	13
Oranges	6	9	6	166	54	3
Oranges	7	9	1	254	237	222
Oranges	7	9	2	253	208	162
Oranges	7	9	3	253	174	107
Oranges	7	9	4	253	141	60
Oranges	7	9	5	241	105	19
Oranges	7	9	6	217	72	1
Oranges	7	9	7	140	45	4
Oranges	8	9	1	255	245	235
Oranges	8	9	2	254	230	206
Oranges	8	9	3	253	208	162
Oranges	8	9	4	253	174	107
Oranges	8	9	5	253	141	60
Oranges	8	9	6	241	105	19
Oranges	8	9	7	217	72	1
Oranges	8	9	8	140	45	4
Oranges	9	9	1	255	245	235
Oranges	9	9	2	254	230	206
Oranges	9	9	3	253	208	162
Oranges	9	9	4	253	174	107
Oranges	9	9	5	253	141	60
Oranges	9	9	6	241	105	19
Oranges	9	9	7	217	72	1
Oranges	9	9	8	166	54	3
Oranges	9	9	9	127	39	4
PuBu	2	9	1	166	189	219
PuBu	2	9	2	43	140	190
PuBu	3	9	1	236	231	242
PuBu	3	9	2	166	189	219
PuBu	3	9	3	43	140	190
PuBu	4	9	1	241	238	246
PuBu	4	9	2	189	201	225
PuBu	4	9	3	116	169	207
PuBu	4	9	4	5	112	176
PuBu	5	9	1	241	238	246
PuBu	5	9	2	189	201	225
PuBu	5	9	3	116	169	207
PuBu	5	9	4	43	140	190
PuBu	5	9	5	4	90	141
PuBu	6	9	1	241	238	246
PuBu	6	9	2	208	209	230
PuBu	6	9	3	166	189	219
PuBu	6	9	4	116	169	207
PuBu	6	9	5	43	140	190
PuBu	6	9	6	4	90	141
PuBu	7	9	1	241	238	246
PuBu	7	9	2	208	209	230
PuBu	7	9	3	166	189	219
PuBu	7	9	4	116	169	207
PuBu	7	9	5	54	144	192
PuBu	7	9	6	5	112	176
PuBu	7	9	7	3	78	123
PuBu	8	9	1	255	247	251
PuBu	8	9	2	236	231	242
PuBu	8	9	3	208	209	230
PuBu	8	9	4	166	189	219
PuBu	8	9	5	116	169	207
PuBu	8	9	6	54	144	192
PuBu	8	9	7	5	112	176
PuBu	8	9	8	3	78	123
PuBu	9	9	1	255	247	251
PuBu	9	9	2	236	231	242
PuBu	9	9	3	208	209	230
PuBu	9	9	4	166	189	219
PuBu	9	9	5	116	169	207
PuBu	9	9	6	54	144	192
PuBu	9	9	7	5	112	176
PuBu	9	9	8	4	90	141
PuBu	9	9	9	2	56	88
PuBuGn	2	9	1	166	189	219
PuBuGn	2	9	2	28	144	153
PuBuGn	3	9	1	236	226	240
PuBuGn	3	9	2	166	189	219
PuBuGn	3	9	3	28	144	153
PuBuGn	4	9	1	246	239	247
PuBuGn	4	9	2	189	201	225
PuBuGn	4	9	3	103	169	207
PuBuGn	4	9	4	2	129	138
PuBuGn	5	9	1	246	239	247
PuBuGn	5	9	2	189	201	225
PuBuGn	5	9	3	103	169	207
PuBuGn	5	9	4	28	144	153
PuBuGn	5	9	5	1	108	89
PuBuGn	6	9	1	246	239	247
PuBuGn	6	9	2	208	209	230
PuBuGn	6	9	3	166	189	219
PuBuGn	6	9	4	103	169	207
PuBuGn	6	9	5	28	144	153
PuBuGn	6	9	6	1	108	89
PuBuGn	7	9	1	246	239	247
PuBuGn	7	9	2	208	209	230
PuBuGn	7	9	3	166	189	219
PuBuGn	7	9	4	103	169	207
PuBuGn	7	9	5	54	144	192
PuBuGn	7	9	6	2	129	138
PuBuGn	7	9	7	1	100	80
PuBuGn	8	9	1	255	247	251
PuBuGn	8	9	2	236	226	240
PuBuGn	8	9	3	208	209	230
PuBuGn	8	9	4	166	189	219
PuBuGn	8	9	5	103	169	207
PuBuGn	8	9	6	54	144	192
PuBuGn	8	9	7	2	129	138
PuBuGn	8	9	8	1	100	80
PuBuGn	9	9	1	255	247	251
PuBuGn	9	9	2	236	226	240
PuBuGn	9	9	3	208	209	230
PuBuGn	9	9	4	166	189	219
PuBuGn	9	9	5	103	169	207
PuBuGn	9	9	6	54	144	192
PuBuGn	9	9	7	2	129	138
PuBuGn	9	9	8	1	108	89
PuBuGn	9	9	9	1	70	54
PuRd	2	9	1	201	148	199
PuRd	2	9	2	221	28	119
PuRd	3	9	1	231	225	239
PuRd	3	9	2	201	148	199
PuRd	3	9	3	221	28	119
PuRd	4	9	1	241	238	246
PuRd	4	9	2	215	181	216
PuRd	4	9	3	223	101	176
PuRd	4	9	4	206	18	86
PuRd	5	9	1	241	238	246
PuRd	5	9	2	215	181	216
PuRd	5	9	3	223	101	176
PuRd	5	9	4	221	28	119
PuRd	5	9	5	152	0	67
PuRd	6	9	1	241	238	246
PuRd	6	9	2	212	185	218
PuRd	6	9	3	201	148	199
PuRd	6	9	4	223	101	176
PuRd	6	9	5	221	28	119
PuRd	6	9	6	152	0	67
PuRd	7	9	1	241	238	246
PuRd	7	9	2	212	185	218
PuRd	7	9	3	201	148	199
PuRd	7	9	4	223	101	176
PuRd	7	9	5	231	41	138
PuRd	7	9	6	206	18	86
PuRd	7	9	7	145	0	63
PuRd	8	9	1	247	244	249
PuRd	8	9	2	231	225	239
PuRd	8	9	3	212	185	218
PuRd	8	9	4	201	148	199
PuRd	8	9	5	223	101	176
PuRd	8	9	6	231	41	138
PuRd	8	9	7	206	18	86
PuRd	8	9	8	145	0	63
PuRd	9	9	1	247	244	249
PuRd	9	9	2	231	225	239
PuRd	9	9	3	212	185	218
PuRd	9	9	4	201	148	199
PuRd	9	9	5	223	101	176
PuRd	9	9	6	231	41	138
PuRd	9	9	7	206	18	86
PuRd	9	9	8	152	0	67
PuRd	9	9	9	103	0	31
Purples	2	9	1	188	189	220
Purples	2	9	2	117	107	177
Purples	3	9	1	239	237	245
Purples	3	9	2	188	189	220
Purples	3	9	3	117	107	177
Purples	4	9	1	242	240	247
Purples	4	9	2	203	201	226
Purples	4	9	3	158	154	200
Purples	4	9	4	106	81	163
Purples	5	9	1	242	240	247
Purples	5	9	2	203	201	226
Purples	5	9	3	158	154	200
Purples	5	9	4	117	107	177
Purples	5	9	5	84	39	143
Purples	6	9	1	242	240	247
Purples	6	9	2	218	218	235
Purples	6	9	3	188	189	220
Purples	6	9	4	158	154	200
Purples	6	9	5	117	107	177
Purples	6	9	6	84	39	143
Purples	7	9	1	242	240	247
Purples	7	9	2	218	218	235
Purples	7	9	3	188	189	220
Purples	7	9	4	158	154	200
Purples	7	9	5	128	125	186
Purples	7	9	6	106	81	163
Purples	7	9	7	74	20	134
Purples	8	9	1	252	251	253
Purples	8	9	2	239	237	245
Purples	8	9	3	218	218	235
Purples	8	9	4	188	189	220
Purples	8	9	5	158	154	200
Purples	8	9	6	128	125	186
Purples	8	9	7	106	81	163
Purples	8	9	8	74	20	134
Purples	9	9	1	252	251	253
Purples	9	9	2	239	237	245
Purples	9	9	3	218	218	235
Purples	9	9	4	188	189	220
Purples	9	9	5	158	154	200
Purples	9	9	6	128	125	186
Purples	9	9	7	106	81	163
Purples	9	9	8	84	39	143
Purples	9	9	9	63	0	125
RdPu	2	9	1	250	159	181
RdPu	2	9	2	197	27	138
RdPu	3	9	1	253	224	221
RdPu	3	9	2	250	159	181
RdPu	3	9	3	197	27	138
RdPu	4	9	1	254	235	226
RdPu	4	9	2	251	180	185
RdPu	4	9	3	247	104	161
RdPu	4	9	4	174	1	126
RdPu	5	9	1	254	235	226
RdPu	5	9	2	251	180	185
RdPu	5	9	3	247	104	161
RdPu	5	9	4	197	27	138
RdPu	5	9	5	122	1	119
RdPu	6	9	1	254	235	226
RdPu	6	9	2	252	197	192
RdPu	6	9	3	250	159	181
RdPu	6	9	4	247	104	161
RdPu	6	9	5	197	27	138
RdPu	6	9	6	122	1	119
RdPu	7	9	1	254	235	226
RdPu	7	9	2	252	197	192
RdPu	7	9	3	250	159	181
RdPu	7	9	4	247	104	161
RdPu	7	9	5	221	52	151
RdPu	7	9	6	174	1	126
RdPu	7	9	7	122	1	119
RdPu	8	9	1	255	247	243
RdPu	8	9	2	253	224	221
RdPu	8	9	3	252	197	192
RdPu	8	9	4	250	159	181
RdPu	8	9	5	247	104	161
RdPu	8	9	6	221	52	151
RdPu	8	9	7	174	1	126
RdPu	8	9	8	122	1	119
RdPu	9	9	1	255	247	243
RdPu	9	9	2	253	224	221
RdPu	9	9	3	252	197	192
RdPu	9	9	4	250	159	181
RdPu	9	9	5	247	104	161
RdPu	9	9	6	221	52	151
RdPu	9	9	7	174	1	126
RdPu	9	9	8	122	1	119
RdPu	9	9	9	73	0	106
Reds	2	9	1	252	146	114
Reds	2	9	2	222	45	38
Reds	3	9	1	254	224	210
Reds	3	9	2	252	146	114
Reds	3	9	3	222	45	38
Reds	4	9	1	254	229	217
Reds	4	9	2	252	174	145
Reds	4	9	3	251	106	74
Reds	4	9	4	203	24	29
Reds	5	9	1	254	229	217
Reds	5	9	2	252	174	145
Reds	5	9	3	251	106	74
Reds	5	9	4	222	45	38
Reds	5	9	5	165	15	21
Reds	6	9	1	254	229	217
Reds	6	9	2	252	187	161
Reds	6	9	3	252	146	114
Reds	6	9	4	251	106	74
Reds	6	9	5	222	45	38
Reds	6	9	6	165	15	21
Reds	7	9	1	254	229	217
Reds	7	9	2	252	187	161
Reds	7	9	3	252	146	114
Reds	7	9	4	251	106	74
Reds	7	9	5	239	59	44
Reds	7	9	6	203	24	29
Reds	7	9	7	153	0	13
Reds	8	9	1	255	245	240
Reds	8	9	2	254	224	210
Reds	8	9	3	252	187	161
Reds	8	9	4	252	146	114
Reds	8	9	5	251	106	74
Reds	8	9	6	239	59	44
Reds	8	9	7	203	24	29
Reds	8	9	8	153	0	13
Reds	9	9	1	255	245	240
Reds	9	9	2	254	224	210
Reds	9	9	3	252	187	161
Reds	9	9	4	252	146	114
Reds	9	9	5	251	106	74
Reds	9	9	6	239	59	44
Reds	9	9	7	203	24	29
Reds	9	9	8	165	15	21
Reds	9	9	9	103	0	13
Terrain	2	16	1	0	166	0
Terrain	2	16	2	242	242	242
Terrain	3	16	1	0	166	0
Terrain	3	16	2	236	177	118
Terrain	3	16	3	242	242	242
Terrain	4	16	1	0	166	0
Terrain	4	16	2	230	230	0
Terrain	4	16	3	236	177	118
Terrain	4	16	4	242	242	242
Terrain	5	16	1	0	166	0
Terrain	5	16	2	230	230	0
Terrain	5	16	3	234	182	78
Terrain	5	16	4	238	185	159
Terrain	5	16	5	242	242	242
Terrain	6	16	1	0	166	0
Terrain	6	16	2	99	198	0
Terrain	6	16	3	230	230	0
Terrain	6	16	4	234	182	78
Terrain	6	16	5	238	185	159
Terrain	6	16	6	242	242	242
Terrain	7	16	1	0	166	0
Terrain	7	16	2	99	198	0
Terrain	7	16	3	230	230	0
Terrain	7	16	4	233	189	58
Terrain	7	16	5	236	177	118
Terrain	7	16	6	239	194	179
Terrain	7	16	7	242	242	242
Terrain	8	16	1	0	166	0
Terrain	8	16	2	62	187	0
Terrain	8	16	3	139	208	0
Terrain	8	16	4	230	230	0
Terrain	8	16	5	233	189	58
Terrain	8	16	6	236	177	118
Terrain	8	16	7	239	194	179
Terrain	8	16	8	242	242	242
Terrain	9	16	1	0	166	0
Terrain	9	16	2	62	187	0
Terrain	9	16	3	139	208	0
Terrain	9	16	4	230	230	0
Terrain	9	16	5	232	195	46
Terrain	9	16	6	235	178	94
Terrain	9	16	7	237	180	142
Terrain	9	16	8	240	201	192
Terrain	9	16	9	242	242	242
Terrain	10	16	1	0	166	0
Terrain	10	16	2	45	182	0
Terrain	10	16	3	99	198	0
Terrain	10	16	4	160	214	0
Terrain	10	16	5	230	230	0
Terrain	10	16	6	232	195	46
Terrain	10	16	7	235	178	94
Terrain	10	16	8	237	180	142
Terrain	10	16	9	240	201	192
Terrain	10	16	10	242	242	242
Terrain	11	16	1	0	166	0
Terrain	11	16	2	45	182	0
Terrain	11	16	3	99	198	0
Terrain	11	16	4	160	214	0
Terrain	11	16	5	230	230	0
Terrain	11	16	6	232	199	39
Terrain	11	16	7	234	182	78
Terrain	11	16	8	236	177	118
Terrain	11	16	9	238	185	159
Terrain	11	16	10	240	207	200
Terrain	11	16	11	242	242	242
Terrain	12	16	1	0	166	0
Terrain	12	16	2	36	179	0
Terrain	12	16	3	76	191	0
Terrain	12	16	4	122	204	0
Terrain	12	16	5	173	217	0
Terrain	12	16	6	230	230	0
Terrain	12	16	7	232	199	39
Terrain	12	16	8	234	182	78
Terrain	12	16	9	236	177	118
Terrain	12	16	10	238	185	159
Terrain	12	16	11	240	207	200
Terrain	12	16	12	242	242	242
Terrain	13	16	1	0	166	0
Terrain	13	16	2	36	179	0
Terrain	13	16	3	76	191	0
Terrain	13	16	4	122	204	0
Terrain	13	16	5	173	217	0
Terrain	13	16	6	230	230	0
Terrain	13	16	7	231	203	33
Terrain	13	16	8	233	186	67
Terrain	13	16	9	235	177	101
Terrain	13	16	10	237	179	135
Terrain	13	16	11	239	190	170
Terrain	13	16	12	240	211	206
Terrain	13	16	13	242	242	242
Terrain	14	16	1	0	166	0
Terrain	14	16	2	29	176	0
Terrain	14	16	3	62	187	0
Terrain	14	16	4	99	198	0
Terrain	14	16	5	139	208	0
Terrain	14	16	6	182	219	0
Terrain	14	16	7	230	230	0
Terrain	14	16	8	231	203	33
Terrain	14	16	9	233	186	67
Terrain	14	16	10	235	177	101
Terrain	14	16	11	237	179	135
Terrain	14	16	12	239	190	170
Terrain	14	16	13	240	211	206
Terrain	14	16	14	242	242	242
Terrain	15	16	1	0	166	0
Terrain	15	16	2	29	176	0
Terrain	15	16	3	62	187	0
Terrain	15	16	4	99	198	0
Terrain	15	16	5	139	208	0
Terrain	15	16	6	182	219	0
Terrain	15	16	7	230	230	0
Terrain	15	16	8	231	206	29
Terrain	15	16	9	233	189	58
Terrain	15	16	10	234	179	88
Terrain	15	16	11	236	177	118
Terrain	15	16	12	237	182	148
Terrain	15	16	13	239	194	179
Terrain	15	16	14	241	214	211
Terrain	15	16	15	242	242	242
Terrain	16	16	1	0	166	0
Terrain	16	16	2	25	175	0
Terrain	16	16	3	53	184	0
Terrain	16	16	4	83	193	0
Terrain	16	16	5	116	202	0
Terrain	16	16	6	151	211	0
Terrain	16	16	7	189	220	0
Terrain	16	16	8	230	230	0
Terrain	16	16	9	231	206	29
Terrain	16	16	10	233	189	58
Terrain	16	16	11	234	179	88
Terrain	16	16	12	236	177	118
Terrain	16	16	13	237	182	148
Terrain	16	16	14	239	194	179
Terrain	16	16	15	241	214	211
Terrain	16	16	16	242	242	242
Topological	2	16	1	76	0	255
Topological	2	16	2	0	229	255
Topological	3	16	1	76	0	255
Topological	3	16	2	0	255	77
Topological	3	16	3	255	255	0
Topological	4	16	1	76	0	255
Topological	4	16	2	0	229	255
Topological	4	16	3	0	255	77
Topological	4	16	4	255	255	0
Topological	5	16	1	76	0	255
Topological	5	16	2	0	76	255
Topological	5	16	3	0	229	255
Topological	5	16	4	0	255	77
Topological	5	16	5	255	255	0
Topological	6	16	1	76	0	255
Topological	6	16	2	0	229	255
Topological	6	16	3	0	255	77
Topological	6	16	4	230	255	0
Topological	6	16	5	255	255	0
Topological	6	16	6	255	224	178
Topological	7	16	1	76	0	255
Topological	7	16	2	0	76	255
Topological	7	16	3	0	229	255
Topological	7	16	4	0	255	77
Topological	7	16	5	230	255	0
Topological	7	16	6	255	255	0
Topological	7	16	7	255	224	178
Topological	8	16	1	76	0	255
Topological	8	16	2	0	25	255
Topological	8	16	3	0	128	255
Topological	8	16	4	0	229	255
Topological	8	16	5	0	255	77
Topological	8	16	6	230	255	0
Topological	8	16	7	255	255	0
Topological	8	16	8	255	224	178
Topological	9	16	1	76	0	255
Topological	9	16	2	0	76	255
Topological	9	16	3	0	229	255
Topological	9	16	4	0	255	77
Topological	9	16	5	77	255	0
Topological	9	16	6	230	255	0
Topological	9	16	7	255	255	0
Topological	9	16	8	255	222	89
Topological	9	16	9	255	224	178
Topological	10	16	1	76	0	255
Topological	10	16	2	0	25	255
Topological	10	16	3	0	128	255
Topological	10	16	4	0	229	255
Topological	10	16	5	0	255	77
Topological	10	16	6	77	255	0
Topological	10	16	7	230	255	0
Topological	10	16	8	255	255	0
Topological	10	16	9	255	222	89
Topological	10	16	10	255	224	178
Topological	11	16	1	76	0	255
Topological	11	16	2	0	0	255
Topological	11	16	3	0	76	255
Topological	11	16	4	0	153	255
Topological	11	16	5	0	229	255
Topological	11	16	6	0	255	77
Topological	11	16	7	77	255	0
Topological	11	16	8	230	255	0
Topological	11	16	9	255	255	0
Topological	11	16	10	255	222	89
Topological	11	16	11	255	224	178
Topological	12	16	1	76	0	255
Topological	12	16	2	0	25	255
Topological	12	16	3	0	128	255
Topological	12	16	4	0	229	255
Topological	12	16	5	0	255	77
Topological	12	16	6	26	255	0
Topological	12	16	7	128	255	0
Topological	12	16	8	230	255	0
Topological	12	16	9	255	255	0
Topological	12	16	10	255	229	59
Topological	12	16	11	255	219	119
Topological	12	16	12	255	224	178
Topological	13	16	1	76	0	255
Topological	13	16	2	0	0	255
Topological	13	16	3	0	76	255
Topological	13	16	4	0	153	255
Topological	13	16	5	0	229	255
Topological	13	16	6	0	255	77
Topological	13	16	7	26	255	0
Topological	13	16	8	128	255	0
Topological	13	16	9	230	255	0
Topological	13	16	10	255	255	0
Topological	13	16	11	255	229	59
Topological	13	16	12	255	219	119
Topological	13	16	13	255	224	178
Topological	14	16	1	76	0	255
Topological	14	16	2	15	0	255
Topological	14	16	3	0	46	255
Topological	14	16	4	0	107	255
Topological	14	16	5	0	168	255
Topological	14	16	6	0	229	255
Topological	14	16	7	0	255	77
Topological	14	16	8	26	255	0
Topological	14	16	9	128	255	0
Topological	14	16	10	230	255	0
Topological	14	16	11	255	255	0
Topological	14	16	12	255	229	59
Topological	14	16	13	255	219	119
Topological	14	16	14	255	224	178
Topological	15	16	1	76	0	255
Topological	15	16	2	0	0	255
Topological	15	16	3	0	76	255
Topological	15	16	4	0	153	255
Topological	15	16	5	0	229	255
Topological	15	16	6	0	255	77
Topological	15	16	7	0	255	0
Topological	15	16	8	77	255	0
Topological	15	16	9	153	255	0
Topological	15	16	10	230	255	0
Topological	15	16	11	255	255	0
Topological	15	16	12	255	234	45
Topological	15	16	13	255	222	89
Topological	15	16	14	255	219	134
Topological	15	16	15	255	224	178
Topological	16	16	1	76	0	255
Topological	16	16	2	15	0	255
Topological	16	16	3	0	46	255
Topological	16	16	4	0	107	255
Topological	16	16	5	0	168	255
Topological	16	16	6	0	229	255
Topological	16	16	7	0	255	77
Topological	16	16	8	0	255	0
Topological	16	16	9	77	255	0
Topological	16	16	10	153	255	0
Topological	16	16	11	230	255	0
Topological	16	16	12	255	255	0
Topological	16	16	13	255	234	45
Topological	16	16	14	255	222	89
Topological	16	16	15	255	219	134
Topological	16	16	16	255	224	178
YlGn	2	9	1	173	221	142
YlGn	2	9	2	49	163	84
YlGn	3	9	1	247	252	185
YlGn	3	9	2	173	221	142
YlGn	3	9	3	49	163	84
YlGn	4	9	1	255	255	204
YlGn	4	9	2	194	230	153
YlGn	4	9	3	120	198	121
YlGn	4	9	4	35	132	67
YlGn	5	9	1	255	255	204
YlGn	5	9	2	194	230	153
YlGn	5	9	3	120	198	121
YlGn	5	9	4	49	163	84
YlGn	5	9	5	0	104	55
YlGn	6	9	1	255	255	204
YlGn	6	9	2	217	240	163
YlGn	6	9	3	173	221	142
YlGn	6	9	4	120	198	121
YlGn	6	9	5	49	163	84
YlGn	6	9	6	0	104	55
YlGn	7	9	1	255	255	204
YlGn	7	9	2	217	240	163
YlGn	7	9	3	173	221	142
YlGn	7	9	4	120	198	121
YlGn	7	9	5	65	171	93
YlGn	7	9	6	35	132	67
YlGn	7	9	7	0	90	50
YlGn	8	9	1	255	255	229
YlGn	8	9	2	247	252	185
YlGn	8	9	3	217	240	163
YlGn	8	9	4	173	221	142
YlGn	8	9	5	120	198	121
YlGn	8	9	6	65	171	93
YlGn	8	9	7	35	132	67
YlGn	8	9	8	0	90	50
YlGn	9	9	1	255	255	229
YlGn	9	9	2	247	252	185
YlGn	9	9	3	217	240	163
YlGn	9	9	4	173	221	142
YlGn	9	9	5	120	198	121
YlGn	9	9	6	65	171	93
YlGn	9	9	7	35	132	67
YlGn	9	9	8	0	104	55
YlGn	9	9	9	0	69	41
YlGnBu	2	9	1	127	205	187
YlGnBu	2	9	2	44	127	184
YlGnBu	3	9	1	237	248	177
YlGnBu	3	9	2	127	205	187
YlGnBu	3	9	3	44	127	184
YlGnBu	4	9	1	255	255	204
YlGnBu	4	9	2	161	218	180
YlGnBu	4	9	3	65	182	196
YlGnBu	4	9	4	34	94	168
YlGnBu	5	9	1	255	255	204
YlGnBu	5	9	2	161	218	180
YlGnBu	5	9	3	65	182	196
YlGnBu	5	9	4	44	127	184
YlGnBu	5	9	5	37	52	148
YlGnBu	6	9	1	255	255	204
YlGnBu	6	9	2	199	233	180
YlGnBu	6	9	3	127	205	187
YlGnBu	6	9	4	65	182	196
YlGnBu	6	9	5	44	127	184
YlGnBu	6	9	6	37	52	148
YlGnBu	7	9	1	255	255	204
YlGnBu	7	9	2	199	233	180
YlGnBu	7	9	3	127	205	187
YlGnBu	7	9	4	65	182	196
YlGnBu	7	9	5	29	145	192
YlGnBu	7	9	6	34	94	168
YlGnBu	7	9	7	12	44	132
YlGnBu	8	9	1	255	255	217
YlGnBu	8	9	2	237	248	177
YlGnBu	8	9	3	199	233	180
YlGnBu	8	9	4	127	205	187
YlGnBu	8	9	5	65	182	196
YlGnBu	8	9	6	29	145	192
YlGnBu	8	9	7	34	94	168
YlGnBu	8	9	8	12	44	132
YlGnBu	9	9	1	255	255	217
YlGnBu	9	9	2	237	248	177
YlGnBu	9	9	3	199	233	180
YlGnBu	9	9	4	127	205	187
YlGnBu	9	9	5	65	182	196
YlGnBu	9	9	6	29	145	192
YlGnBu	9	9	7	34	94	168
YlGnBu	9	9	8	37	52	148
YlGnBu	9	9	9	8	29	88
YlOrBr	2	9	1	254	196	79
YlOrBr	2	9	2	217	95	14
YlOrBr	3	9	1	255	247	188
YlOrBr	3	9	2	254	196	79
YlOrBr	3	9	3	217	95	14
YlOrBr	4	9	1	255	255	212
YlOrBr	4	9	2	254	217	142
YlOrBr	4	9	3	254	153	41
YlOrBr	4	9	4	204	76	2
YlOrBr	5	9	1	255	255	212
YlOrBr	5	9	2	254	217	142
YlOrBr	5	9	3	254	153	41
YlOrBr	5	9	4	217	95	14
YlOrBr	5	9	5	153	52	4
YlOrBr	6	9	1	255	255	212
YlOrBr	6	9	2	254	227	145
YlOrBr	6	9	3	254	196	79
YlOrBr	6	9	4	254	153	41
YlOrBr	6	9	5	217	95	14
YlOrBr	6	9	6	153	52	4
YlOrBr	7	9	1	255	255	212
YlOrBr	7	9	2	254	227	145
YlOrBr	7	9	3	254	196	79
YlOrBr	7	9	4	254	153	41
YlOrBr	7	9	5	236	112	20
YlOrBr	7	9	6	204	76	2
YlOrBr	7	9	7	140	45	4
YlOrBr	8	9	1	255	255	229
YlOrBr	8	9	2	255	247	188
YlOrBr	8	9	3	254	227	145
YlOrBr	8	9	4	254	196	79
YlOrBr	8	9	5	254	153	41
YlOrBr	8	9	6	236	112	20
YlOrBr	8	9	7	204	76	2
YlOrBr	8	9	8	140	45	4
YlOrBr	9	9	1	255	255	229
YlOrBr	9	9	2	255	247	188
YlOrBr	9	9	3	254	227	145
YlOrBr	9	9	4	254	196	79
YlOrBr	9	9	5	254	153	41
YlOrBr	9	9	6	236	112	20
YlOrBr	9	9	7	204	76	2
YlOrBr	9	9	8	153	52	4
YlOrBr	9	9	9	102	37	6
YlOrRd	2	9	1	254	178	76
YlOrRd	2	9	2	240	59	32
YlOrRd	3	9	1	255	237	160
YlOrRd	3	9	2	254	178	76
YlOrRd	3	9	3	240	59	32
YlOrRd	4	9	1	255	255	178
YlOrRd	4	9	2	254	204	92
YlOrRd	4	9	3	253	141	60
YlOrRd	4	9	4	227	26	28
YlOrRd	5	9	1	255	255	178
YlOrRd	5	9	2	254	204	92
YlOrRd	5	9	3	253	141	60
YlOrRd	5	9	4	240	59	32
YlOrRd	5	9	5	189	0	38
YlOrRd	6	9	1	255	255	178
YlOrRd	6	9	2	254	217	118
YlOrRd	6	9	3	254	178	76
YlOrRd	6	9	4	253	141	60
YlOrRd	6	9	5	240	59	32
YlOrRd	6	9	6	189	0	38
YlOrRd	7	9	1	255	255	178
YlOrRd	7	9	2	254	217	118
YlOrRd	7	9	3	254	178	76
YlOrRd	7	9	4	253	141	60
YlOrRd	7	9	5	252	78	42
YlOrRd	7	9	6	227	26	28
YlOrRd	7	9	7	177	0	38
YlOrRd	8	9	1	255	255	204
YlOrRd	8	9	2	255	237	160
YlOrRd	8	9	3	254	217	118
YlOrRd	8	9	4	254	178	76
YlOrRd	8	9	5	253	141	60
YlOrRd	8	9	6	252	78	42
YlOrRd	8	9	7	227	26	28
YlOrRd	8	9	8	177	0	38
YlOrRd	9	9	1	255	255	204
YlOrRd	9	9	2	255	237	160
YlOrRd	9	9	3	254	217	118
YlOrRd	9	9	4	254	178	76
YlOrRd	9	9	5	253	141	60
YlOrRd	9	9	6	252	78	42
YlOrRd	9	9	7	227	26	28
YlOrRd	9	9	8	189	0	38
YlOrRd	9	9	9	128	0	38
BrBG	2	11	1	216	179	101
BrBG	2	11	2	90	180	172
BrBG	3	11	1	216	179	101
BrBG	3	11	2	245	245	245
BrBG	3	11	3	90	180	172
BrBG	4	11	1	166	97	26
BrBG	4	11	2	223	194	125
BrBG	4	11	3	128	205	193
BrBG	4	11	4	1	133	113
BrBG	5	11	1	166	97	26
BrBG	5	11	2	223	194	125
BrBG	5	11	3	245	245	245
BrBG	5	11	4	128	205	193
BrBG	5	11	5	1	133	113
BrBG	6	11	1	140	81	10
BrBG	6	11	2	216	179	101
BrBG	6	11	3	246	232	195
BrBG	6	11	4	199	234	229
BrBG	6	11	5	90	180	172
BrBG	6	11	6	1	102	94
BrBG	7	11	1	140	81	10
BrBG	7	11	2	216	179	101
BrBG	7	11	3	246	232	195
BrBG	7	11	4	245	245	245
BrBG	7	11	5	199	234	229
BrBG	7	11	6	90	180	172
BrBG	7	11	7	1	102	94
BrBG	8	11	1	140	81	10
BrBG	8	11	2	191	129	45
BrBG	8	11	3	223	194	125
BrBG	8	11	4	246	232	195
BrBG	8	11	5	199	234	229
BrBG	8	11	6	128	205	193
BrBG	8	11	7	53	151	143
BrBG	8	11	8	1	102	94
BrBG	9	11	1	140	81	10
BrBG	9	11	2	191	129	45
BrBG	9	11	3	223	194	125
BrBG	9	11	4	246	232	195
BrBG	9	11	5	245	245	245
BrBG	9	11	6	199	234	229
BrBG	9	11	7	128	205	193
BrBG	9	11	8	53	151	143
BrBG	9	11	9	1	102	94
BrBG	10	11	1	84	48	5
BrBG	10	11	2	140	81	10
BrBG	10	11	3	191	129	45
BrBG	10	11	4	223	194	125
BrBG	10	11	5	246	232	195
BrBG	10	11	6	199	234	229
BrBG	10	11	7	128	205	193
BrBG	10	11	8	53	151	143
BrBG	10	11	9	1	102	94
BrBG	10	11	10	0	60	48
BrBG	11	11	1	84	48	5
BrBG	11	11	2	140	81	10
BrBG	11	11	3	191	129	45
BrBG	11	11	4	223	194	125
BrBG	11	11	5	246	232	195
BrBG	11	11	6	245	245	245
BrBG	11	11	7	199	234	229
BrBG	11	11	8	128	205	193
BrBG	11	11	9	53	151	143
BrBG	11	11	10	1	102	94
BrBG	11	11	11	0	60	48
BuRd	2	11	1	103	169	207
BuRd	2	11	2	239	138	98
BuRd	3	11	1	103	169	207
BuRd	3	11	2	247	247	247
BuRd	3	11	3	239	138	98
BuRd	4	11	1	5	113	176
BuRd	4	11	2	146	197	222
BuRd	4	11	3	244	165	130
BuRd	4	11	4	202	0	32
BuRd	5	11	1	5	113	176
BuRd	5	11	2	146	197	222
BuRd	5	11	3	247	247	247
BuRd	5	11	4	244	165	130
BuRd	5	11	5	202	0	32
BuRd	6	11	1	33	102	172
BuRd	6	11	2	103	169	207
BuRd	6	11	3	209	229	240
BuRd	6	11	4	253	219	199
BuRd	6	11	5	239	138	98
BuRd	6	11	6	178	24	43
BuRd	7	11	1	33	102	172
BuRd	7	11	2	103	169	207
BuRd	7	11	3	209	229	240
BuRd	7	11	4	247	247	247
BuRd	7	11	5	253	219	199
BuRd	7	11	6	239	138	98
BuRd	7	11	7	178	24	43
BuRd	8	11	1	33	102	172
BuRd	8	11	2	67	147	195
BuRd	8	11	3	146	197	222
BuRd	8	11	4	209	229	240
BuRd	8	11	5	253	219	199
BuRd	8	11	6	244	165	130
BuRd	8	11	7	214	96	77
BuRd	8	11	8	178	24	43
BuRd	9	11	1	33	102	172
BuRd	9	11	2	67	147	195
BuRd	9	11	3	146	197	222
BuRd	9	11	4	209	229	240
BuRd	9	11	5	247	247	247
BuRd	9	11	6	253	219	199
BuRd	9	11	7	244	165	130
BuRd	9	11	8	214	96	77
BuRd	9	11	9	178	24	43
BuRd	10	11	1	5	48	97
BuRd	10	11	2	33	102	172
BuRd	10	11	3	67	147	195
BuRd	10	11	4	146	197	222
BuRd	10	11	5	209	229	240
BuRd	10	11	6	253	219	199
BuRd	10	11	7	244	165	130
BuRd	10	11	8	214	96	77
BuRd	10	11	9	178	24	43
BuRd	10	11	10	103	0	31
BuRd	11	11	1	5	48	97
BuRd	11	11	2	33	102	172
BuRd	11	11	3	67	147	195
BuRd	11	11	4	146	197	222
BuRd	11	11	5	209	229	240
BuRd	11	11	6	247	247	247
BuRd	11	11	7	253	219	199
BuRd	11	11	8	244	165	130
BuRd	11	11	9	214	96	77
BuRd	11	11	10	178	24	43
BuRd	11	11	11	103	0	31
BuYlRd	2	11	1	145	191	219
BuYlRd	2	11	2	252	141	89
BuYlRd	3	11	1	145	191	219
BuYlRd	3	11	2	255	255	191
BuYlRd	3	11	3	252	141	89
BuYlRd	4	11	1	44	123	182
BuYlRd	4	11	2	171	217	233
BuYlRd	4	11	3	253	174	97
BuYlRd	4	11	4	215	25	28
BuYlRd	5	11	1	44	123	182
BuYlRd	5	11	2	171	217	233
BuYlRd	5	11	3	255	255	191
BuYlRd	5	11	4	253	174	97
BuYlRd	5	11	5	215	25	28
BuYlRd	6	11	1	69	117	180
BuYlRd	6	11	2	145	191	219
BuYlRd	6	11	3	224	243	248
BuYlRd	6	11	4	254	224	144
BuYlRd	6	11	5	252	141	89
BuYlRd	6	11	6	215	48	39
BuYlRd	7	11	1	69	117	180
BuYlRd	7	11	2	145	191	219
BuYlRd	7	11	3	224	243	248
BuYlRd	7	11	4	255	255	191
BuYlRd	7	11	5	254	224	144
BuYlRd	7	11	6	252	141	89
BuYlRd	7	11	7	215	48	39
BuYlRd	8	11	1	69	117	180
BuYlRd	8	11	2	116	173	209
BuYlRd	8	11	3	171	217	233
BuYlRd	8	11	4	224	243	248
BuYlRd	8	11	5	254	224	144
BuYlRd	8	11	6	253	174	97
BuYlRd	8	11	7	244	109	67
BuYlRd	8	11	8	215	48	39
BuYlRd	9	11	1	69	117	180
BuYlRd	9	11	2	116	173	209
BuYlRd	9	11	3	171	217	233
BuYlRd	9	11	4	224	243	248
BuYlRd	9	11	5	255	255	191
BuYlRd	9	11	6	254	224	144
BuYlRd	9	11	7	253	174	97
BuYlRd	9	11	8	244	109	67
BuYlRd	9	11	9	215	48	39
BuYlRd	10	11	1	49	54	149
BuYlRd	10	11	2	69	117	180
BuYlRd	10	11	3	116	173	209
BuYlRd	10	11	4	171	217	233
BuYlRd	10	11	5	224	243	248
BuYlRd	10	11	6	254	224	144
BuYlRd	10	11	7	253	174	97
BuYlRd	10	11	8	244	109	67
BuYlRd	10	11	9	215	48	39
BuYlRd	10	11	10	165	0	38
BuYlRd	11	11	1	49	54	149
BuYlRd	11	11	2	69	117	180
BuYlRd	11	11	3	116	173	209
BuYlRd	11	11	4	171	217	233
BuYlRd	11	11	5	224	243	248
BuYlRd	11	11	6	255	255	191
BuYlRd	11	11	7	254	224	144
BuYlRd	11	11	8	253	174	97
BuYlRd	11	11	9	244	109	67
BuYlRd	11	11	10	215	48	39
BuYlRd	11	11	11	165	0	38
PRGn	2	11	1	175	141	195
PRGn	2	11	2	127	191	123
PRGn	3	11	1	175	141	195
PRGn	3	11	2	247	247	247
PRGn	3	11	3	127	191	123
PRGn	4	11	1	123	50	148
PRGn	4	11	2	194	165	207
PRGn	4	11	3	166	219	160
PRGn	4	11	4	0	136	55
PRGn	5	11	1	123	50	148
PRGn	5	11	2	194	165	207
PRGn	5	11	3	247	247	247
PRGn	5	11	4	166	219	160
PRGn	5	11	5	0	136	55
PRGn	6	11	1	118	42	131
PRGn	6	11	2	175	141	195
PRGn	6	11	3	231	212	232
PRGn	6	11	4	217	240	211
PRGn	6	11	5	127	191	123
PRGn	6	11	6	27	120	55
PRGn	7	11	1	118	42	131
PRGn	7	11	2	175	141	195
PRGn	7	11	3	231	212	232
PRGn	7	11	4	247	247	247
PRGn	7	11	5	217	240	211
PRGn	7	11	6	127	191	123
PRGn	7	11	7	27	120	55
PRGn	8	11	1	118	42	131
PRGn	8	11	2	153	112	171
PRGn	8	11	3	194	165	207
PRGn	8	11	4	231	212	232
PRGn	8	11	5	217	240	211
PRGn	8	11	6	166	219	160
PRGn	8	11	7	90	174	97
PRGn	8	11	8	27	120	55
PRGn	9	11	1	118	42	131
PRGn	9	11	2	153	112	171
PRGn	9	11	3	194	165	207
PRGn	9	11	4	231	212	232
PRGn	9	11	5	247	247	247
PRGn	9	11	6	217	240	211
PRGn	9	11	7	166	219	160
PRGn	9	11	8	90	174	97
PRGn	9	11	9	27	120	55
PRGn	10	11	1	64	0	75
PRGn	10	11	2	118	42	131
PRGn	10	11	3	153	112	171
PRGn	10	11	4	194	165	207
PRGn	10	11	5	231	212	232
PRGn	10	11	6	217	240	211
PRGn	10	11	7	166	219	160
PRGn	10	11	8	90	174	97
PRGn	10	11	9	27	120	55
PRGn	10	11	10	0	68	27
PRGn	11	11	1	64	0	75
PRGn	11	11	2	118	42	131
PRGn	11	11	3	153	112	171
PRGn	11	11	4	194	165	207
PRGn	11	11	5	231	212	232
PRGn	11	11	6	247	247	247
PRGn	11	11	7	217	240	211
PRGn	11	11	8	166	219	160
PRGn	11	11	9	90	174	97
PRGn	11	11	10	27	120	55
PRGn	11	11	11	0	68	27
PiYG	2	11	1	233	163	201
PiYG	2	11	2	161	215	106
PiYG	3	11	1	233	163	201
PiYG	3	11	2	247	247	247
PiYG	3	11	3	161	215	106
PiYG	4	11	1	208	28	139
PiYG	4	11	2	241	182	218
PiYG	4	11	3	184	225	134
PiYG	4	11	4	77	172	38
PiYG	5	11	1	208	28	139
PiYG	5	11	2	241	182	218
PiYG	5	11	3	247	247	247
PiYG	5	11	4	184	225	134
PiYG	5	11	5	77	172	38
PiYG	6	11	1	197	27	125
PiYG	6	11	2	233	163	201
PiYG	6	11	3	253	224	239
PiYG	6	11	4	230	245	208
PiYG	6	11	5	161	215	106
PiYG	6	11	6	77	146	33
PiYG	7	11	1	197	27	125
PiYG	7	11	2	233	163	201
PiYG	7	11	3	253	224	239
PiYG	7	11	4	247	247	247
PiYG	7	11	5	230	245	208
PiYG	7	11	6	161	215	106
PiYG	7	11	7	77	146	33
PiYG	8	11	1	197	27	125
PiYG	8	11	2	222	119	174
PiYG	8	11	3	241	182	218
PiYG	8	11	4	253	224	239
PiYG	8	11	5	230	245	208
PiYG	8	11	6	184	225	134
PiYG	8	11	7	127	188	65
PiYG	8	11	8	77	146	33
PiYG	9	11	1	197	27	125
PiYG	9	11	2	222	119	174
PiYG	9	11	3	241	182	218
PiYG	9	11	4	253	224	239
PiYG	9	11	5	247	247	247
PiYG	9	11	6	230	245	208
PiYG	9	11	7	184	225	134
PiYG	9	11	8	127	188	65
PiYG	9	11	9	77	146	33
PiYG	10	11	1	142	1	82
PiYG	10	11	2	197	27	125
PiYG	10	11	3	222	119	174
PiYG	10	11	4	241	182	218
PiYG	10	11	5	253	224	239
PiYG	10	11	6	230	245	208
PiYG	10	11	7	184	225	134
PiYG	10	11	8	127	188	65
PiYG	10	11	9	77	146	33
PiYG	10	11	10	39	100	25
PiYG	11	11	1	142	1	82
PiYG	11	11	2	197	27	125
PiYG	11	11	3	222	119	174
PiYG	11	11	4	241	182	218
PiYG	11	11	5	253	224	239
PiYG	11	11	6	247	247	247
PiYG	11	11	7	230	245	208
PiYG	11	11	8	184	225	134
PiYG	11	11	9	127	188	65
PiYG	11	11	10	77	146	33
PiYG	11	11	11	39	100	25
PuOr	2	11	1	241	163	64
PuOr	2	11	2	153	142	195
PuOr	3	11	1	241	163	64
PuOr	3	11	2	247	247	247
PuOr	3	11	3	153	142	195
PuOr	4	11	1	230	97	1
PuOr	4	11	2	253	184	99
PuOr	4	11	3	178	171	210
PuOr	4	11	4	94	60	153
PuOr	5	11	1	230	97	1
PuOr	5	11	2	253	184	99
PuOr	5	11	3	247	247	247
PuOr	5	11	4	178	171	210
PuOr	5	11	5	94	60	153
PuOr	6	11	1	179	88	6
PuOr	6	11	2	241	163	64
PuOr	6	11	3	254	224	182
PuOr	6	11	4	216	218	235
PuOr	6	11	5	153	142	195
PuOr	6	11	6	84	39	136
PuOr	7	11	1	179	88	6
PuOr	7	11	2	241	163	64
PuOr	7	11	3	254	224	182
PuOr	7	11	4	247	247	247
PuOr	7	11	5	216	218	235
PuOr	7	11	6	153	142	195
PuOr	7	11	7	84	39	136
PuOr	8	11	1	179	88	6
PuOr	8	11	2	224	130	20
PuOr	8	11	3	253	184	99
PuOr	8	11	4	254	224	182
PuOr	8	11	5	216	218	235
PuOr	8	11	6	178	171	210
PuOr	8	11	7	128	115	172
PuOr	8	11	8	84	39	136
PuOr	9	11	1	179	88	6
PuOr	9	11	2	224	130	20
PuOr	9	11	3	253	184	99
PuOr	9	11	4	254	224	182
PuOr	9	11	5	247	247	247
PuOr	9	11	6	216	218	235
PuOr	9	11	7	178	171	210
PuOr	9	11	8	128	115	172
PuOr	9	11	9	84	39	136
PuOr	10	11	1	127	59	8
PuOr	10	11	2	179	88	6
PuOr	10	11	3	224	130	20
PuOr	10	11	4	253	184	99
PuOr	10	11	5	254	224	182
PuOr	10	11	6	216	218	235
PuOr	10	11	7	178	171	210
PuOr	10	11	8	128	115	172
PuOr	10	11	9	84	39	136
PuOr	10	11	10	45	0	75
PuOr	11	11	1	127	59	8
PuOr	11	11	2	179	88	6
PuOr	11	11	3	224	130	20
PuOr	11	11	4	253	184	99
PuOr	11	11	5	254	224	182
PuOr	11	11	6	247	247	247
PuOr	11	11	7	216	218	235
PuOr	11	11	8	178	171	210
PuOr	11	11	9	128	115	172
PuOr	11	11	10	84	39	136
PuOr	11	11	11	45	0	75
RdBu	2	11	1	239	138	98
RdBu	2	11	2	103	169	207
RdBu	3	11	1	239	138	98
RdBu	3	11	2	247	247	247
RdBu	3	11	3	103	169	207
RdBu	4	11	1	202	0	32
RdBu	4	11	2	244	165	130
RdBu	4	11	3	146	197	222
RdBu	4	11	4	5	113	176
RdBu	5	11	1	202	0	32
RdBu	5	11	2	244	165	130
RdBu	5	11	3	247	247	247
RdBu	5	11	4	146	197	222
RdBu	5	11	5	5	113	176
RdBu	6	11	1	178	24	43
RdBu	6	11	2	239	138	98
RdBu	6	11	3	253	219	199
RdBu	6	11	4	209	229	240
RdBu	6	11	5	103	169	207
RdBu	6	11	6	33	102	172
RdBu	7	11	1	178	24	43
RdBu	7	11	2	239	138	98
RdBu	7	11	3	253	219	199
RdBu	7	11	4	247	247	247
RdBu	7	11	5	209	229	240
RdBu	7	11	6	103	169	207
RdBu	7	11	7	33	102	172
RdBu	8	11	1	178	24	43
RdBu	8	11	2	214	96	77
RdBu	8	11	3	244	165	130
RdBu	8	11	4	253	219	199
RdBu	8	11	5	209	229	240
RdBu	8	11	6	146	197	222
RdBu	8	11	7	67	147	195
RdBu	8	11	8	33	102	172
RdBu	9	11	1	178	24	43
RdBu	9	11	2	214	96	77
RdBu	9	11	3	244	165	130
RdBu	9	11	4	253	219	199
RdBu	9	11	5	247	247	247
RdBu	9	11	6	209	229	240
RdBu	9	11	7	146	197	222
RdBu	9	11	8	67	147	195
RdBu	9	11	9	33	102	172
RdBu	10	11	1	103	0	31
RdBu	10	11	2	178	24	43
RdBu	10	11	3	214	96	77
RdBu	10	11	4	244	165	130
RdBu	10	11	5	253	219	199
RdBu	10	11	6	209	229	240
RdBu	10	11	7	146	197	222
RdBu	10	11	8	67	147	195
RdBu	10	11	9	33	102	172
RdBu	10	11	10	5	48	97
RdBu	11	11	1	103	0	31
RdBu	11	11	2	178	24	43
RdBu	11	11	3	214	96	77
RdBu	11	11	4	244	165	130
RdBu	11	11	5	253	219	199
RdBu	11	11	6	247	247	247
RdBu	11	11	7	209	229	240
RdBu	11	11	8	146	197	222
RdBu	11	11	9	67	147	195
RdBu	11	11	10	33	102	172
RdBu	11	11	11	5	48	97
RdGy	2	11	1	239	138	98
RdGy	2	11	2	153	153	153
RdGy	3	11	1	239	138	98
RdGy	3	11	2	255	255	255
RdGy	3	11	3	153	153	153
RdGy	4	11	1	202	0	32
RdGy	4	11	2	244	165	130
RdGy	4	11	3	186	186	186
RdGy	4	11	4	64	64	64
RdGy	5	11	1	202	0	32
RdGy	5	11	2	244	165	130
RdGy	5	11	3	255	255	255
RdGy	5	11	4	186	186	186
RdGy	5	11	5	64	64	64
RdGy	6	11	1	178	24	43
RdGy	6	11	2	239	138	98
RdGy	6	11	3	253	219	199
RdGy	6	11	4	224	224	224
RdGy	6	11	5	153	153	153
RdGy	6	11	6	77	77	77
RdGy	7	11	1	178	24	43
RdGy	7	11	2	239	138	98
RdGy	7	11	3	253	219	199
RdGy	7	11	4	255	255	255
RdGy	7	11	5	224	224	224
RdGy	7	11	6	153	153	153
RdGy	7	11	7	77	77	77
RdGy	8	11	1	178	24	43
RdGy	8	11	2	214	96	77
RdGy	8	11	3	244	165	130
RdGy	8	11	4	253	219	199
RdGy	8	11	5	224	224	224
RdGy	8	11	6	186	186	186
RdGy	8	11	7	135	135	135
RdGy	8	11	8	77	77	77
RdGy	9	11	1	178	24	43
RdGy	9	11	2	214	96	77
RdGy	9	11	3	244	165	130
RdGy	9	11	4	253	219	199
RdGy	9	11	5	255	255	255
RdGy	9	11	6	224	224	224
RdGy	9	11	7	186	186	186
RdGy	9	11	8	135	135	135
RdGy	9	11	9	77	77	77
RdGy	10	11	1	103	0	31
RdGy	10	11	2	178	24	43
RdGy	10	11	3	214	96	77
RdGy	10	11	4	244	165	130
RdGy	10	11	5	253	219	199
RdGy	10	11	6	224	224	224
RdGy	10	11	7	186	186	186
RdGy	10	11	8	135	135	135
RdGy	10	11	9	77	77	77
RdGy	10	11	10	26	26	26
RdGy	11	11	1	103	0	31
RdGy	11	11	2	178	24	43
RdGy	11	11	3	214	96	77
RdGy	11	11	4	244	165	130
RdGy	11	11	5	253	219	199
RdGy	11	11	6	255	255	255
RdGy	11	11	7	224	224	224
RdGy	11	11	8	186	186	186
RdGy	11	11	9	135	135	135
RdGy	11	11	10	77	77	77
RdGy	11	11	11	26	26	26
RdYlBu	2	11	1	252	141	89
RdYlBu	2	11	2	145	191	219
RdYlBu	3	11	1	252	141	89
RdYlBu	3	11	2	255	255	191
RdYlBu	3	11	3	145	191	219
RdYlBu	4	11	1	215	25	28
RdYlBu	4	11	2	253	174	97
RdYlBu	4	11	3	171	217	233
RdYlBu	4	11	4	44	123	182
RdYlBu	5	11	1	215	25	28
RdYlBu	5	11	2	253	174	97
RdYlBu	5	11	3	255	255	191
RdYlBu	5	11	4	171	217	233
RdYlBu	5	11	5	44	123	182
RdYlBu	6	11	1	215	48	39
RdYlBu	6	11	2	252	141	89
RdYlBu	6	11	3	254	224	144
RdYlBu	6	11	4	224	243	248
RdYlBu	6	11	5	145	191	219
RdYlBu	6	11	6	69	117	180
RdYlBu	7	11	1	215	48	39
RdYlBu	7	11	2	252	141	89
RdYlBu	7	11	3	254	224	144
RdYlBu	7	11	4	255	255	191
RdYlBu	7	11	5	224	243	248
RdYlBu	7	11	6	145	191	219
RdYlBu	7	11	7	69	117	180
RdYlBu	8	11	1	215	48	39
RdYlBu	8	11	2	244	109	67
RdYlBu	8	11	3	253	174	97
RdYlBu	8	11	4	254	224	144
RdYlBu	8	11	5	224	243	248
RdYlBu	8	11	6	171	217	233
RdYlBu	8	11	7	116	173	209
RdYlBu	8	11	8	69	117	180
RdYlBu	9	11	1	215	48	39
RdYlBu	9	11	2	244	109	67
RdYlBu	9	11	3	253	174	97
RdYlBu	9	11	4	254	224	144
RdYlBu	9	11	5	255	255	191
RdYlBu	9	11	6	224	243	248
RdYlBu	9	11	7	171	217	233
RdYlBu	9	11	8	116	173	209
RdYlBu	9	11	9	69	117	180
RdYlBu	10	11	1	165	0	38
RdYlBu	10	11	2	215	48	39
RdYlBu	10	11	3	244	109	67
RdYlBu	10	11	4	253	174	97
RdYlBu	10	11	5	254	224	144
RdYlBu	10	11	6	224	243	248
RdYlBu	10	11	7	171	217	233
RdYlBu	10	11	8	116	173	209
RdYlBu	10	11	9	69	117	180
RdYlBu	10	11	10	49	54	149
RdYlBu	11	11	1	165	0	38
RdYlBu	11	11	2	215	48	39
RdYlBu	11	11	3	244	109	67
RdYlBu	11	11	4	253	174	97
RdYlBu	11	11	5	254	224	144
RdYlBu	11	11	6	255	255	191
RdYlBu	11	11	7	224	243	248
RdYlBu	11	11	8	171	217	233
RdYlBu	11	11	9	116	173	209
RdYlBu	11	11	10	69	117	180
RdYlBu	11	11	11	49	54	149
RdYlGn	2	11	1	252	141	89
RdYlGn	2	11	2	145	207	96
RdYlGn	3	11	1	252	141	89
RdYlGn	3	11	2	255	255	191
RdYlGn	3	11	3	145	207	96
RdYlGn	4	11	1	215	25	28
RdYlGn	4	11	2	253	174	97
RdYlGn	4	11	3	166	217	106
RdYlGn	4	11	4	26	150	65
RdYlGn	5	11	1	215	25	28
RdYlGn	5	11	2	253	174	97
RdYlGn	5	11	3	255	255	191
RdYlGn	5	11	4	166	217	106
RdYlGn	5	11	5	26	150	65
RdYlGn	6	11	1	215	48	39
RdYlGn	6	11	2	252	141	89
RdYlGn	6	11	3	254	224	139
RdYlGn	6	11	4	217	239	139
RdYlGn	6	11	5	145	207	96
RdYlGn	6	11	6	26	152	80
RdYlGn	7	11	1	215	48	39
RdYlGn	7	11	2	252	141	89
RdYlGn	7	11	3	254	224	139
RdYlGn	7	11	4	255	255	191
RdYlGn	7	11	5	217	239	139
RdYlGn	7	11	6	145	207	96
RdYlGn	7	11	7	26	152	80
RdYlGn	8	11	1	215	48	39
RdYlGn	8	11	2	244	109	67
RdYlGn	8	11	3	253	174	97
RdYlGn	8	11	4	254	224	139
RdYlGn	8	11	5	217	239	139
RdYlGn	8	11	6	166	217	106
RdYlGn	8	11	7	102	189	99
RdYlGn	8	11	8	26	152	80
RdYlGn	9	11	1	215	48	39
RdYlGn	9	11	2	244	109	67
RdYlGn	9	11	3	253	174	97
RdYlGn	9	11	4	254	224	139
RdYlGn	9	11	5	255	255	191
RdYlGn	9	11	6	217	239	139
RdYlGn	9	11	7	166	217	106
RdYlGn	9	11	8	102	189	99
RdYlGn	9	11	9	26	152	80
RdYlGn	10	11	1	165	0	38
RdYlGn	10	11	2	215	48	39
RdYlGn	10	11	3	244	109	67
RdYlGn	10	11	4	253	174	97
RdYlGn	10	11	5	254	224	139
RdYlGn	10	11	6	217	239	139
RdYlGn	10	11	7	166	217	106
RdYlGn	10	11	8	102	189	99
RdYlGn	10	11	9	26	152	80
RdYlGn	10	11	10	0	104	55
RdYlGn	11	11	1	165	0	38
RdYlGn	11	11	2	215	48	39
RdYlGn	11	11	3	244	109	67
RdYlGn	11	11	4	253	174	97
RdYlGn	11	11	5	254	224	139
RdYlGn	11	11	6	255	255	191
RdYlGn	11	11	7	217	239	139
RdYlGn	11	11	8	166	217	106
RdYlGn	11	11	9	102	189	99
RdYlGn	11	11	10	26	152	80
RdYlGn	11	11	11	0	104	55
Spectral	2	11	1	252	141	89
Spectral	2	11	2	153	213	148
Spectral	3	11	1	252	141	89
Spectral	3	11	2	255	255	191
Spectral	3	11	3	153	213	148
Spectral	4	11	1	215	25	28
Spectral	4	11	2	253	174	97
Spectral	4	11	3	171	221	164
Spectral	4	11	4	43	131	186
Spectral	5	11	1	215	25	28
Spectral	5	11	2	253	174	97
Spectral	5	11	3	255	255	191
Spectral	5	11	4	171	221	164
Spectral	5	11	5	43	131	186
Spectral	6	11	1	213	62	79
Spectral	6	11	2	252	141	89
Spectral	6	11	3	254	224	139
Spectral	6	11	4	230	245	152
Spectral	6	11	5	153	213	148
Spectral	6	11	6	50	136	189
Spectral	7	11	1	213	62	79
Spectral	7	11	2	252	141	89
Spectral	7	11	3	254	224	139
Spectral	7	11	4	255	255	191
Spectral	7	11	5	230	245	152
Spectral	7	11	6	153	213	148
Spectral	7	11	7	50	136	189
Spectral	8	11	1	213	62	79
Spectral	8	11	2	244	109	67
Spectral	8	11	3	253	174	97
Spectral	8	11	4	254	224	139
Spectral	8	11	5	230	245	152
Spectral	8	11	6	171	221	164
Spectral	8	11	7	102	194	165
Spectral	8	11	8	50	136	189
Spectral	9	11	1	213	62	79
Spectral	9	11	2	244	109	67
Spectral	9	11	3	253	174	97
Spectral	9	11	4	254	224	139
Spectral	9	11	5	255	255	191
Spectral	9	11	6	230	245	152
Spectral	9	11	7	171	221	164
Spectral	9	11	8	102	194	165
Spectral	9	11	9	50	136	189
Spectral	10	11	1	158	1	66
Spectral	10	11	2	213	62	79
Spectral	10	11	3	244	109	67
Spectral	10	11	4	253	174	97
Spectral	10	11	5	254	224	139
Spectral	10	11	6	230	245	152
Spectral	10	11	7	171	221	164
Spectral	10	11	8	102	194	165
Spectral	10	11	9	50	136	189
Spectral	10	11	10	94	79	162
Spectral	11	11	1	158	1	66
Spectral	11	11	2	213	62	79
Spectral	11	11	3	244	109	67
Spectral	11	11	4	253	174	97
Spectral	11	11	5	254	224	139
Spectral	11	11	6	255	255	191
Spectral	11	11	7	230	245	152
Spectral	11	11	8	171	221	164
Spectral	11	11	9	102	194	165
Spectral	11	11	10	50	136	189
Spectral	11	11	11	94	79	162
Accent	2	8	1	127	201	127
Accent	2	8	2	190	174	212
Accent	3	8	1	127	201	127
Accent	3	8	2	190	174	212
Accent	3	8	3	253	192	134
Accent	4	8	1	127	201	127
Accent	4	8	2	190	174	212
Accent	4	8	3	253	192	134
Accent	4	8	4	255	255	153
Accent	5	8	1	127	201	127
Accent	5	8	2	190	174	212
Accent	5	8	3	253	192	134
Accent	5	8	4	255	255	153
Accent	5	8	5	56	108	176
Accent	6	8	1	127	201	127
Accent	6	8	2	190	174	212
Accent	6	8	3	253	192	134
Accent	6	8	4	255	255	153
Accent	6	8	5	56	108	176
Accent	6	8	6	240	2	127
Accent	7	8	1	127	201	127
Accent	7	8	2	190	174	212
Accent	7	8	3	253	192	134
Accent	7	8	4	255	255	153
Accent	7	8	5	56	108	176
Accent	7	8	6	240	2	127
Accent	7	8	7	191	91	23
Accent	8	8	1	127	201	127
Accent	8	8	2	190	174	212
Accent	8	8	3	253	192	134
Accent	8	8	4	255	255	153
Accent	8	8	5	56	108	176
Accent	8	8	6	240	2	127
Accent	8	8	7	191	91	23
Accent	8	8	8	102	102	102
Dark2	2	8	1	27	158	119
Dark2	2	8	2	217	95	2
Dark2	3	8	1	27	158	119
Dark2	3	8	2	217	95	2
Dark2	3	8	3	117	112	179
Dark2	4	8	1	27	158	119
Dark2	4	8	2	217	95	2
Dark2	4	8	3	117	112	179
Dark2	4	8	4	231	41	138
Dark2	5	8	1	27	158	119
Dark2	5	8	2	217	95	2
Dark2	5	8	3	117	112	179
Dark2	5	8	4	231	41	138
Dark2	5	8	5	102	166	30
Dark2	6	8	1	27	158	119
Dark2	6	8	2	217	95	2
Dark2	6	8	3	117	112	179
Dark2	6	8	4	231	41	138
Dark2	6	8	5	102	166	30
Dark2	6	8	6	230	171	2
Dark2	7	8	1	27	158	119
Dark2	7	8	2	217	95	2
Dark2	7	8	3	117	112	179
Dark2	7	8	4	231	41	138
Dark2	7	8	5	102	166	30
Dark2	7	8	6	230	171	2
Dark2	7	8	7	166	118	29
Dark2	8	8	1	27	158	119
Dark2	8	8	2	217	95	2
Dark2	8	8	3	117	112	179
Dark2	8	8	4	231	41	138
Dark2	8	8	5	102	166	30
Dark2	8	8	6	230	171	2
Dark2	8	8	7	166	118	29
Dark2	8	8	8	102	102	102
Paired	2	12	1	166	206	227
Paired	2	12	2	31	120	180
Paired	3	12	1	166	206	227
Paired	3	12	2	31	120	180
Paired	3	12	3	178	223	138
Paired	4	12	1	166	206	227
Paired	4	12	2	31	120	180
Paired	4	12	3	178	223	138
Paired	4	12	4	51	160	44
Paired	5	12	1	166	206	227
Paired	5	12	2	31	120	180
Paired	5	12	3	178	223	138
Paired	5	12	4	51	160	44
Paired	5	12	5	251	154	153
Paired	6	12	1	166	206	227
Paired	6	12	2	31	120	180
Paired	6	12	3	178	223	138
Paired	6	12	4	51	160	44
Paired	6	12	5	251	154	153
Paired	6	12	6	227	26	28
Paired	7	12	1	166	206	227
Paired	7	12	2	31	120	180
Paired	7	12	3	178	223	138
Paired	7	12	4	51	160	44
Paired	7	12	5	251	154	153
Paired	7	12	6	227	26	28
Paired	7	12	7	253	191	111
Paired	8	12	1	166	206	227
Paired	8	12	2	31	120	180
Paired	8	12	3	178	223	138
Paired	8	12	4	51	160	44
Paired	8	12	5	251	154	153
Paired	8	12	6	227	26	28
Paired	8	12	7	253	191	111
Paired	8	12	8	255	127	0
Paired	9	12	1	166	206	227
Paired	9	12	2	31	120	180
Paired	9	12	3	178	223	138
Paired	9	12	4	51	160	44
Paired	9	12	5	251	154	153
Paired	9	12	6	227	26	28
Paired	9	12	7	253	191	111
Paired	9	12	8	255	127	0
Paired	9	12	9	202	178	214
Paired	10	12	1	166	206	227
Paired	10	12	2	31	120	180
Paired	10	12	3	178	223	138
Paired	10	12	4	51	160	44
Paired	10	12	5	251	154	153
Paired	10	12	6	227	26	28
Paired	10	12	7	253	191	111
Paired	10	12	8	255	127	0
Paired	10	12	9	202	178	214
Paired	10	12	10	106	61	154
Paired	11	12	1	166	206	227
Paired	11	12	2	31	120	180
Paired	11	12	3	178	223	138
Paired	11	12	4	51	160	44
Paired	11	12	5	251	154	153
Paired	11	12	6	227	26	28
Paired	11	12	7	253	191	111
Paired	11	12	8	255	127	0
Paired	11	12	9	202	178	214
Paired	11	12	10	106	61	154
Paired	11	12	11	255	255	153
Paired	12	12	1	166	206	227
Paired	12	12	2	31	120	180
Paired	12	12	3	178	223	138
Paired	12	12	4	51	160	44
Paired	12	12	5	251	154	153
Paired	12	12	6	227	26	28
Paired	12	12	7	253	191	111
Paired	12	12	8	255	127	0
Paired	12	12	9	202	178	214
Paired	12	12	10	106	61	154
Paired	12	12	11	255	255	153
Paired	12	12	12	177	89	40
Pastel1	2	9	1	251	180	174
Pastel1	2	9	2	179	205	227
Pastel1	3	9	1	251	180	174
Pastel1	3	9	2	179	205	227
Pastel1	3	9	3	204	235	197
Pastel1	4	9	1	251	180	174
Pastel1	4	9	2	179	205	227
Pastel1	4	9	3	204	235	197
Pastel1	4	9	4	222	203	228
Pastel1	5	9	1	251	180	174
Pastel1	5	9	2	179	205	227
Pastel1	5	9	3	204	235	197
Pastel1	5	9	4	222	203	228
Pastel1	5	9	5	254	217	166
Pastel1	6	9	1	251	180	174
Pastel1	6	9	2	179	205	227
Pastel1	6	9	3	204	235	197
Pastel1	6	9	4	222	203	228
Pastel1	6	9	5	254	217	166
Pastel1	6	9	6	255	255	204
Pastel1	7	9	1	251	180	174
Pastel1	7	9	2	179	205	227
Pastel1	7	9	3	204	235	197
Pastel1	7	9	4	222	203	228
Pastel1	7	9	5	254	217	166
Pastel1	7	9	6	255	255	204
Pastel1	7	9	7	229	216	189
Pastel1	8	9	1	251	180	174
Pastel1	8	9	2	179	205	227
Pastel1	8	9	3	204	235	197
Pastel1	8	9	4	222	203	228
Pastel1	8	9	5	254	217	166
Pastel1	8	9	6	255	255	204
Pastel1	8	9	7	229	216	189
Pastel1	8	9	8	253	218	236
Pastel1	9	9	1	251	180	174
Pastel1	9	9	2	179	205	227
Pastel1	9	9	3	204	235	197
Pastel1	9	9	4	222	203	228
Pastel1	9	9	5	254	217	166
Pastel1	9	9	6	255	255	204
Pastel1	9	9	7	229	216	189
Pastel1	9	9	8	253	218	236
Pastel1	9	9	9	242	242	242
Pastel2	2	8	1	179	226	205
Pastel2	2	8	2	253	205	172
Pastel2	3	8	1	179	226	205
Pastel2	3	8	2	253	205	172
Pastel2	3	8	3	203	213	232
Pastel2	4	8	1	179	226	205
Pastel2	4	8	2	253	205	172
Pastel2	4	8	3	203	213	232
Pastel2	4	8	4	244	202	228
Pastel2	5	8	1	179	226	205
Pastel2	5	8	2	253	205	172
Pastel2	5	8	3	203	213	232
Pastel2	5	8	4	244	202	228
Pastel2	5	8	5	230	245	201
Pastel2	6	8	1	179	226	205
Pastel2	6	8	2	253	205	172
Pastel2	6	8	3	203	213	232
Pastel2	6	8	4	244	202	228
Pastel2	6	8	5	230	245	201
Pastel2	6	8	6	255	242	174
Pastel2	7	8	1	179	226	205
Pastel2	7	8	2	253	205	172
Pastel2	7	8	3	203	213	232
Pastel2	7	8	4	244	202	228
Pastel2	7	8	5	230	245	201
Pastel2	7	8	6	255	242	174
Pastel2	7	8	7	241	226	204
Pastel2	8	8	1	179	226	205
Pastel2	8	8	2	253	205	172
Pastel2	8	8	3	203	213	232
Pastel2	8	8	4	244	202	228
Pastel2	8	8	5	230	245	201
Pastel2	8	8	6	255	242	174
Pastel2	8	8	7	241	226	204
Pastel2	8	8	8	204	204	204
Set1	2	9	1	228	26	28
Set1	2	9	2	55	126	184
Set1	3	9	1	228	26	28
Set1	3	9	2	55	126	184
Set1	3	9	3	77	175	74
Set1	4	9	1	228	26	28
Set1	4	9	2	55	126	184
Set1	4	9	3	77	175	74
Set1	4	9	4	152	78	163
Set1	5	9	1	228	26	28
Set1	5	9	2	55	126	184
Set1	5	9	3	77	175	74
Set1	5	9	4	152	78	163
Set1	5	9	5	255	127	0
Set1	6	9	1	228	26	28
Set1	6	9	2	55	126	184
Set1	6	9	3	77	175	74
Set1	6	9	4	152	78	163
Set1	6	9	5	255	127	0
Set1	6	9	6	255	255	51
Set1	7	9	1	228	26	28
Set1	7	9	2	55	126	184
Set1	7	9	3	77	175	74
Set1	7	9	4	152	78	163
Set1	7	9	5	255	127	0
Set1	7	9	6	255	255	51
Set1	7	9	7	166	86	40
Set1	8	9	1	228	26	28
Set1	8	9	2	55	126	184
Set1	8	9	3	77	175	74
Set1	8	9	4	152	78	163
Set1	8	9	5	255	127	0
Set1	8	9	6	255	255	51
Set1	8	9	7	166	86	40
Set1	8	9	8	247	129	191
Set1	9	9	1	228	26	28
Set1	9	9	2	55	126	184
Set1	9	9	3	77	175	74
Set1	9	9	4	152	78	163
Set1	9	9	5	255	127	0
Set1	9	9	6	255	255	51
Set1	9	9	7	166	86	40
Set1	9	9	8	247	129	191
Set1	9	9	9	153	153	153
Set2	2	8	1	102	194	165
Set2	2	8	2	252	141	98
Set2	3	8	1	102	194	165
Set2	3	8	2	252	141	98
Set2	3	8	3	141	160	203
Set2	4	8	1	102	194	165
Set2	4	8	2	252	141	98
Set2	4	8	3	141	160	203
Set2	4	8	4	231	138	195
Set2	5	8	1	102	194	165
Set2	5	8	2	252	141	98
Set2	5	8	3	141	160	203
Set2	5	8	4	231	138	195
Set2	5	8	5	166	216	84
Set2	6	8	1	102	194	165
Set2	6	8	2	252	141	98
Set2	6	8	3	141	160	203
Set2	6	8	4	231	138	195
Set2	6	8	5	166	216	84
Set2	6	8	6	255	217	47
Set2	7	8	1	102	194	165
Set2	7	8	2	252	141	98
Set2	7	8	3	141	160	203
Set2	7	8	4	231	138	195
Set2	7	8	5	166	216	84
Set2	7	8	6	255	217	47
Set2	7	8	7	229	196	148
Set2	8	8	1	102	194	165
Set2	8	8	2	252	141	98
Set2	8	8	3	141	160	203
Set2	8	8	4	231	138	195
Set2	8	8	5	166	216	84
Set2	8	8	6	255	217	47
Set2	8	8	7	229	196	148
Set2	8	8	8	179	179	179
Set3	2	12	1	141	211	199
Set3	2	12	2	255	255	179
Set3	3	12	1	141	211	199
Set3	3	12	2	255	255	179
Set3	3	12	3	190	186	218
Set3	4	12	1	141	211	199
Set3	4	12	2	255	255	179
Set3	4	12	3	190	186	218
Set3	4	12	4	251	128	114
Set3	5	12	1	141	211	199
Set3	5	12	2	255	255	179
Set3	5	12	3	190	186	218
Set3	5	12	4	251	128	114
Set3	5	12	5	128	177	211
Set3	6	12	1	141	211	199
Set3	6	12	2	255	255	179
Set3	6	12	3	190	186	218
Set3	6	12	4	251	128	114
Set3	6	12	5	128	177	211
Set3	6	12	6	253	180	98
Set3	7	12	1	141	211	199
Set3	7	12	2	255	255	179
Set3	7	12	3	190	186	218
Set3	7	12	4	251	128	114
Set3	7	12	5	128	177	211
Set3	7	12	6	253	180	98
Set3	7	12	7	179	222	105
Set3	8	12	1	141	211	199
Set3	8	12	2	255	255	179
Set3	8	12	3	190	186	218
Set3	8	12	4	251	128	114
Set3	8	12	5	128	177	211
Set3	8	12	6	253	180	98
Set3	8	12	7	179	222	105
Set3	8	12	8	252	205	229
Set3	9	12	1	141	211	199
Set3	9	12	2	255	255	179
Set3	9	12	3	190	186	218
Set3	9	12	4	251	128	114
Set3	9	12	5	128	177	211
Set3	9	12	6	253	180	98
Set3	9	12	7	179	222	105
Set3	9	12	8	252	205	229
Set3	9	12	9	217	217	217
Set3	10	12	1	141	211	199
Set3	10	12	2	255	255	179
Set3	10	12	3	190	186	218
Set3	10	12	4	251	128	114
Set3	10	12	5	128	177	211
Set3	10	12	6	253	180	98
Set3	10	12	7	179	222	105
Set3	10	12	8	252	205	229
Set3	10	12	9	217	217	217
Set3	10	12	10	188	128	189
Set3	11	12	1	141	211	199
Set3	11	12	2	255	255	179
Set3	11	12	3	190	186	218
Set3	11	12	4	251	128	114
Set3	11	12	5	128	177	211
Set3	11	12	6	253	180	98
Set3	11	12	7	179	222	105
Set3	11	12	8	252	205	229
Set3	11	12	9	217	217	217
Set3	11	12	10	188	128	189
Set3	11	12	11	204	235	197
Set3	12	12	1	141	211	199
Set3	12	12	2	255	255	179
Set3	12	12	3	190	186	218
Set3	12	12	4	251	128	114
Set3	12	12	5	128	177	211
Set3	12	12	6	253	180	98
Set3	12	12	7	179	222	105
Set3	12	12	8	252	205	229
Set3	12	12	9	217	217	217
Set3	12	12	10	188	128	189
Set3	12	12	11	204	235	197
Set3	12	12	12	255	237	111
